/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
import { EventEmitter } from '@angular/core';
import { Subscription } from 'rxjs';
import { ButtonClick } from '../../interfaces/button-click.interface';
import { ToolbarButton } from '../../interfaces/toolbar-button.interface';
import * as i0 from "@angular/core";
/**
 * A wrapper for `MatToolbar` to control how buttons are rendered in the
 * toolbar. Basically just left or right alignment in the toolbar. It also
 * includes the ability to render custom content in the middle of the toolbar,
 * for things like the search filter drop down meant to be rendered above
 * paged collections in any component that utilizes the
 * `PagedCollectionWithToolbar`.
 */
export declare class ButtonToolbarComponent {
    /** The management buttons to display in the toolbar. */
    buttons: ToolbarButton[];
    /**
     * String value indicating whether buttons should appear on left or right
     * side of screen (defaults to right).
     */
    buttonAlign: 'left' | 'right';
    /** Event emitted when user clicks button in toolbar. */
    buttonClick: EventEmitter<ButtonClick>;
    /** The subscriptions for the component. */
    sub: Subscription;
    constructor();
    /**
     * Emits a buttonClick event to the parent.
     *
     * @param buttonClick The action from the button that was clicked by the user.
     */
    emitButtonClick(buttonClick: ButtonClick): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ButtonToolbarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ButtonToolbarComponent, "ngx-mat-button-toolbar", never, { "buttons": "buttons"; "buttonAlign": "buttonAlign"; }, { "buttonClick": "buttonClick"; }, never, ["*"]>;
}
