import * as i0 from '@angular/core';
import { Injectable, Component, Input, NgModule, EventEmitter, ChangeDetectionStrategy, ContentChild, Output, ViewChild, Directive, HostListener, ElementRef, Inject, ViewChildren, ContentChildren } from '@angular/core';
import * as i4 from '@angular/common';
import { CommonModule } from '@angular/common';
import { ComponentPortal } from '@angular/cdk/portal';
import { BehaviorSubject, Subject, filter, Subscription } from 'rxjs';
import * as i1 from '@angular/router';
import { NavigationStart, RouterModule } from '@angular/router';
import { faTimes, faArrowUpWideShort, faArrowDownShortWide, faCaretDown, faSearch, faEdit, faTrash, faAngleDown, faAngleRight, faBars, faPlus } from '@fortawesome/free-solid-svg-icons';
import * as i2 from '@fortawesome/angular-fontawesome';
import { FontAwesomeModule } from '@fortawesome/angular-fontawesome';
import * as i2$1 from '@angular/cdk/overlay';
import { OverlayModule } from '@angular/cdk/overlay';
import * as i1$2 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import { DataSource, SelectionModel } from '@angular/cdk/collections';
import * as i3$2 from '@angular/material/table';
import { MatTableDataSource, MatColumnDef, MatTable, MatTableModule } from '@angular/material/table';
import { HttpHeaders } from '@angular/common/http';
import * as i2$6 from '@angular/material/sort';
import { MatSort, MatSortModule } from '@angular/material/sort';
import * as i1$1 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i2$2 from '@angular/material/select';
import { MatSelectModule } from '@angular/material/select';
import * as i4$1 from '@angular/material/core';
import * as i5 from '@angular/flex-layout/flex';
import * as i2$3 from '@angular/material/paginator';
import { MatPaginator, MatPaginatorModule } from '@angular/material/paginator';
import * as i1$3 from '@angular/material/checkbox';
import { MatCheckboxModule } from '@angular/material/checkbox';
import * as i5$1 from '@angular/material/tooltip';
import { MatTooltipModule } from '@angular/material/tooltip';
import * as i3 from '@angular/material/menu';
import { MatMenuModule } from '@angular/material/menu';
import { FlexLayoutModule } from '@angular/flex-layout';
import * as i1$5 from '@angular/material/toolbar';
import { MatToolbarModule } from '@angular/material/toolbar';
import * as i1$4 from '@angular/forms';
import { FormGroup, FormArray, FormsModule, ReactiveFormsModule } from '@angular/forms';
import * as i1$6 from '@angular/material/dialog';
import { MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import * as i5$2 from '@angular/material/grid-list';
import { MatGridList, MatGridTile, MatGridListModule } from '@angular/material/grid-list';
import * as i1$7 from '@angular/cdk/layout';
import { Breakpoints } from '@angular/cdk/layout';
import * as i2$4 from '@angular/material/progress-spinner';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import * as i2$5 from '@angular/material/list';
import { MatListModule } from '@angular/material/list';
import * as i6 from '@angular/flex-layout/extended';
import * as i3$1 from '@angular/material/sidenav';
import { MatSidenavModule } from '@angular/material/sidenav';
import * as i8 from 'angular-material-rail-drawer';
import { DrawerRailModule } from 'angular-material-rail-drawer';
import { MatDividerModule } from '@angular/material/divider';
import { MatInputModule } from '@angular/material/input';

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The options available for alert types.
 */
var AlertType;
(function (AlertType) {
    AlertType[AlertType["Success"] = 0] = "Success";
    AlertType[AlertType["Error"] = 1] = "Error";
    AlertType[AlertType["Info"] = 2] = "Info";
    AlertType[AlertType["Warning"] = 3] = "Warning";
})(AlertType || (AlertType = {}));

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `Alert` class defines properties useful for tracking and rendering alert
 * messages.
 */
class Alert {
    constructor(init) {
        this.autoClose = true;
        this.fade = true;
        Object.assign(this, init);
    }
}

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `AlertService` provides convenience methods for emitting alert messages
 * of type error, info, success, and warn.
 */
class AlertService {
    constructor() {
        /** List of alerts that should be rendered on screen. */
        this.alerts = [];
        /** Subject used to emit latest list of alerts. */
        this.alertsSubject = new BehaviorSubject(this.alerts);
        /** Observable of list of alerts. */
        this.alerts$ = this.alertsSubject.asObservable();
        /** Subject used to emit latest alert added to array of alerts. */
        this.subject = new Subject();
        /** Default id to set for alerts. */
        this.defaultId = 'default-alert';
    }
    /**
     * An observable for alerts that can be subscribed to for rendering or
     * dealing with alerts.
     *
     * @param id Optional id value to filter on.
     * @returns An observable for alert messages.
     */
    onAlert(id = this.defaultId) {
        return this.subject
            .asObservable()
            .pipe(filter((x) => x && x.id === id));
    }
    /**
     * Emits the given message as an error alert.
     *
     * @param message The message to render in the alert.
     * @param options Optional options to include for alert.
     */
    error(message, options) {
        this.alert(new Alert(Object.assign(Object.assign({}, options), { type: AlertType.Error, message })));
    }
    /**
     * Emits the given message as an info alert.
     *
     * @param message The message to render in the alert.
     * @param options Optional options to include for alert.
     */
    info(message, options) {
        this.alert(new Alert(Object.assign(Object.assign({}, options), { type: AlertType.Info, message })));
    }
    /**
     * Emits the given message as a success alert.
     *
     * @param message The message to render in the alert.
     * @param options Optional options to include for alert.
     */
    success(message, options) {
        this.alert(new Alert(Object.assign(Object.assign({}, options), { type: AlertType.Success, message })));
    }
    /**
     * Emits the given message as a warning alert.
     *
     * @param message The message to render in the alert.
     * @param options Optional options to include for alert.
     */
    warn(message, options) {
        this.alert(new Alert(Object.assign(Object.assign({}, options), { type: AlertType.Warning, message })));
    }
    /**
     * Emits the given alert. You should not need to call this method directly
     * unless you define alerts other than error, info, success, or warn.
     * Leaving this public so that is available as an option though...
     *
     * @param alert The alert to render.
     */
    alert(alert) {
        if (!alert.message) {
            this.alerts = [];
            this.alertsSubject.next(this.alerts);
        }
        else {
            // set id for alert if not already set and update subject for onAlert
            alert.id = alert.id || this.defaultId;
            this.subject.next(alert);
            // add alert to array of alerts currently rendered and update subj
            this.alerts.push(alert);
            this.alertsSubject.next(this.alerts);
            // auto close alert if required
            if (alert.autoClose) {
                setTimeout(() => this.removeAlert(alert), 3000);
            }
        }
    }
    /**
     * Clears alerts by emitting an Alert with empty message. AlertComponent has
     * logic to clear alerts when next Alert has empty message.
     *
     * @param id Optional id to set for the alert.
     */
    clear(id = this.defaultId) {
        this.subject.next(new Alert({ id }));
    }
    /**
     * Removes the given alert from array of alerts (if it is still in array).
     *
     * @param alert The alert to remove;
     */
    removeAlert(alert) {
        // check if already removed to prevent error on auto close
        if (!this.alerts.includes(alert))
            return;
        if (alert.fade) {
            const a = this.alerts.find((x) => x === alert);
            // fade out alert
            if (a) {
                a.fade = true;
            }
            // remove alert after faded out
            setTimeout(() => {
                this.alerts = this.alerts.filter((x) => x !== alert);
                this.alertsSubject.next(this.alerts);
            }, 250);
        }
        else {
            // remove alert
            this.alerts = this.alerts.filter((x) => x !== alert);
            this.alertsSubject.next(this.alerts);
        }
    }
}
AlertService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: AlertService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
AlertService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: AlertService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: AlertService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * `Alerts` handles rendering array of alerts to screen, and controls how
 * alerts are displayed (i.e. color/class based on type of alert).
 */
class AlertsComponent {
    constructor(router, alertService) {
        this.router = router;
        this.alertService = alertService;
        this.id = 'default-alert';
        this.alerts = [];
        this.faTimes = faTimes;
        this.sub = new Subscription();
    }
    ngOnDestroy() {
        this.sub.unsubscribe();
    }
    ngOnInit() {
        const sub = this.alertService.alerts$.subscribe((res) => {
            this.alerts = res;
        });
        this.sub.add(sub);
        // clear alerts on location change
        const routeSub = this.router.events.subscribe((event) => {
            if (event instanceof NavigationStart) {
                this.alertService.clear(this.id);
            }
        });
        this.sub.add(routeSub);
    }
    /**
     * Removes the given alert from array of alerts and therefore the screen,
     * as long as the alert is still on the screen.
     *
     * @param alert The alert to remove.
     */
    removeAlert(alert) {
        this.alertService.removeAlert(alert);
    }
    cssClass(alert) {
        const classes = ['alert', 'alert-dismissable'];
        const alertTypeClass = {
            [AlertType.Success]: 'alert-success',
            [AlertType.Error]: 'alert-danger',
            [AlertType.Info]: 'alert-info',
            [AlertType.Warning]: 'alert-warning'
        };
        classes.push(alertTypeClass[alert.type]);
        if (alert.fade) {
            classes.push('fade');
        }
        return classes.join(' ');
    }
}
AlertsComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: AlertsComponent, deps: [{ token: i1.Router }, { token: AlertService }], target: i0.ɵɵFactoryTarget.Component });
AlertsComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: AlertsComponent, selector: "ngx-mat-alerts", inputs: { id: "id" }, ngImport: i0, template: "<div fxLayout=\"column\" fxLayoutGap=\"10px\">\n    <div *ngFor=\"let alert of alerts\" class=\"{{cssClass(alert)}}\" fxLayout=\"row\">\n        <span [innerHTML]=\"alert.message\"></span>\n        <span fxFlex></span>\n        <span class=\"close\" (click)=\"removeAlert(alert)\">\n            <fa-icon [icon]=\"faTimes\"></fa-icon>\n        </span>\n    </div>\n</div>\n", styles: [":host{display:block;width:100%;overflow:auto}.alert{position:relative;padding:.75rem 1.25rem;margin:1rem;border:1px solid transparent;border-top-color:transparent;border-right-color:transparent;border-bottom-color:transparent;border-left-color:transparent;border-radius:.25rem}.alert-danger{color:#721c24;background-color:#f8d7da;border-color:#f5c6cb}.alert-info{color:#0c5460;background-color:#d1ecf1;border-color:#bee5eb}.alert-success{color:#155724;background-color:#d4edda;border-color:#c3e6cb}.alert-warning{color:#856404;background-color:#fff3cd;border-color:#ffeeba}.close:hover{cursor:pointer}\n"], components: [{ type: i2.FaIconComponent, selector: "fa-icon", inputs: ["icon", "title", "spin", "pulse", "mask", "styles", "flip", "size", "pull", "border", "inverse", "symbol", "rotate", "fixedWidth", "classes", "transform", "a11yRole"] }], directives: [{ type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: AlertsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-alerts', template: "<div fxLayout=\"column\" fxLayoutGap=\"10px\">\n    <div *ngFor=\"let alert of alerts\" class=\"{{cssClass(alert)}}\" fxLayout=\"row\">\n        <span [innerHTML]=\"alert.message\"></span>\n        <span fxFlex></span>\n        <span class=\"close\" (click)=\"removeAlert(alert)\">\n            <fa-icon [icon]=\"faTimes\"></fa-icon>\n        </span>\n    </div>\n</div>\n", styles: [":host{display:block;width:100%;overflow:auto}.alert{position:relative;padding:.75rem 1.25rem;margin:1rem;border:1px solid transparent;border-top-color:transparent;border-right-color:transparent;border-bottom-color:transparent;border-left-color:transparent;border-radius:.25rem}.alert-danger{color:#721c24;background-color:#f8d7da;border-color:#f5c6cb}.alert-info{color:#0c5460;background-color:#d1ecf1;border-color:#bee5eb}.alert-success{color:#155724;background-color:#d4edda;border-color:#c3e6cb}.alert-warning{color:#856404;background-color:#fff3cd;border-color:#ffeeba}.close:hover{cursor:pointer}\n"] }]
        }], ctorParameters: function () { return [{ type: i1.Router }, { type: AlertService }]; }, propDecorators: { id: [{
                type: Input
            }] } });

/**
 * `Alert` handles rendering and managing the OverlayRef needed to render
 * alerts on screen (on top of main content).
 */
class AlertComponent {
    constructor(alertService, overlay) {
        this.alertService = alertService;
        this.overlay = overlay;
        this.sub = new Subscription();
    }
    ngOnDestroy() {
        this.sub.unsubscribe();
    }
    ngOnInit() {
        const sub = this.alertService.onAlert().subscribe((alert) => {
            if (alert.message) {
                // create overlay if overlayRef not defined
                if (!this.overlayRef) {
                    const overlayRef = this.overlay.create();
                    this.overlayRef = overlayRef;
                    this.overlayRef.updateSize({ width: '100%' });
                    //create portal to render component
                    const componentPortal = new ComponentPortal(AlertsComponent);
                    // render portal in overlay
                    const compRef = this.overlayRef.attach(componentPortal);
                    // set alerts on AlertsComponent since subscription for
                    // onAlert there won't work for this one as its already
                    // been fired
                    compRef.instance.alerts = [alert];
                    // auto close alert if required
                    if (alert.autoClose) {
                        setTimeout(() => compRef.instance.removeAlert(alert), 3000);
                    }
                }
            }
        });
        this.sub.add(sub);
        // create subscription for clear overlay event emitter and
        // dispose of the overlay so components behind are availabe
        const subArray = this.alertService.alerts$.subscribe((res) => {
            var _a;
            if (res.length === 0) {
                (_a = this.overlayRef) === null || _a === void 0 ? void 0 : _a.dispose();
                this.overlayRef = undefined;
            }
        });
        this.sub.add(subArray);
    }
}
AlertComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: AlertComponent, deps: [{ token: AlertService }, { token: i2$1.Overlay }], target: i0.ɵɵFactoryTarget.Component });
AlertComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: AlertComponent, selector: "ngx-mat-alert", ngImport: i0, template: "", styles: ["@import\"~@angular/cdk/overlay-prebuilt.css\";\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: AlertComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-alert', template: "", styles: ["@import\"~@angular/cdk/overlay-prebuilt.css\";\n"] }]
        }], ctorParameters: function () { return [{ type: AlertService }, { type: i2$1.Overlay }]; } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
class AlertModule {
}
AlertModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: AlertModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
AlertModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: AlertModule, declarations: [AlertComponent, AlertsComponent], imports: [CommonModule, MatButtonModule, OverlayModule, FontAwesomeModule] });
AlertModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: AlertModule, imports: [[CommonModule, MatButtonModule, OverlayModule, FontAwesomeModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: AlertModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [AlertComponent, AlertsComponent],
                    imports: [CommonModule, MatButtonModule, OverlayModule, FontAwesomeModule]
                }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A wrapper for the `DataSource` class that provides a basic way to sort,
 * filter, paginate, and retrieve data from your main data source. Ultimately
 * this relies on an implementation of the `JsonDatastore` which is where the
 * functionality to filter, paginate, and retreive data comes from.
 *
 * There are two main functions to use to sort, filter, paginate, and retrieve
 * data. The `load` function includes parameters to sort, filter, paginate, and
 * retrieve data. All parameters are optional, so if you call `load()` without
 * any parameters, then you will get the broadest data set without any filter,
 * with the default sort of id values in ascending order, and with default
 * number of 25 results. The other function is `refresh()` which just calls
 * `load` using the last parameter values used.
 *
 * #### Basic Usage Example
 * ```typescript
 * class RemoteDataSourceUsageExample<T extends JsonModel> {
 *
 *     dataSource: RemoteDataSource<T>;
 *
 *     constructor(
 *         @Inject(JsonModel) private modelType: ModelType<T>,
 *         private jsonApiService: JsonDatastore
 *     ) {
 *         this.dataSource = new RemoteDataSource(this.modelType, this.jsonApiService);
 *     }
 *
 *     loadData(): void {
 *         this.dataSource.load();
 *     }
 *
 *     refresh(): void {
 *         this.dataSource.refresh();
 *     }
 * }
 *
 * ```
 *
 * > NOTE: The `RemoteDataSource` can be used with any component that paginates
 * > data, whether it is a grid, list, table, or any other kind of paged
 * > component that I can't think of right now.
 */
class RemoteDataSource extends DataSource {
    constructor(modelType, baseModelService) {
        super();
        this.modelType = modelType;
        this.baseModelService = baseModelService;
        this.data = [];
        this.loadingSubject = new BehaviorSubject(false);
        this.loading = this.loadingSubject.asObservable();
        this.dataSubject = new BehaviorSubject([]);
        this.total = 0;
    }
    /**
     * Returns the paginator for the data source.
     */
    get paginator() {
        return this.paginator$;
    }
    /**
     * Sets the paginator for the data source and the subscription for page
     * events so the data source is updated when user changes page or page
     * size.
     */
    set paginator(p) {
        var _a;
        this.paginator$ = p;
        (_a = this.paginator$) === null || _a === void 0 ? void 0 : _a.page.subscribe((next) => {
            this.pageIndex = next.pageIndex;
            this.pageSize = next.pageSize;
            this.refresh();
        });
    }
    /**
     * Returns the sort for the data source.
     */
    get sort() {
        return this.sort$;
    }
    /**
     * Sets the sort for the data source and the subscription for sort events
     * so the data source is updated when the user changes the active sort
     * field or the direction.
     */
    set sort(s) {
        var _a;
        this.sort$ = s;
        (_a = this.sort$) === null || _a === void 0 ? void 0 : _a.sortChange.subscribe((next) => {
            this.active = next.active;
            this.direction = next.direction;
            this.refresh();
        });
    }
    connect(collectionViewer) {
        // this.logger.info("RemoteDataSource: Connecting data source");
        return this.dataSubject.asObservable();
    }
    disconnect(collectionViewer) {
        // this.logger.info("RemoteDataSource: Disconnecting data source");
        this.dataSubject.complete();
        this.loadingSubject.complete();
    }
    /**
     * Loads the data for the collection.
     *
     * @param filter The filter to apply when loading the data.
     * @param sort The column to sort the data.
     * @param order The order to sort the data ("asc" or "desc").
     * @param pageIndex The page of data to get.
     * @param pageSize The number of results to get.
     * @param include Comma separated list of relationships to include in results.
     * @param headers Custom header values.
     */
    load(filter = {}, active = 'id', direction = 'asc', pageIndex = 0, pageSize = 20, include = '', headers = new HttpHeaders()) {
        this.filter = filter;
        this.active = active;
        this.direction = direction;
        this.pageIndex = pageIndex;
        this.pageSize = pageSize;
        this.include = include;
        this.headers = headers;
        // paged query for models that match the given filter and order results
        this.baseModelService
            .findAll(this.modelType, {
            page_size: pageSize.toString(),
            page: pageIndex.toString(),
            filter,
            sort: active,
            order: direction,
            include
        })
            .subscribe((res) => {
            // update meta data (totalPages based on total results and pageSize)
            this.total = res.getMeta().meta.total;
            if (this.pageSize) {
                this.totalPages = this.total / this.pageSize;
            }
            // update data for source with models returned from query
            this.data = res.getModels();
            this.dataSubject.next(this.data);
        });
    }
    /**
     * Reload the data using current paging and query parameters.
     */
    refresh() {
        this.load(this.filter, this.active, this.direction, this.pageIndex, this.pageSize, this.include, this.headers);
    }
}

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A custom component meant to allow user to change sort order for paged
 * collections. This is basically just a wrapper around `MatSelect` providing
 * some additional display details and an @Output emitter for the field to
 * sort on and order selected needed in the parent component to handle the
 * sort change for the collection.
 */
class SorterComponent extends MatSort {
    constructor() {
        super();
        /** The icon used for displaying current sort order. */
        this.faSort = faArrowUpWideShort;
        /** The options to display in the select drop down. */
        this.selectOptions = [];
        /** The list of fields to include in the sort. */
        this.options = [];
    }
    /**
     * Lifecycle method automatically called by angular when the component is
     * initialized.
     */
    ngOnInit() {
        super.ngOnInit();
        for (const option of this.options) {
            this.selectOptions.push({
                field: option,
                icon: faArrowUpWideShort,
                order: 'asc'
            });
            this.selectOptions.push({
                field: option,
                icon: faArrowDownShortWide,
                order: 'desc'
            });
            this.sortables.set(option, {
                id: option,
                start: 'asc',
                disableClear: true
            });
        }
    }
    /**
     * Handler for when the user selects an option in the drop down. Emits the
     * needed sort event to the parent so it can handle changing the sort
     * order for the data in the collection.
     *
     * @param event The event containing the value selected in the drop down.
     */
    onSelectionChange(event) {
        this.active = event.value.field;
        this.faSort = event.value.icon;
        this.direction = event.value.order;
        this.sortChange.emit({
            active: this.active,
            direction: this.direction
        });
    }
}
SorterComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: SorterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
SorterComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: SorterComponent, selector: "ngx-mat-sorter", inputs: { options: "options" }, usesInheritance: true, ngImport: i0, template: "<mat-form-field>\n    <mat-label>Sort By</mat-label>\n    <mat-select appearance=\"standard\" (selectionChange)=\"onSelectionChange($event)\">\n        <mat-select-trigger fxLayout=\"row\" fxLayoutGap=\"5px\">\n            <span>{{active}}</span>\n            <fa-icon [icon]=\"faSort\"></fa-icon>\n        </mat-select-trigger>\n        <mat-option *ngFor=\"let option of selectOptions\" [value]=\"option\">\n            <span>{{option.field}} - {{option.order}}</span>\n        </mat-option>\n    </mat-select>\n</mat-form-field>\n", styles: ["mat-form-field{font-size:12px;padding:.4375em 0}\n"], components: [{ type: i1$1.MatFormField, selector: "mat-form-field", inputs: ["color", "appearance", "hideRequiredMarker", "hintLabel", "floatLabel"], exportAs: ["matFormField"] }, { type: i2$2.MatSelect, selector: "mat-select", inputs: ["disabled", "disableRipple", "tabIndex"], exportAs: ["matSelect"] }, { type: i2.FaIconComponent, selector: "fa-icon", inputs: ["icon", "title", "spin", "pulse", "mask", "styles", "flip", "size", "pull", "border", "inverse", "symbol", "rotate", "fixedWidth", "classes", "transform", "a11yRole"] }, { type: i4$1.MatOption, selector: "mat-option", exportAs: ["matOption"] }], directives: [{ type: i1$1.MatLabel, selector: "mat-label" }, { type: i2$2.MatSelectTrigger, selector: "mat-select-trigger" }, { type: i5.DefaultLayoutDirective, selector: "  [fxLayout], [fxLayout.xs], [fxLayout.sm], [fxLayout.md],  [fxLayout.lg], [fxLayout.xl], [fxLayout.lt-sm], [fxLayout.lt-md],  [fxLayout.lt-lg], [fxLayout.lt-xl], [fxLayout.gt-xs], [fxLayout.gt-sm],  [fxLayout.gt-md], [fxLayout.gt-lg]", inputs: ["fxLayout", "fxLayout.xs", "fxLayout.sm", "fxLayout.md", "fxLayout.lg", "fxLayout.xl", "fxLayout.lt-sm", "fxLayout.lt-md", "fxLayout.lt-lg", "fxLayout.lt-xl", "fxLayout.gt-xs", "fxLayout.gt-sm", "fxLayout.gt-md", "fxLayout.gt-lg"] }, { type: i5.DefaultLayoutGapDirective, selector: "  [fxLayoutGap], [fxLayoutGap.xs], [fxLayoutGap.sm], [fxLayoutGap.md],  [fxLayoutGap.lg], [fxLayoutGap.xl], [fxLayoutGap.lt-sm], [fxLayoutGap.lt-md],  [fxLayoutGap.lt-lg], [fxLayoutGap.lt-xl], [fxLayoutGap.gt-xs], [fxLayoutGap.gt-sm],  [fxLayoutGap.gt-md], [fxLayoutGap.gt-lg]", inputs: ["fxLayoutGap", "fxLayoutGap.xs", "fxLayoutGap.sm", "fxLayoutGap.md", "fxLayoutGap.lg", "fxLayoutGap.xl", "fxLayoutGap.lt-sm", "fxLayoutGap.lt-md", "fxLayoutGap.lt-lg", "fxLayoutGap.lt-xl", "fxLayoutGap.gt-xs", "fxLayoutGap.gt-sm", "fxLayoutGap.gt-md", "fxLayoutGap.gt-lg"] }, { type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: SorterComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-sorter', template: "<mat-form-field>\n    <mat-label>Sort By</mat-label>\n    <mat-select appearance=\"standard\" (selectionChange)=\"onSelectionChange($event)\">\n        <mat-select-trigger fxLayout=\"row\" fxLayoutGap=\"5px\">\n            <span>{{active}}</span>\n            <fa-icon [icon]=\"faSort\"></fa-icon>\n        </mat-select-trigger>\n        <mat-option *ngFor=\"let option of selectOptions\" [value]=\"option\">\n            <span>{{option.field}} - {{option.order}}</span>\n        </mat-option>\n    </mat-select>\n</mat-form-field>\n", styles: ["mat-form-field{font-size:12px;padding:.4375em 0}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { options: [{
                type: Input
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * Tracks and emits changes to `SelectionModel`. Also provides convenience
 * method for enabling/disabling `ToolbarButton`s. Currently used by the
 * `PagedTable` to handle when the user selects one or more rows in the table
 * or clicks on the select all checkbox. It can be used anywhere select boxes
 * are used, but you will need to initialize the service and handle selection
 * changes manually if you want to use this anywhere else right now.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <div *ngFor="let thing of things">
 *     <mat-checkbox (click)="$event.stopPropagation()"
 *         (change)="onSelected(thing);"
 *         [checked]="selection.isSelected(thing)">
 *     </mat-checkbox>
 *     <span>{{{thing.name}}}</span>
 * </div>
 * ```
 * ```typescript
 * import {SelectionModel} from '@angular/cdk/collections';
 * import {Component} from '@angular/core';
 * import {SelectionService} from '@ngx-material-dashboard/widgets';
 *
 * @Component({
 *     selector: 'selection-example',
 *     templateUrl: './selection-example.html'
 * })
 * export class SelectionExample<T> {
 *
 *     selection: SelectionModel<T>;
 *     things: T[] = []; // assuming this is initialized and filled with data
 *
 *     constructor(private selectionService: SelectionService<T>) {
 *         this.selection = new SelectionModel<T>(true, []);
 *         this.selectionService.selectionSubject.next(this.selection);
 *     }
 *
 *     onSelected(val: T): void {
 *         this.selection.toggle(val);
 *         // update the selection in the selectionService
 *         this.selectionService.selectionSubject.next(this.selection);
 *     }
 * }
 * ```
 */
class SelectionService {
    constructor() {
        this.selectionSubject = new BehaviorSubject(new SelectionModel(true, []));
        this.selection = this.selectionSubject.asObservable();
        this.selectionChangeSubject = new BehaviorSubject(true);
        this.selectionChange = this.selectionChangeSubject.asObservable();
    }
    /**
     * Returns the current `SelectionModel` value.
     */
    get selectionValue() {
        return this.selectionSubject.value;
    }
    /**
     * Enables or disables the ToolbarButtons based on the given disabled boolean value. If the given
     * disabled value is false (meaning the buttons should be enabled), then an additional check is
     * required to disable any buttons if more than one row is selected and the ToolbarButton has a
     * multiSelectDisabled value of true. Currently only "Edit" buttons should be disabled if more than
     * one row is selected in the table since we don't want to handle modifying multiple data values at
     * once.
     *
     * @param disabled Set to true if the ToolbarButtons should be disabled.
     */
    toggleButtons(disabled, buttons) {
        buttons.forEach((button) => {
            this.toggleButton(button, disabled);
        });
    }
    toggleButton(button, disabled) {
        if (!disabled &&
            this.selectionValue.selected.length > 1 &&
            button.multiSelectDisabled) {
            // disable the ToolbarButton if more than one element is selected and the button does
            // not allow multiple selections (i.e. "Edit" buttons)
            button.disabled = true;
        }
        else {
            button.disabled = disabled;
            // if (!disabled && button.click === 'delete') {
            //     // if the buttons should be enabled and the current button is the delete button, then
            //     // the delete button should only be enabled if the rows selected in the table are
            //     // deletable; find all rows that cannot be deleted (rows that have deletable property and
            //     // deletable set to false)
            //     const nonDeletableRows = this.selectionValue.selected.filter(it => 'deletable' in it && !it.deletable);
            //     if (nonDeletableRows && nonDeletableRows.length > 0) {
            //         // disable button if there are rows that cannot be deleted in selection
            //         button.disabled = true;
            //     } else {
            //         // enable the delete button if all of the selected rows are deletable (i.e. there are no
            //         // non deletable rows)
            //         button.disabled = false;
            //     }
            // } else {
            //     // set the disabled property for the button based on the given disabled parameter
            //     button.disabled = disabled;
            // }
        }
    }
}
SelectionService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: SelectionService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
SelectionService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: SelectionService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: SelectionService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/*
mermaid.js inheritance graph
graph TD
    A[Collection]
    B[PagedCollection] -->|extends| A
    C[PagedCollectionWithToolbar] -->|extends| B
    D[PagedCollectionWithIconToolbar] -->|extends| C
    E[PagedCollectionWithRaisedButtonToolbar] -->|extends| C
*/
/**
 * The `Collection` defines the most basic properties needed to render a
 * collection. It is similar to the `MatTable` component, but designed to
 * work with any type of collection (i.e. grid, list, table). This works
 * with both local and remote data. This manages things like initialize
 * and connect/disconnect to/from the dataSource, along with tracking models
 * rendered in the collection based on changes to the state (i.e. sort
 * changes). Additionally it provides the ability to select one or more items
 * in the collection along with the ability to track the current selection, and
 * an output observable for parent components to be able to manage button click
 * events coming from buttons associated with each item in the collection.
 * NOTE: any sorting included should be of type `MatSort` or the `Sorter`
 * defined in the `toolbar` module for this library, which actually just
 * extends `MatSort`.
 *
 * @overviewDetails
 *
 * This component can be used for any type of collection, i.e. a grid, list,
 * or table (or any other type of collection I may not be thinking of right
 * now), however it does not provide any template. Generally speaking you
 * would use something like the `Grid`, `List`, or `Table` components defined
 * in their respective modules, which extend this component and provide
 * templates for rendering the appropriate collection type. The only time you
 * might utilize this component directly is if you use it to create your own
 * collection type component (if the existing `Grid`, `List`, or `Table` do not
 * provide the capabilities you need). If you do define your own collection, you
 * must define a template for it. You can find more details in the documentation
 * for the [Grid](/widgets/grid/overview), [List](/widgets/list/overview),
 * and [Table](/widgets/table/overview) at the included links.
 *
 * #### Features
 *
 * The `Collection` handles dataSource management, including connecting to the
 * data source, disconnecting when the component is destoryed, as well as
 * tracking and managing models rendered in the collection, and sorting. It
 * also tracks the selection of models (in addition to controlling whether more
 * than 1 model can be selected), and provides an easy output event for parent
 * components to handle when users click buttons assoicated with each model in
 * the collection.
 *
 * ##### DataSource Management
 *
 * While you may initialize your own dataSource and pass it in to the
 * `Collection`, you can also pass in an array which will be initialized as a
 * local data source. Either way the component manages the necessary code to
 * connect to the database and update the rendered models based on the latest
 * data to be rendered in the collection. It also includes code to disconnect
 * from the dataSource when the component is destroyed. As such, if you intend
 * to use your own dataSource, then it must extend the cdk collections
 * `Datasource` and implement connect and disconnect functions.
 *
 * ##### Sort
 *
 * The `sort$` property is defined as a `MatSort` or a custom `SorterComponent`
 * defined in the `Toolbar` module, which just extends `MatSort`. If you intend
 * to use your own sorter component, then it must extend `MatSort`. The `sort$`
 * property is treated as an internal value specifically for this component.
 * The `sort` getter is defined to be a more `public` facing property, and use
 * when initializing the sort for the dataSource.
 *
 * ##### Selection Model
 *
 * The component allows you to control whether you can select 1 or more models
 * in the collection using the `multiple` input property. This defaults to true
 * meaning the default behaviour is to allow more than 1 model to be selected
 * in the collection.
 *
 * ##### Collection Button Events
 *
 * The component includes a `buttonClick` output that you can use in your parent
 * components to listed for and handle click events for buttons in the
 * collection.
 */
class CollectionComponent {
    constructor(selectionService$) {
        this.selectionService$ = selectionService$;
        /** The buttons to render with each element in the collection. */
        this.collectionButtons = [];
        /**
         * Boolean to indicate whether SorterComponent associated with collection
         * should be included (defaults to false). If using a toolbar you probably
         * want to use the sorter there, so this is configurable to be turned off.
         */
        this.displaySorter = true;
        /** List of fields included in each element of list that can be sorted on. */
        this.fields = [];
        /** Any values that should be selected when collection initially renders. */
        this.initiallySelectedValues = [];
        /** The total number of elements in the collection. */
        this.length = 0;
        /** The models to display in collection. */
        this.models = [];
        /** Boolean value indicating whether multiple rows can be selected. */
        this.multiple$ = true;
        this.buttonClick = new EventEmitter();
        this.lengthChange = new EventEmitter();
        this.selection = new SelectionModel(this.multiple$, []);
        this.selectionService.selectionSubject.next(this.selection);
        this.sub = new Subscription();
    }
    /**
     * Setter for paged data. This re-initializes the dataSource everytime data changes.
     * @deprecated use dataSource instead
     */
    set data(data) {
        if (data) {
            this.initDataSource(data);
        }
    }
    /**
     * Setter for the dataSource on the component. Initializes the models to
     * render in the collection based on the latest data defined from the
     * dataSource. TODO: only re-initialize when necessary; just update data otherwise
     */
    set dataSource(dataSource) {
        if (dataSource) {
            this.initDataSource(dataSource);
        }
    }
    /** Boolean value to indicate whether multiple rows can be selected (defaults to true i.e. multiple can be selected). */
    set multiple(multiple) {
        this.multiple$ = multiple;
        this.selection = new SelectionModel(multiple, this.initiallySelectedValues);
        this.selectionService.selectionSubject.next(this.selection);
    }
    /**
     * Returns the selection service that tracks and emits changes to the
     * selection model.
     */
    get selectionService() {
        return this.selectionService$;
    }
    /**
     * Returns the sorter for the component if it exists.
     */
    get sort() {
        return this.sort$;
    }
    /**
     * Initializes the sort for the component after the view is initialized.
     */
    ngAfterViewInit() {
        this.initSort();
    }
    /**
     * Destroy all subscriptions in the component.
     */
    ngOnDestroy() {
        this.sub.unsubscribe();
        this.dataSource$.disconnect();
    }
    /**
     * Initializes the data source bsaed on the type of data/source given, and
     * any additional properties required (i.e. sorting).
     *
     * @param data Either an array (local data), MatTableDataSource, or RemoteDataSource.
     */
    initDataSource(dataSource) {
        // initialize the dataSource
        if (dataSource instanceof RemoteDataSource) {
            this.dataSource$ = dataSource;
        }
        else {
            if (dataSource instanceof MatTableDataSource) {
                this.dataSource$ = dataSource;
            }
            else {
                this.dataSource$ = new MatTableDataSource(dataSource);
            }
        }
        // subscribe to connect observable to get filtered, paged, sorted
        // data; see below github issue comment
        // https://github.com/angular/components/issues/9419#issuecomment-359594686
        const sub = this.dataSource$.connect().subscribe((res) => {
            // set the models to render in the collection
            this.models = res;
            // TODO figure out why needed to make karma tests pass due to
            // expressionchangedafter... but seems to work fine when running
            // component in app without this
            //this.changeDetectorRef.markForCheck() //.detectChanges();
            // set the total length of the dataSource and emit lengthChange
            // event so parent components can update accordingly
            if (this.dataSource$ instanceof RemoteDataSource) {
                this.length = this.dataSource$.total;
            }
            else {
                this.length = this.dataSource$.data.length;
            }
            this.lengthChange.emit(this.length);
        });
        this.sub.add(sub);
        // re-initialize the sort on the dataSource
        this.initSort();
    }
    /**
     * Initializes subscription for when user changes the sort order for data
     * in the collection.
     */
    initSort() {
        if (this.dataSource$ && this.sort) {
            this.dataSource$.sort = this.sort;
        }
    }
    /**
     * Returns true if all visible elements in the collection are selected;
     * otherwise returns false.
     *
     * @returns true if all visible elements in the collection are selected.
     */
    isAllSelected() {
        if (this.dataSource$.data.length === 0) {
            return false;
        }
        else {
            return (this.selection.selected.length === this.dataSource$.data.length);
        }
    }
    /**
     * Handler for checkbox in collection header. Clears all selections if all
     * visible elements in the collection are selected; otherwise selects all
     * visible elements in the collection.
     */
    masterToggle() {
        if (this.isAllSelected() || !this.multiple$) {
            // clear all selections and disable ToolbarButtons
            this.selection.clear();
            this.selectionService.selectionChangeSubject.next(true);
        }
        else {
            // select all rows in the table and enable ToolbarButtons
            this.dataSource$.data.forEach((row) => this.selection.select(row));
            if (this.dataSource$.data.length > 0) {
                // only enable ToolbarButtons if there is data in table
                this.selectionService.selectionChangeSubject.next(false);
            }
        }
        // update the selection in the selectionService
        this.selectionService.selectionSubject.next(this.selection);
    }
    /**
     * Handler for when the user clicks a button next to an element in the
     * collection.
     *
     * @param click The action that was clicked (i.e. 'edit', 'delete', etc).
     * @param row The row/element where the button was clicked.
     */
    onActionButtonClick(click, row) {
        this.buttonClick.emit({ click: click, row: row });
    }
    /**
     * Handler for checkbox in collection. Toggles the selection for the given
     * element and updates the ToolbarButtons accordingly.
     *
     * @param row The element that was (de)selected in the collection.
     */
    onRowSelected(row) {
        if (!this.multiple$ && this.selection.selected.length > 0) {
            // if table does not allow multiple selections and there are any
            // existing rows selected, then clear selection before making new
            // one
            this.selection.clear();
        }
        this.selection.toggle(row);
        // disable the buttons if no rows are selected; otherwise enable them
        this.selectionService.selectionChangeSubject.next(this.selection.selected.length === 0);
        // update the selection in the selectionService
        this.selectionService.selectionSubject.next(this.selection);
    }
}
CollectionComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: CollectionComponent, deps: [{ token: SelectionService }], target: i0.ɵɵFactoryTarget.Component });
CollectionComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: CollectionComponent, selector: "ng-component", inputs: { collectionButtons: "collectionButtons", data: "data", dataSource: "dataSource", displaySorter: "displaySorter", fields: "fields", initiallySelectedValues: "initiallySelectedValues", multiple: "multiple" }, outputs: { buttonClick: "buttonClick", lengthChange: "lengthChange" }, queries: [{ propertyName: "template", first: true, predicate: ["model"], descendants: true }], viewQueries: [{ propertyName: "sort$", first: true, predicate: SorterComponent, descendants: true }], ngImport: i0, template: '', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: CollectionComponent, decorators: [{
            type: Component,
            args: [{
                    template: '',
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: SelectionService }]; }, propDecorators: { template: [{
                type: ContentChild,
                args: ['model', { static: false }]
            }], collectionButtons: [{
                type: Input
            }], data: [{
                type: Input
            }], dataSource: [{
                type: Input
            }], displaySorter: [{
                type: Input
            }], fields: [{
                type: Input
            }], initiallySelectedValues: [{
                type: Input
            }], multiple: [{
                type: Input
            }], buttonClick: [{
                type: Output
            }], lengthChange: [{
                type: Output
            }], sort$: [{
                type: ViewChild,
                args: [SorterComponent]
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `PagedCollection` is a wrapper component for the `Collection` which adds
 * paging capabilities. This component expects a `Collection` to be defined as
 * a child in the template. Any paginator used should be of type `MatPaginator`.
 *
 * @overviewDetails
 *
 * Like the `Collection`, this component does not provide a template, and
 * the intention is for you to use things like the `PagedGrid`, `PagedList`,
 * or `PagedTable` instead of using this component directly. The only time you
 * might utilize this component directly is if you use it to create your own
 * paged collection type component (if the existing `PagedGrid`, `PagedList`,
 * or `PagedTable` do not provide the capabilities you need). If you do define
 * your own paged collection, you must define a template for it. You can find
 * more details in the documentation for the
 * [PagedGrid](/widgets/grid/overview#paged-grid-component),
 * [PagedList](/widgets/list/overview#paged-list-component),
 * and [PagedTable](/widgets/table/overview#paged-table-component) at the included links.
 *
 * #### Features
 *
 * The `PagedCollection` provides paging capabilities for collections.
 *
 * ##### Paginator
 *
 * The `paginator$` is a ViewChild property defined for the `PagedCollection`,
 * and is treated as an internal value specifically for this component. The
 * `paginator` getter is defined to be a more `public` facing property, and used
 * when initializing the paginator for the dataSource. If you create your own
 * paged collection by extending this component, all you need to do for the
 * paginator to work is add a `MatPaginator` to the template. If you use
 * something other than a `MatPaginator` or a ViewChild (i.e. ContentChild),
 * then you can override the `paginator` getter to return the type of paginator
 * you use in your component. *NOTE: whatever paginator you do use must extend
 * `MatPaginator` in order to work with the dataSource.
 */
class PagedCollectionComponent {
    constructor() {
        /** The buttons to render with each item in collection. */
        this.collectionButtons = [];
        /** List of fields included in each element of collection that can be sorted on. */
        this.fields = [];
        /**
         * The max number of pages to display in the paginator. Defaults to 10
         * (does not include 'First', 'Prev', 'Next', 'Last').
         */
        this.maxPages = 10;
        /** Boolean value to indicate whether multiple rows can be selected. */
        this.multiple = true;
        /** Number of items to display on a page. Defaults to 25. */
        this.pageSize = 25;
        /** The total number of elements in the collection. */
        this.length = 0;
        this.buttonClick = new EventEmitter();
        this.sub = new Subscription();
    }
    /** The dataSource for the collection. */
    set dataSource(val) {
        this.dataSource$ = val;
    }
    // eslint-disable-next-line @typescript-eslint/adjacent-overload-signatures
    get dataSource() {
        return this.dataSource$;
    }
    /**
     * Returns the paginator for the component if it exists.
     */
    get paginator() {
        if (this.paginator$) {
            return this.paginator$;
        }
        else {
            return null;
        }
    }
    ngAfterViewInit() {
        this.initPaginator();
        const sub = this.collection$.lengthChange.subscribe((length) => {
            this.length = length;
        });
        this.sub.add(sub);
    }
    ngOnDestroy() {
        this.sub.unsubscribe();
    }
    /**
     * Initializes subscription for when user changes page or page size. Works
     * for both local and remote data.
     */
    initPaginator() {
        if (this.collection$.dataSource$) {
            this.collection$.dataSource$.paginator = this.paginator;
        }
    }
    /**
     * Handler for when the user clicks a button associated with an item in the
     * collection.
     *
     * @param buttonClick The value emitted from the collection.
     */
    onButtonClick(buttonClick) {
        this.buttonClick.emit(buttonClick);
    }
}
PagedCollectionComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedCollectionComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
PagedCollectionComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: PagedCollectionComponent, selector: "ng-component", inputs: { collectionButtons: "collectionButtons", dataSource: "dataSource", fields: "fields", maxPages: "maxPages", multiple: "multiple", pageSize: "pageSize" }, outputs: { buttonClick: "buttonClick" }, queries: [{ propertyName: "template", first: true, predicate: ["model"], descendants: true }], viewQueries: [{ propertyName: "paginator$", first: true, predicate: MatPaginator, descendants: true }, { propertyName: "collection$", first: true, predicate: ["collection"], descendants: true }], ngImport: i0, template: '', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedCollectionComponent, decorators: [{
            type: Component,
            args: [{
                    template: '',
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { template: [{
                type: ContentChild,
                args: ['model', { static: false }]
            }], collectionButtons: [{
                type: Input
            }], dataSource: [{
                type: Input
            }], fields: [{
                type: Input
            }], maxPages: [{
                type: Input
            }], multiple: [{
                type: Input
            }], pageSize: [{
                type: Input
            }], buttonClick: [{
                type: Output
            }], paginator$: [{
                type: ViewChild,
                args: [MatPaginator]
            }], collection$: [{
                type: ViewChild,
                args: ['collection']
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
class IconButtonsComponent {
    constructor() {
        /** The management buttons to display in the toolbar. */
        this.buttons = [];
        this.buttonClick = new EventEmitter();
        this.sub = new Subscription();
    }
    /**
     * Destroys any subscriptions for the component.
     */
    ngOnDestroy() {
        this.sub.unsubscribe();
    }
    /**
     * Initialize the main subscriptions object for the component.
     */
    ngOnInit() {
        this.sub = new Subscription();
    }
    /**
     * Emits a buttonClick event to the parent.
     *
     * @param buttonClick The action from the button that was clicked by the user.
     */
    emitButtonClick(buttonClick) {
        this.buttonClick.emit({ click: buttonClick });
    }
}
IconButtonsComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: IconButtonsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
IconButtonsComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: IconButtonsComponent, selector: "ngx-mat-icon-buttons", inputs: { buttons: "buttons" }, outputs: { buttonClick: "buttonClick" }, ngImport: i0, template: "<div fxLayout=\"row\" class=\"marker-icon-buttons-bar\">\n    <div *ngFor=\"let button of buttons\">\n        <button *ngIf=\"button.click; else hyperlink\"\n            class=\"mat-button marker-button-{{button.click}}\"\n            (click)=\"emitButtonClick(button.click)\"\n            [disabled]=\"button.disabled\"\n            [matTooltip]=\"button.text\"\n            mat-icon-button>\n            <div *ngIf=\"button.icon && !button.stackedIcon; else stackedIcon\">\n                <fa-icon [icon]=\"button.icon\"></fa-icon>\n            </div>\n            <ng-template #stackedIcon>\n                <fa-layers *ngIf=\"button.icon && button.stackedIcon\" [fixedWidth]=\"true\">\n                    <fa-icon [icon]=\"button.icon\"></fa-icon>\n                    <fa-icon [icon]=\"button.stackedIcon\" [styles]=\"button.stackedIconStyles\"></fa-icon>\n                </fa-layers>\n            </ng-template>\n        </button>\n        <ng-template #hyperlink>\n            <a class=\"mat-button marker-button-{{button.click}}\"\n                [attr.disabled]=\"button.disabled\"\n                [href]=\"button.href\"\n                [matTooltip]=\"button.text\"\n                target=\"_blank\"\n                mat-icon-button>\n                <div *ngIf=\"button.icon && !button.stackedIcon; else stackedIcon\">\n                    <fa-icon [icon]=\"button.icon\"></fa-icon>\n                </div>\n                <ng-template #stackedIcon>\n                    <fa-layers *ngIf=\"button.icon && button.stackedIcon\" [fixedWidth]=\"true\">\n                        <fa-icon [icon]=\"button.icon\"></fa-icon>\n                        <fa-icon [icon]=\"button.stackedIcon\" [styles]=\"button.stackedIconStyles\"></fa-icon>\n                    </fa-layers>\n                </ng-template>\n            </a>\n        </ng-template>\n    </div>\n</div>\n", styles: [""], components: [{ type: i1$2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i2.FaIconComponent, selector: "fa-icon", inputs: ["icon", "title", "spin", "pulse", "mask", "styles", "flip", "size", "pull", "border", "inverse", "symbol", "rotate", "fixedWidth", "classes", "transform", "a11yRole"] }, { type: i2.FaLayersComponent, selector: "fa-layers", inputs: ["size", "fixedWidth"] }, { type: i1$2.MatAnchor, selector: "a[mat-button], a[mat-raised-button], a[mat-icon-button], a[mat-fab],             a[mat-mini-fab], a[mat-stroked-button], a[mat-flat-button]", inputs: ["disabled", "disableRipple", "color", "tabIndex"], exportAs: ["matButton", "matAnchor"] }], directives: [{ type: i5.DefaultLayoutDirective, selector: "  [fxLayout], [fxLayout.xs], [fxLayout.sm], [fxLayout.md],  [fxLayout.lg], [fxLayout.xl], [fxLayout.lt-sm], [fxLayout.lt-md],  [fxLayout.lt-lg], [fxLayout.lt-xl], [fxLayout.gt-xs], [fxLayout.gt-sm],  [fxLayout.gt-md], [fxLayout.gt-lg]", inputs: ["fxLayout", "fxLayout.xs", "fxLayout.sm", "fxLayout.md", "fxLayout.lg", "fxLayout.xl", "fxLayout.lt-sm", "fxLayout.lt-md", "fxLayout.lt-lg", "fxLayout.lt-xl", "fxLayout.gt-xs", "fxLayout.gt-sm", "fxLayout.gt-md", "fxLayout.gt-lg"] }, { type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i5$1.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: IconButtonsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-icon-buttons', template: "<div fxLayout=\"row\" class=\"marker-icon-buttons-bar\">\n    <div *ngFor=\"let button of buttons\">\n        <button *ngIf=\"button.click; else hyperlink\"\n            class=\"mat-button marker-button-{{button.click}}\"\n            (click)=\"emitButtonClick(button.click)\"\n            [disabled]=\"button.disabled\"\n            [matTooltip]=\"button.text\"\n            mat-icon-button>\n            <div *ngIf=\"button.icon && !button.stackedIcon; else stackedIcon\">\n                <fa-icon [icon]=\"button.icon\"></fa-icon>\n            </div>\n            <ng-template #stackedIcon>\n                <fa-layers *ngIf=\"button.icon && button.stackedIcon\" [fixedWidth]=\"true\">\n                    <fa-icon [icon]=\"button.icon\"></fa-icon>\n                    <fa-icon [icon]=\"button.stackedIcon\" [styles]=\"button.stackedIconStyles\"></fa-icon>\n                </fa-layers>\n            </ng-template>\n        </button>\n        <ng-template #hyperlink>\n            <a class=\"mat-button marker-button-{{button.click}}\"\n                [attr.disabled]=\"button.disabled\"\n                [href]=\"button.href\"\n                [matTooltip]=\"button.text\"\n                target=\"_blank\"\n                mat-icon-button>\n                <div *ngIf=\"button.icon && !button.stackedIcon; else stackedIcon\">\n                    <fa-icon [icon]=\"button.icon\"></fa-icon>\n                </div>\n                <ng-template #stackedIcon>\n                    <fa-layers *ngIf=\"button.icon && button.stackedIcon\" [fixedWidth]=\"true\">\n                        <fa-icon [icon]=\"button.icon\"></fa-icon>\n                        <fa-icon [icon]=\"button.stackedIcon\" [styles]=\"button.stackedIconStyles\"></fa-icon>\n                    </fa-layers>\n                </ng-template>\n            </a>\n        </ng-template>\n    </div>\n</div>\n", styles: [""] }]
        }], ctorParameters: function () { return []; }, propDecorators: { buttons: [{
                type: Input
            }], buttonClick: [{
                type: Output
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A toolbar that renders `mat-icon-button`s and a paginator with optional
 * select checkbox and sorting capability. It is designed to be rendered above
 * paged collections since the paginator is automatically included on the right
 * side of the toolbar. Unlike the `RaisedButtonToolbar you cannot control the
 * button alignment; buttons are aligned left, after the optional select
 * checkbox, and the paginator is aligned to the right side of the page, after
 * the optional `Sorter`.
 *
 * #### Features
 *
 * You may optional exclude a select checkbox and `Sorter`. These default to
 * automatically be included. Simply set the corresponding `display` input
 * value to `false` if you want to exclude either feature.
 *
 * ##### Optional Select Checkbox
 *
 * The optional select checkbox is meant to act as a master toggle for
 * collections, similar to the master toggle rendered in the header row above
 * a table with select option. See the material
 * [docs](https://material.angular.io/components/table/examples#table-selection)
 * for what I'm talking about. If included it is the first thing rendered in
 * the toolbar so it can line up with collection content rendered as a list. If
 * you use the PagedListWithRaisedButtonToolbar, you should see the checkbox
 * line up with the checkbox rendered for each row in the list (just like it is
 * in the table with select). This was made optional so this toolbar can be used
 * above the `PagedTable` that already includes the master toggle select in the
 * header row (there is no reason to include multiple master toggles).
 *
 * To handle when the user (de)selects the checkbox you can use the
 * `masterToggle` output event emitter in the parent component.
 *
 * ##### Sorter
 *
 * The optional `Sorter` is rendered before the `MatPaginator` and is meant
 * to sort contents of the collection. Like the masterToggle, this is optional
 * so this toolbar can be used above the `PagedTable`, which already includes
 * sorting in the header row.
 */
class IconButtonsWithPaginatorComponent {
    constructor() {
        /** The management buttons to display in the toolbar. */
        this.buttons = [];
        /** Boolean to indicate whether to render the select all checkbox. */
        this.displaySelectAll = true;
        /** Boolean to indicate whether to render the sort drop down. */
        this.displaySort = true;
        /** The fields to render in the sort drop down. */
        this.fields = [];
        /** Boolean to indicate whether all items are selected. */
        this.isAllSelected = false;
        /** The total number of items in the collection. */
        this.length = 0;
        /** Boolean to indicate whether multiple items can be selected. */
        this.multiple = true;
        /** The number of items to render in the page. */
        this.pageSize = 25;
        /** The model to track items selected in the table. */
        this.selection = new SelectionModel(this.multiple, []);
        this.buttonClick = new EventEmitter();
        this.masterToggle = new EventEmitter();
        this.sub = new Subscription();
    }
    /**
     * Emits a buttonClick event to the parent.
     *
     * @param buttonClick The action from the button that was clicked by the user.
     */
    emitButtonClick(buttonClick) {
        this.buttonClick.emit(buttonClick);
    }
    /**
     * Emits a masterToggle event to the parent with the latest value for the
     * master toggle checkbox.
     *
     * @param check The checkbox change event.
     */
    emitMasterToggle(check) {
        this.masterToggle.emit(check.checked);
    }
}
IconButtonsWithPaginatorComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: IconButtonsWithPaginatorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
IconButtonsWithPaginatorComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: IconButtonsWithPaginatorComponent, selector: "ngx-mat-icon-buttons-with-paginator", inputs: { buttons: "buttons", displaySelectAll: "displaySelectAll", displaySort: "displaySort", fields: "fields", isAllSelected: "isAllSelected", length: "length", multiple: "multiple", pageSize: "pageSize", selection: "selection" }, outputs: { buttonClick: "buttonClick", masterToggle: "masterToggle" }, viewQueries: [{ propertyName: "paginator", first: true, predicate: MatPaginator, descendants: true }, { propertyName: "sort", first: true, predicate: SorterComponent, descendants: true }], ngImport: i0, template: "<div fxLayout=\"row\" class=\"marker-collection-toolbar\">\n    <div fxLayoutAlign=\"center center\">\n        <mat-checkbox *ngIf=\"displaySelectAll\"\n            class=\"marker-checkbox-select-all\"\n            (change)=\"emitMasterToggle($event)\"\n            [checked]=\"selection.hasValue() && isAllSelected\"\n            [indeterminate]=\"selection.hasValue() && !isAllSelected\">\n        </mat-checkbox>\n        <ngx-mat-icon-buttons [buttons]=\"buttons\"\n            (buttonClick)=\"emitButtonClick($event)\"></ngx-mat-icon-buttons>\n    </div>\n    <div fxFlex></div>\n    <ngx-mat-sorter *ngIf=\"displaySort\" [options]=\"fields\"></ngx-mat-sorter>\n    <mat-paginator [length]=\"length\"\n        [pageSize]=\"pageSize\"\n        [pageSizeOptions]=\"[15, 25, 50, 75, 100]\"\n        #paginator>\n    </mat-paginator>\n</div>\n", styles: [""], components: [{ type: i1$3.MatCheckbox, selector: "mat-checkbox", inputs: ["disableRipple", "color", "tabIndex", "aria-label", "aria-labelledby", "aria-describedby", "id", "required", "labelPosition", "name", "value", "checked", "disabled", "indeterminate"], outputs: ["change", "indeterminateChange"], exportAs: ["matCheckbox"] }, { type: IconButtonsComponent, selector: "ngx-mat-icon-buttons", inputs: ["buttons"], outputs: ["buttonClick"] }, { type: SorterComponent, selector: "ngx-mat-sorter", inputs: ["options"] }, { type: i2$3.MatPaginator, selector: "mat-paginator", inputs: ["disabled"], exportAs: ["matPaginator"] }], directives: [{ type: i5.DefaultLayoutDirective, selector: "  [fxLayout], [fxLayout.xs], [fxLayout.sm], [fxLayout.md],  [fxLayout.lg], [fxLayout.xl], [fxLayout.lt-sm], [fxLayout.lt-md],  [fxLayout.lt-lg], [fxLayout.lt-xl], [fxLayout.gt-xs], [fxLayout.gt-sm],  [fxLayout.gt-md], [fxLayout.gt-lg]", inputs: ["fxLayout", "fxLayout.xs", "fxLayout.sm", "fxLayout.md", "fxLayout.lg", "fxLayout.xl", "fxLayout.lt-sm", "fxLayout.lt-md", "fxLayout.lt-lg", "fxLayout.lt-xl", "fxLayout.gt-xs", "fxLayout.gt-sm", "fxLayout.gt-md", "fxLayout.gt-lg"] }, { type: i5.DefaultLayoutAlignDirective, selector: "  [fxLayoutAlign], [fxLayoutAlign.xs], [fxLayoutAlign.sm], [fxLayoutAlign.md],  [fxLayoutAlign.lg], [fxLayoutAlign.xl], [fxLayoutAlign.lt-sm], [fxLayoutAlign.lt-md],  [fxLayoutAlign.lt-lg], [fxLayoutAlign.lt-xl], [fxLayoutAlign.gt-xs], [fxLayoutAlign.gt-sm],  [fxLayoutAlign.gt-md], [fxLayoutAlign.gt-lg]", inputs: ["fxLayoutAlign", "fxLayoutAlign.xs", "fxLayoutAlign.sm", "fxLayoutAlign.md", "fxLayoutAlign.lg", "fxLayoutAlign.xl", "fxLayoutAlign.lt-sm", "fxLayoutAlign.lt-md", "fxLayoutAlign.lt-lg", "fxLayoutAlign.lt-xl", "fxLayoutAlign.gt-xs", "fxLayoutAlign.gt-sm", "fxLayoutAlign.gt-md", "fxLayoutAlign.gt-lg"] }, { type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i5.DefaultFlexDirective, selector: "  [fxFlex], [fxFlex.xs], [fxFlex.sm], [fxFlex.md],  [fxFlex.lg], [fxFlex.xl], [fxFlex.lt-sm], [fxFlex.lt-md],  [fxFlex.lt-lg], [fxFlex.lt-xl], [fxFlex.gt-xs], [fxFlex.gt-sm],  [fxFlex.gt-md], [fxFlex.gt-lg]", inputs: ["fxFlex", "fxFlex.xs", "fxFlex.sm", "fxFlex.md", "fxFlex.lg", "fxFlex.xl", "fxFlex.lt-sm", "fxFlex.lt-md", "fxFlex.lt-lg", "fxFlex.lt-xl", "fxFlex.gt-xs", "fxFlex.gt-sm", "fxFlex.gt-md", "fxFlex.gt-lg"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: IconButtonsWithPaginatorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-icon-buttons-with-paginator', template: "<div fxLayout=\"row\" class=\"marker-collection-toolbar\">\n    <div fxLayoutAlign=\"center center\">\n        <mat-checkbox *ngIf=\"displaySelectAll\"\n            class=\"marker-checkbox-select-all\"\n            (change)=\"emitMasterToggle($event)\"\n            [checked]=\"selection.hasValue() && isAllSelected\"\n            [indeterminate]=\"selection.hasValue() && !isAllSelected\">\n        </mat-checkbox>\n        <ngx-mat-icon-buttons [buttons]=\"buttons\"\n            (buttonClick)=\"emitButtonClick($event)\"></ngx-mat-icon-buttons>\n    </div>\n    <div fxFlex></div>\n    <ngx-mat-sorter *ngIf=\"displaySort\" [options]=\"fields\"></ngx-mat-sorter>\n    <mat-paginator [length]=\"length\"\n        [pageSize]=\"pageSize\"\n        [pageSizeOptions]=\"[15, 25, 50, 75, 100]\"\n        #paginator>\n    </mat-paginator>\n</div>\n", styles: [""] }]
        }], ctorParameters: function () { return []; }, propDecorators: { buttons: [{
                type: Input
            }], displaySelectAll: [{
                type: Input
            }], displaySort: [{
                type: Input
            }], fields: [{
                type: Input
            }], isAllSelected: [{
                type: Input
            }], length: [{
                type: Input
            }], multiple: [{
                type: Input
            }], pageSize: [{
                type: Input
            }], selection: [{
                type: Input
            }], buttonClick: [{
                type: Output
            }], masterToggle: [{
                type: Output
            }], paginator: [{
                type: ViewChild,
                args: [MatPaginator]
            }], sort: [{
                type: ViewChild,
                args: [SorterComponent]
            }] } });

/**
 * The `PagedCollectionWithToolbar` expands upon the capabilities of the
 * `Collection` and `PagedCollection` by providing features that a collection
 * should have when associated with a toolbar used to manage data in the
 * collection. It is a wrapper for a `PagedCollection` and one of the toolbars
 * defined in the `toolbar` module. This component acts as a base component
 * for paged collections with toolbars, defining properties and functions
 * needed for those components without defining the type of toolbar used in the
 * component. As such this component is not meant to be used directly. Instead
 * you should use the `PagedCollectionWithIconBar` or
 * `PagedCollectionWithRaisedButtonBar` component, which define the type of
 * toolbar expected to be used in the template (either the
 * `IconButtonWithPaginator` or the `RaisedButtonToolbar` respectively).
 *
 * @overviewDetails
 * #### Features
 *
 * A toolbar associated with a paged collection may have buttons that are
 * enabled/disabled based on selections in the collection. As such this
 * component provides built in capabilities to enable/disable those buttons
 * based on configuration parameters provided for the toolbar buttons. See
 * documentation for the `ToolbarButton` interface for more details:
 * [ToolbarButton](/widgets/toolbar/overview#toolbar-button).
 *
 * Additionally, the component utilizes the `buttonClick` output event emitter
 * for emitting button click events from buttons in the toolbar. This way
 * parent components only need to use the `buttonClick` output to handle button
 * click events in either the toolbar or the collection itself. This seemed to
 * be the best solution (for now at least; as opposed to having a separate
 * emitter for toolbar events), as you may have the same or similar handlers
 * for toolbar and collection button events.
 */
class PagedCollectionWithToolbarComponent {
    constructor(changeDetectorRef) {
        this.changeDetectorRef = changeDetectorRef;
        /** Boolean to indicate whether sorter should render in header. */
        this.displaySorterInToolbar = false;
        /** List of fields included in each element of collection that can be sorted on. */
        this.fields = [];
        /** Boolean value to indicate whether multiple rows can be selected. */
        this.multiple = true;
        this.pageSize = 25;
        /** The buttons to render in the toolbar. */
        this.toolbarButtons = [];
        /**
         * These are the buttons in the toolbar that can be disabled. Just a filtered
         * subset of toolbarButtons that have canDisable=true.
         */
        this.disableableToolbarButtons = [];
        /** The total number of elements in the collection. */
        this.length = 0;
        this.buttonClick = new EventEmitter();
        this.sub = new Subscription();
    }
    /**
     * Returns the paginator for the component, whether it resides in paged
     * collection, or in the toolbar.
     */
    get paginator() {
        if (this.toolbar instanceof IconButtonsWithPaginatorComponent) {
            //  paginator should be in toolbar if toolbar is IconButtonsWithPaginator
            return this.toolbar.paginator;
        }
        else {
            return undefined;
        }
    }
    /**
     * Returns the sort for the component.
     */
    get sort() {
        if (this.toolbar instanceof IconButtonsWithPaginatorComponent) {
            // sort should be in toolbar if toolbar is IconButtonsWithPaginator
            return this.toolbar.sort;
        }
        else {
            return undefined;
        }
    }
    ngAfterViewInit() {
        if (this.collectionCmp instanceof CollectionComponent) {
            this.collectionCmp.dataSource$.paginator = this.paginator;
            const sub = this.collectionCmp.lengthChange.subscribe((length) => {
                this.length = length;
                this.changeDetectorRef.detectChanges();
            });
            this.sub.add(sub);
        }
        // get buttons that can be disabled from given list of buttons
        this.disableableToolbarButtons = this.toolbarButtons.filter((button) => button.canDisable);
        this.sub = new Subscription();
        let selectionService;
        if (this.collectionCmp instanceof CollectionComponent) {
            selectionService = this.collectionCmp.selectionService;
        }
        else {
            selectionService = this.collectionCmp.collection$.selectionService;
        }
        const sub = selectionService.selectionChange.subscribe((disabled) => {
            selectionService.toggleButtons(disabled, this.disableableToolbarButtons);
            this.changeDetectorRef.detectChanges();
        });
        this.sub.add(sub);
    }
    ngOnDestroy() {
        this.sub.unsubscribe();
    }
    /**
     * Adds current collection selection to given buttonClick and emits event
     * to parent. TODO handle multiple selections
     *
     * @param buttonClick A buttonClick event from the tableToolbar.
     */
    onToolbarButtonClick(buttonClick) {
        let selection;
        if (this.collectionCmp instanceof CollectionComponent) {
            selection = this.collectionCmp.selection;
        }
        else {
            selection = this.collectionCmp.collection$.selection;
        }
        if (!selection.isEmpty()) {
            // make sure selection is not empty before adding selected row(s)
            buttonClick.row = selection.selected[0];
        }
        this.buttonClick.emit(buttonClick);
    }
}
PagedCollectionWithToolbarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedCollectionWithToolbarComponent, deps: [{ token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
PagedCollectionWithToolbarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: PagedCollectionWithToolbarComponent, selector: "ng-component", inputs: { displaySorterInToolbar: "displaySorterInToolbar", fields: "fields", multiple: "multiple", pageSize: "pageSize", toolbarButtons: "toolbarButtons" }, outputs: { buttonClick: "buttonClick" }, queries: [{ propertyName: "collectionCmp", first: true, predicate: ["collection"], descendants: true }], viewQueries: [{ propertyName: "toolbar", first: true, predicate: ["toolbar"], descendants: true }], ngImport: i0, template: '', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedCollectionWithToolbarComponent, decorators: [{
            type: Component,
            args: [{
                    template: '',
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }]; }, propDecorators: { collectionCmp: [{
                type: ContentChild,
                args: ['collection']
            }], displaySorterInToolbar: [{
                type: Input
            }], fields: [{
                type: Input
            }], multiple: [{
                type: Input
            }], pageSize: [{
                type: Input
            }], toolbarButtons: [{
                type: Input
            }], buttonClick: [{
                type: Output
            }], toolbar: [{
                type: ViewChild,
                args: ['toolbar']
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `PagedCollectionWithIconToolbar` extends the
 * `PagedCollectionWithToolbar`. This component does not add new capabilities,
 * but defines the type of toolbar expected to be used with the collection,
 * which is the `IconButtonsWithPaginator`. It requires the collection in the
 * template to be of type `Collection` since paging is rendered and managed
 * from the toolbar. See the documentation for the `IconButtonsWithPaginator`
 * for more details
 * [here](/widgets/toolbar/overview#icon-buttons-with-paginator-component).
 */
class PagedCollectionWithIconToolbarComponent extends PagedCollectionWithToolbarComponent {
}
PagedCollectionWithIconToolbarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedCollectionWithIconToolbarComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
PagedCollectionWithIconToolbarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: PagedCollectionWithIconToolbarComponent, selector: "ng-component", queries: [{ propertyName: "collectionCmp", first: true, predicate: ["collection"], descendants: true }], viewQueries: [{ propertyName: "toolbar", first: true, predicate: IconButtonsWithPaginatorComponent, descendants: true }], usesInheritance: true, ngImport: i0, template: '', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedCollectionWithIconToolbarComponent, decorators: [{
            type: Component,
            args: [{
                    template: '',
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], propDecorators: { collectionCmp: [{
                type: ContentChild,
                args: ['collection']
            }], toolbar: [{
                type: ViewChild,
                args: [IconButtonsWithPaginatorComponent]
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A simple directive to stop a `click` event from propagating. This is mainly
 * being used in the `FilterDropDown` to prevent the drop down from closing
 * when the user clicks in the form defined for the drop down, but it can be
 * used anywhere you want to prevent `click` events from propagating to parent
 * elements.
 *
 * @overviewDetails
 * #### Basic Usage Example
 * ```html
 * <div [matMenuTriggerFor]="filterMenu">
 *     <span>Drop Down</span>
 * </div>
 * <mat-menu #filterMenu="matMenu">
 *     <form ngxMatClickStopPropagation>
 *         <!-- form fields go here -->
 *     </form>
 * </mat-menu>
 * ```
 */
class ClickStopPropagationDirective {
    /**
     * Calls the `stopPropagation` function on the given event.
     *
     * @param event A `click` event.
     */
    onClick(event) {
        event.stopPropagation();
    }
}
ClickStopPropagationDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ClickStopPropagationDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
ClickStopPropagationDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.12", type: ClickStopPropagationDirective, selector: "[ngxMatClickStopPropagation]", host: { listeners: { "click": "onClick($event)" } }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ClickStopPropagationDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngxMatClickStopPropagation]'
                }]
        }], propDecorators: { onClick: [{
                type: HostListener,
                args: ['click', ['$event']]
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A simple directive to stop the `tab` `keydown` event from propagating. This
 * is mainly used in the `FilterDropDown` to prevent the drop down from closing
 * when the user clicks the `tab` key to navigate from one input to the next,
 * but it can be used anywhere you want to prevent the `tab` `keydown` event
 * from propagating to parent elements.
 *
 * @overviewDetails
 * #### Basic Usage Example
 * ```typescript
 * <div [matMenuTriggerFor]="menu">
 *     <span>Drop Down</span>
 * </div>
 * <mat-menu #filterMenu="matMenu">
 *     <form ngxMatTabStopPropagation>
 *         <!-- form fields go here -->
 *     </form>
 * </div>
 * ```
 */
class TabStopPropagationDirective {
    /**
     * Calls the `stopPropagation` function on the given event.
     *
     * @param event A `keydown.tab` event.
     */
    onKeyDown(event) {
        event.stopPropagation();
    }
}
TabStopPropagationDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: TabStopPropagationDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
TabStopPropagationDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.12", type: TabStopPropagationDirective, selector: "[ngxMatTabStopPropagation]", host: { listeners: { "keydown.tab": "onKeyDown($event)" } }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: TabStopPropagationDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngxMatTabStopPropagation]'
                }]
        }], propDecorators: { onKeyDown: [{
                type: HostListener,
                args: ['keydown.tab', ['$event']]
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A drop down component for filtering data. The component includes all tags
 * and buttons necessary to render the drop down menu and filter data. This is
 * included with the `PagedTableWithToolbar`, and all logic is included to
 * handle filtering your data when the user clicks the `Search` button. The only
 * thing you must provide is a form with one or more fields to filter your data.
 * See the [PagedTableWithToolbar](/widgets/table/overview#paged-table-with-toolbar-component)
 * for more details.
 *
 * > NOTE: The key for each control included in the form should match up with
 * > expected filter values to be included in query parameters sent to your API.
 * > This allows a map to be generated dynamically by looping over controls,
 * > rather than requiring parent component to define filter map (which can get
 * > repetative).
 */
class FilterDropDownComponent {
    constructor() {
        this.clearSearchForm = new EventEmitter();
        /** The event emitted when the user clicks the search button. */
        this.searchClick = new EventEmitter();
        /** The icon used to open the drop down. */
        this.faCaretDown = faCaretDown;
        /** The icon to display next to search text. */
        this.faSearch = faSearch;
    }
    ngAfterViewInit() {
        // wait a tick to avoid expressionchangedafterithasbeencheckederror;
        // then set menuWidth to width of search field where drop down is
        // rendered from
        setTimeout(() => (this.menuWidth = this.field.nativeElement.clientWidth));
    }
    clear() {
        this.clearSearchForm.emit(true);
    }
    search() {
        this.searchClick.emit(true);
    }
}
FilterDropDownComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FilterDropDownComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
FilterDropDownComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: FilterDropDownComponent, selector: "ngx-mat-filter-drop-down", outputs: { clearSearchForm: "clearSearchForm", searchClick: "searchClick" }, viewQueries: [{ propertyName: "field", first: true, predicate: ["searchField"], descendants: true, read: ElementRef, static: true }], ngImport: i0, template: "<div floatLabel=\"never\" fxFlex fxLayout=\"column\" #searchField [matMenuTriggerFor]=\"filterMenu\">\n    <!-- <input placeholder=\"Search...\"\n            matInput\n            formControlName=\"search\"> -->\n    <div fxFlex fxLayout=\"row\">\n        <fa-icon class=\"pr-2\" matPrefix [icon]=\"faSearch\"></fa-icon>\n        <span fxFlex>Search...</span>\n        <fa-icon [icon]=\"faCaretDown\" class=\"marker-menu-trigger\"></fa-icon>\n    </div>\n    <mat-divider fxFlex></mat-divider>\n</div>\n<mat-menu class=\"container search-menu\" xPosition=\"before\" yPosition=\"below\" #filterMenu=\"matMenu\">\n    <div [style.width.px]=\"menuWidth\" fxLayout=\"column\" fxLayoutGap=\"10px\" matMenuContent #filterMenuContent>\n        <span>Filter results</span>\n        <form ngxMatClickStopPropagation ngxMatTabStopPropagation> <!-- (keydown.tab)=\"$event.stopPropagation()\" -->\n            <!-- include search filters defined in tag where this component is used -->\n            <ng-content></ng-content>\n        </form>\n        <div fxLayout=\"row\">\n            <div fxFlex></div>\n            <button mat-flat-button (click)=\"clear()\" class=\"marker-button-clear\">Clear</button>\n            <button mat-raised-button color=\"primary\" (click)=\"search()\" class=\"marker-button-search\">Search</button>\n        </div>\n    </div>\n</mat-menu>\n", styles: [""], components: [{ type: i2.FaIconComponent, selector: "fa-icon", inputs: ["icon", "title", "spin", "pulse", "mask", "styles", "flip", "size", "pull", "border", "inverse", "symbol", "rotate", "fixedWidth", "classes", "transform", "a11yRole"] }, { type: i3.MatMenu, selector: "mat-menu", exportAs: ["matMenu"] }, { type: i1$2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }], directives: [{ type: i5.DefaultFlexDirective, selector: "  [fxFlex], [fxFlex.xs], [fxFlex.sm], [fxFlex.md],  [fxFlex.lg], [fxFlex.xl], [fxFlex.lt-sm], [fxFlex.lt-md],  [fxFlex.lt-lg], [fxFlex.lt-xl], [fxFlex.gt-xs], [fxFlex.gt-sm],  [fxFlex.gt-md], [fxFlex.gt-lg]", inputs: ["fxFlex", "fxFlex.xs", "fxFlex.sm", "fxFlex.md", "fxFlex.lg", "fxFlex.xl", "fxFlex.lt-sm", "fxFlex.lt-md", "fxFlex.lt-lg", "fxFlex.lt-xl", "fxFlex.gt-xs", "fxFlex.gt-sm", "fxFlex.gt-md", "fxFlex.gt-lg"] }, { type: i5.DefaultLayoutDirective, selector: "  [fxLayout], [fxLayout.xs], [fxLayout.sm], [fxLayout.md],  [fxLayout.lg], [fxLayout.xl], [fxLayout.lt-sm], [fxLayout.lt-md],  [fxLayout.lt-lg], [fxLayout.lt-xl], [fxLayout.gt-xs], [fxLayout.gt-sm],  [fxLayout.gt-md], [fxLayout.gt-lg]", inputs: ["fxLayout", "fxLayout.xs", "fxLayout.sm", "fxLayout.md", "fxLayout.lg", "fxLayout.xl", "fxLayout.lt-sm", "fxLayout.lt-md", "fxLayout.lt-lg", "fxLayout.lt-xl", "fxLayout.gt-xs", "fxLayout.gt-sm", "fxLayout.gt-md", "fxLayout.gt-lg"] }, { type: i3.MatMenuTrigger, selector: "[mat-menu-trigger-for], [matMenuTriggerFor]", exportAs: ["matMenuTrigger"] }, { type: i1$1.MatPrefix, selector: "[matPrefix]" }, { type: i5.DefaultLayoutGapDirective, selector: "  [fxLayoutGap], [fxLayoutGap.xs], [fxLayoutGap.sm], [fxLayoutGap.md],  [fxLayoutGap.lg], [fxLayoutGap.xl], [fxLayoutGap.lt-sm], [fxLayoutGap.lt-md],  [fxLayoutGap.lt-lg], [fxLayoutGap.lt-xl], [fxLayoutGap.gt-xs], [fxLayoutGap.gt-sm],  [fxLayoutGap.gt-md], [fxLayoutGap.gt-lg]", inputs: ["fxLayoutGap", "fxLayoutGap.xs", "fxLayoutGap.sm", "fxLayoutGap.md", "fxLayoutGap.lg", "fxLayoutGap.xl", "fxLayoutGap.lt-sm", "fxLayoutGap.lt-md", "fxLayoutGap.lt-lg", "fxLayoutGap.lt-xl", "fxLayoutGap.gt-xs", "fxLayoutGap.gt-sm", "fxLayoutGap.gt-md", "fxLayoutGap.gt-lg"] }, { type: ClickStopPropagationDirective, selector: "[ngxMatClickStopPropagation]" }, { type: TabStopPropagationDirective, selector: "[ngxMatTabStopPropagation]" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FilterDropDownComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-filter-drop-down', template: "<div floatLabel=\"never\" fxFlex fxLayout=\"column\" #searchField [matMenuTriggerFor]=\"filterMenu\">\n    <!-- <input placeholder=\"Search...\"\n            matInput\n            formControlName=\"search\"> -->\n    <div fxFlex fxLayout=\"row\">\n        <fa-icon class=\"pr-2\" matPrefix [icon]=\"faSearch\"></fa-icon>\n        <span fxFlex>Search...</span>\n        <fa-icon [icon]=\"faCaretDown\" class=\"marker-menu-trigger\"></fa-icon>\n    </div>\n    <mat-divider fxFlex></mat-divider>\n</div>\n<mat-menu class=\"container search-menu\" xPosition=\"before\" yPosition=\"below\" #filterMenu=\"matMenu\">\n    <div [style.width.px]=\"menuWidth\" fxLayout=\"column\" fxLayoutGap=\"10px\" matMenuContent #filterMenuContent>\n        <span>Filter results</span>\n        <form ngxMatClickStopPropagation ngxMatTabStopPropagation> <!-- (keydown.tab)=\"$event.stopPropagation()\" -->\n            <!-- include search filters defined in tag where this component is used -->\n            <ng-content></ng-content>\n        </form>\n        <div fxLayout=\"row\">\n            <div fxFlex></div>\n            <button mat-flat-button (click)=\"clear()\" class=\"marker-button-clear\">Clear</button>\n            <button mat-raised-button color=\"primary\" (click)=\"search()\" class=\"marker-button-search\">Search</button>\n        </div>\n    </div>\n</mat-menu>\n", styles: [""] }]
        }], ctorParameters: function () { return []; }, propDecorators: { clearSearchForm: [{
                type: Output
            }], searchClick: [{
                type: Output
            }], field: [{
                type: ViewChild,
                args: ['searchField', { static: true, read: ElementRef }]
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `PagedCollectionWithRaisedButtonToolbar` extends the
 * `PagedCollectionWithToolbar`. This component does not add new capabilities,
 * but defines the type of toolbar expected to be used with the collection,
 * which is the `RaisedButtonToolbar`. It requires the collection in the
 * template to be of type `PagedCollection` since it expects paging to be
 * managed by the collection itself. See the documentation for the
 * `RaisedButtonToolbar` for more details
 * [here](/widgets/toolbar/overview#raised-button-toolbar-component).
 */
class PagedCollectionWithRaisedButtonToolbarComponent extends PagedCollectionWithToolbarComponent {
}
PagedCollectionWithRaisedButtonToolbarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedCollectionWithRaisedButtonToolbarComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
PagedCollectionWithRaisedButtonToolbarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: PagedCollectionWithRaisedButtonToolbarComponent, selector: "ng-component", inputs: { form: "form" }, queries: [{ propertyName: "filter", first: true, predicate: FilterDropDownComponent, descendants: true }], usesInheritance: true, ngImport: i0, template: '', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedCollectionWithRaisedButtonToolbarComponent, decorators: [{
            type: Component,
            args: [{
                    template: '',
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], propDecorators: { filter: [{
                type: ContentChild,
                args: [FilterDropDownComponent]
            }], form: [{
                type: Input
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `ButtonClickAction` enum defines the default actions available for
 * buttons related to collections. The basic actions are Create, Edit, and
 * Delete.
 */
var ButtonClickAction;
(function (ButtonClickAction) {
    ButtonClickAction["Create"] = "create";
    ButtonClickAction["Edit"] = "edit";
    ButtonClickAction["Delete"] = "delete";
})(ButtonClickAction || (ButtonClickAction = {}));

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A basic edit button.
 */
const EDIT_BUTTON = {
    icon: faEdit,
    click: 'edit'
};
/**
 * A basic delete button.
 */
const DELETE_BUTTON = {
    icon: faTrash,
    click: 'delete'
};
/** Default buttons that appear in each row inside actions column. */
const DEFAULT_COLLECTION_BUTTONS = [EDIT_BUTTON, DELETE_BUTTON];

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A simple service that provides convenience methods for forms.
 *
 * @overviewDetails
 * #### Features
 *
 * Currently the only method available is `markAsTouched`. This will iterate
 * through the controls of given form and mark them all as touched. Mainly
 * intended to cause change detection so potential error messages are rendered
 * for all controls on the given form where appropriate, allowing for nested
 * FormGroups and FormArrays.
 *
 * #### Basic Usage Example
 * ```typescript
 * // ...
 * import {FormService} from '@ngx-material-dashboard/widgets';
 * // ...
 * constructor(private formService: FormService) {}
 *
 * submit(form: FormGroup | FormArray): void {
 *     this.formService.markAsTouched(form);
 * }
 * ```
 */
class FormService {
    /**
     * Iterates through the controls of the given form and marks them as touched.
     * Mainly intended to display error messages on form. Allows for nested
     * FormGroups and FormArrays. Taken from below stackoverflow response.
     * https://stackoverflow.com/a/50992362
     *
     * @param form The form group or array to mark as touched.
     */
    markAsTouched(form) {
        Object.keys(form.controls).forEach((controlName) => {
            const control = form.get(controlName);
            if (control instanceof FormGroup || control instanceof FormArray) {
                // recurse and handle nested FormGroups/FormArrays
                this.markAsTouched(control);
            }
            else if (control) {
                // mark the control as touched
                control.markAsTouched();
            }
        });
    }
}
FormService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FormService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
FormService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FormService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FormService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A component for rendering errors for a single form field. This simplifies
 * rendering errors on forms so you don't need to have more than one `mat-error`
 * per form field (if your fields have multiple validators). This component
 * should be rendered inside of a mat-error tag so it displays correctly below
 * a form field.
 *
 * The component requires 3 input values, (1) the name of the field to render
 * errors for, (2) the `FormGroup` where the field is defined, (3) and an array
 * of `ValidationMessage`s which define the error messages for their respective
 * validator type. You should use the `ValidationMessages` type to define your
 * validation messages in your typescript, which is a map of field names to
 * arrays of `ValidationMessage`s. See
 * [ValidationMessages](/widgets/form/overview#validation-messages) for more
 * info about the `ValidationMessages` type.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <form [formGroup]="form" fxLayout="column" fxLayoutGap="10px">
 *     <mat-form-field fxFlex>
 *         <mat-label>Username</mat-label>
 *         <input matInput type="text" formControlName="username">
 *         <mat-error>
 *             <ngx-mat-field-error
 *                 field='username'
 *                 [form]="form"
 *                 [validationMessages]="validationMessages.username">
 *             </ngx-mat-field-error>
 *         </mat-error>
 *     </mat-form-field>
 *     <mat-form-field fxFlex>
 *         <mat-label>Password</mat-label>
 *         <input matInput type="password" formControlName="password">
 *         <mat-error>
 *             <ngx-mat-field-error
 *                 field='password'
 *                 [form]="form"
 *                 [validationMessages]="validationMessages.password">
 *             </ngx-mat-field-error>
 *         </mat-error>
 *     </mat-form-field>
 * </form>
 * ```
 * ```typescript
 * import {Component} from '@angular/core';
 * import {FormControl, FormGroup} from '@angular/forms';
 * import {ValidationMessages} from '@ngx-material-dashboard/widgets';
 *
 * @Component({
 *     selector: 'field-error-basic-usage-example',
 *     templateUrl: './field-error-basic-usage-example.html'
 * }) export class FieldErrorBasicUsageExample {
 *     form: FormGroup = new FormGroup({
 *         username: new FormControl('', [Validators.required]),
 *         password: new FormControl('', [Validators.required])
 *     });
 *     validationMessages: ValidationMessages = {
 *         username: [
 *             { type: 'username', message: 'Username is required' }
 *         ],
 *         password: [
 *             { type: 'password', message: 'Password is required' }
 *         ]
 *     };
 * }
 * ```
 */
class FieldErrorComponent {
    constructor(formBuilder) {
        this.formBuilder = formBuilder;
        /** The name of the field the errors should be displayed for. */
        this.field = '';
        /**
         * The form that contains the field (defaults to new formGroup to prevent
         * errors and having to define field as nullable).
         */
        this.form = this.formBuilder.group({});
        /** The array of validation messages that correspond with the field. */
        this.validationMessages = [];
    }
    /**
     * Returns true if the given field on the form has an error of the
     * given validation type.
     *
     * @param field The name of the field on the form.
     * @param validationType The type of validation (i.e. 'required', 'pattern', etc.).
     */
    checkFieldError(validationType) {
        var _a;
        if ((_a = this.form.get(this.field)) === null || _a === void 0 ? void 0 : _a.hasError(validationType)) {
            return true;
        }
        else {
            return false;
        }
    }
}
FieldErrorComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FieldErrorComponent, deps: [{ token: i1$4.FormBuilder }], target: i0.ɵɵFactoryTarget.Component });
FieldErrorComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: FieldErrorComponent, selector: "ngx-mat-field-error", inputs: { field: "field", form: "form", validationMessages: "validationMessages" }, ngImport: i0, template: "<mat-error *ngFor=\"let validation of validationMessages\">\n    <mat-error class=\"error-message\" *ngIf=\"checkFieldError(validation.type)\">\n        {{validation.message}}\n    </mat-error>\n</mat-error>", styles: [""], directives: [{ type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i1$1.MatError, selector: "mat-error", inputs: ["id"] }, { type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FieldErrorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-field-error', template: "<mat-error *ngFor=\"let validation of validationMessages\">\n    <mat-error class=\"error-message\" *ngIf=\"checkFieldError(validation.type)\">\n        {{validation.message}}\n    </mat-error>\n</mat-error>", styles: [""] }]
        }], ctorParameters: function () { return [{ type: i1$4.FormBuilder }]; }, propDecorators: { field: [{
                type: Input
            }], form: [{
                type: Input
            }], validationMessages: [{
                type: Input
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
class FormModule {
}
FormModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FormModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
FormModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FormModule, declarations: [FieldErrorComponent,
        ClickStopPropagationDirective,
        TabStopPropagationDirective], imports: [CommonModule, MatFormFieldModule], exports: [ClickStopPropagationDirective,
        TabStopPropagationDirective,
        FieldErrorComponent] });
FormModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FormModule, providers: [FormService], imports: [[CommonModule, MatFormFieldModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FormModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        FieldErrorComponent,
                        ClickStopPropagationDirective,
                        TabStopPropagationDirective
                    ],
                    exports: [
                        ClickStopPropagationDirective,
                        TabStopPropagationDirective,
                        FieldErrorComponent
                    ],
                    imports: [CommonModule, MatFormFieldModule],
                    providers: [FormService]
                }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * Displays a list of `ToolbarButtons`.
 */
class ButtonsComponent {
    constructor() {
        /** The management buttons to display in the toolbar. */
        this.buttons = [];
        this.buttonClick = new EventEmitter();
        this.sub = new Subscription();
    }
    /**
     * Destroys any subscriptions for the component.
     */
    ngOnDestroy() {
        this.sub.unsubscribe();
    }
    /**
     * Initialize the main subscriptions object for the component.
     */
    ngOnInit() {
        this.sub = new Subscription();
    }
    /**
     * Emits a buttonClick event to the parent.
     *
     * @param buttonClick The action from the button that was clicked by the user.
     */
    emitButtonClick(buttonClick) {
        this.buttonClick.emit({ click: buttonClick });
    }
}
ButtonsComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ButtonsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
ButtonsComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: ButtonsComponent, selector: "ngx-mat-buttons", inputs: { buttons: "buttons" }, outputs: { buttonClick: "buttonClick" }, ngImport: i0, template: "<div fxLayout=\"row\" class=\"marker-buttons-bar\">\n    <div *ngFor=\"let button of buttons\">\n        <button *ngIf=\"button.click; else hyperlink\"\n            class=\"mat-button marker-button-{{button.click}}\"\n            (click)=\"emitButtonClick(button.click)\"\n            [disabled]=\"button.disabled\"\n            mat-button>\n            <div *ngIf=\"button.icon && !button.stackedIcon; else stackedIcon\">\n                <fa-icon [icon]=\"button.icon\"></fa-icon>\n                <span class=\"pl-2\">{{button.text}}</span>\n            </div>\n            <ng-template #stackedIcon>\n                <fa-layers *ngIf=\"button.icon && button.stackedIcon\" [fixedWidth]=\"true\">\n                    <fa-icon [icon]=\"button.icon\"></fa-icon>\n                    <fa-icon [icon]=\"button.stackedIcon\" [styles]=\"button.stackedIconStyles\"></fa-icon>\n                </fa-layers>\n                <span class=\"pl-2\">{{button.text}}</span>\n            </ng-template>\n        </button>\n        <ng-template #hyperlink>\n            <a class=\"mat-button marker-button-{{button.click}}\"\n                [attr.disabled]=\"button.disabled\"\n                [href]=\"button.href\"\n                target=\"_blank\"\n                mat-button>\n                <div *ngIf=\"button.icon && !button.stackedIcon; else stackedIcon\">\n                    <fa-icon [icon]=\"button.icon\"></fa-icon>\n                    <span class=\"pl-2\">{{button.text}}</span>\n                </div>\n                <ng-template #stackedIcon>\n                    <fa-layers *ngIf=\"button.icon && button.stackedIcon\" [fixedWidth]=\"true\">\n                        <fa-icon [icon]=\"button.icon\"></fa-icon>\n                        <fa-icon [icon]=\"button.stackedIcon\" [styles]=\"button.stackedIconStyles\"></fa-icon>\n                    </fa-layers>\n                    <span class=\"pl-2\">{{button.text}}</span>\n                </ng-template>\n            </a>\n        </ng-template>\n    </div>\n</div>", styles: [""], components: [{ type: i1$2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i2.FaIconComponent, selector: "fa-icon", inputs: ["icon", "title", "spin", "pulse", "mask", "styles", "flip", "size", "pull", "border", "inverse", "symbol", "rotate", "fixedWidth", "classes", "transform", "a11yRole"] }, { type: i2.FaLayersComponent, selector: "fa-layers", inputs: ["size", "fixedWidth"] }, { type: i1$2.MatAnchor, selector: "a[mat-button], a[mat-raised-button], a[mat-icon-button], a[mat-fab],             a[mat-mini-fab], a[mat-stroked-button], a[mat-flat-button]", inputs: ["disabled", "disableRipple", "color", "tabIndex"], exportAs: ["matButton", "matAnchor"] }], directives: [{ type: i5.DefaultLayoutDirective, selector: "  [fxLayout], [fxLayout.xs], [fxLayout.sm], [fxLayout.md],  [fxLayout.lg], [fxLayout.xl], [fxLayout.lt-sm], [fxLayout.lt-md],  [fxLayout.lt-lg], [fxLayout.lt-xl], [fxLayout.gt-xs], [fxLayout.gt-sm],  [fxLayout.gt-md], [fxLayout.gt-lg]", inputs: ["fxLayout", "fxLayout.xs", "fxLayout.sm", "fxLayout.md", "fxLayout.lg", "fxLayout.xl", "fxLayout.lt-sm", "fxLayout.lt-md", "fxLayout.lt-lg", "fxLayout.lt-xl", "fxLayout.gt-xs", "fxLayout.gt-sm", "fxLayout.gt-md", "fxLayout.gt-lg"] }, { type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ButtonsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-buttons', template: "<div fxLayout=\"row\" class=\"marker-buttons-bar\">\n    <div *ngFor=\"let button of buttons\">\n        <button *ngIf=\"button.click; else hyperlink\"\n            class=\"mat-button marker-button-{{button.click}}\"\n            (click)=\"emitButtonClick(button.click)\"\n            [disabled]=\"button.disabled\"\n            mat-button>\n            <div *ngIf=\"button.icon && !button.stackedIcon; else stackedIcon\">\n                <fa-icon [icon]=\"button.icon\"></fa-icon>\n                <span class=\"pl-2\">{{button.text}}</span>\n            </div>\n            <ng-template #stackedIcon>\n                <fa-layers *ngIf=\"button.icon && button.stackedIcon\" [fixedWidth]=\"true\">\n                    <fa-icon [icon]=\"button.icon\"></fa-icon>\n                    <fa-icon [icon]=\"button.stackedIcon\" [styles]=\"button.stackedIconStyles\"></fa-icon>\n                </fa-layers>\n                <span class=\"pl-2\">{{button.text}}</span>\n            </ng-template>\n        </button>\n        <ng-template #hyperlink>\n            <a class=\"mat-button marker-button-{{button.click}}\"\n                [attr.disabled]=\"button.disabled\"\n                [href]=\"button.href\"\n                target=\"_blank\"\n                mat-button>\n                <div *ngIf=\"button.icon && !button.stackedIcon; else stackedIcon\">\n                    <fa-icon [icon]=\"button.icon\"></fa-icon>\n                    <span class=\"pl-2\">{{button.text}}</span>\n                </div>\n                <ng-template #stackedIcon>\n                    <fa-layers *ngIf=\"button.icon && button.stackedIcon\" [fixedWidth]=\"true\">\n                        <fa-icon [icon]=\"button.icon\"></fa-icon>\n                        <fa-icon [icon]=\"button.stackedIcon\" [styles]=\"button.stackedIconStyles\"></fa-icon>\n                    </fa-layers>\n                    <span class=\"pl-2\">{{button.text}}</span>\n                </ng-template>\n            </a>\n        </ng-template>\n    </div>\n</div>", styles: [""] }]
        }], ctorParameters: function () { return []; }, propDecorators: { buttons: [{
                type: Input
            }], buttonClick: [{
                type: Output
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
class SearchFilterDirective {
    constructor(changeDetectorRef) {
        this.changeDetectorRef = changeDetectorRef;
        this.searchClick = new EventEmitter();
        this.sub = new Subscription();
    }
    /** The filter drop down. */
    set filter(val) {
        if (val && this.collection && this.form) {
            const sub = val.searchClick.subscribe(() => {
                // set dataSource filter based on values entered on searchFilter
                const searchFilterData = this.form.get('searchFilter');
                this.collection.dataSource.filter =
                    this.buildSearchFilter(searchFilterData);
                // emit the filter in case parent components want to handle themselves
                // TODO settle on whether parent component handles filter or it is done
                // here
                this.searchClick.emit(this.collection.dataSource.filter);
                if (this.collection.dataSource instanceof RemoteDataSource) {
                    // refresh the data with updated filter
                    this.collection.dataSource.refresh();
                }
                else {
                    // TODO handle local dataSource
                    this.throwError();
                }
            });
            this.sub.add(sub);
        }
    }
    /**
     * Builds a map of search filter data based on controls from given FormGroup,
     * which should be form used in FilterDropDown component defined for the
     * toolbar. The key for each control should match up with expected filter
     * values to be included in query parameters sent to server API. This allows
     * map to be generated dynamically by looping over controls, rather than
     * requiring parent component to define filter map (which can get repetative).
     * Code to loop over form controls taken from answer to stackoverflow below:
     * https://stackoverflow.com/a/42235220/.
     *
     * @param searchFilterData FormGroup defined for filter drop down.
     * @returns A map of search filters to send to server API.
     */
    buildSearchFilter(searchFilterData) {
        const searchFilter = {};
        Object.keys(searchFilterData.controls).forEach((key) => {
            searchFilter[key] = searchFilterData.controls[key].value;
        });
        return searchFilter;
    }
    ngOnDestroy() {
        this.sub.unsubscribe();
    }
    throwError() {
        throw new Error('Local datasource not yet handled');
    }
}
SearchFilterDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: SearchFilterDirective, deps: [{ token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Directive });
SearchFilterDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.12", type: SearchFilterDirective, selector: "[ngxMatSearchFilter]", inputs: { filter: "filter", form: "form", collection: "collection" }, outputs: { searchClick: "searchClick" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: SearchFilterDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngxMatSearchFilter]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }]; }, propDecorators: { filter: [{
                type: Input
            }], form: [{
                type: Input
            }], collection: [{
                type: Input
            }], searchClick: [{
                type: Output
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A wrapper for `MatToolbar` to control how buttons are rendered in the
 * toolbar. Basically just left or right alignment in the toolbar. It also
 * includes the ability to render custom content in the middle of the toolbar,
 * for things like the search filter drop down meant to be rendered above
 * paged collections in any component that utilizes the
 * `PagedCollectionWithToolbar`.
 */
class ButtonToolbarComponent {
    constructor() {
        /** The management buttons to display in the toolbar. */
        this.buttons = [];
        /**
         * String value indicating whether buttons should appear on left or right
         * side of screen (defaults to right).
         */
        this.buttonAlign = 'right';
        this.buttonClick = new EventEmitter();
        this.sub = new Subscription();
    }
    /**
     * Emits a buttonClick event to the parent.
     *
     * @param buttonClick The action from the button that was clicked by the user.
     */
    emitButtonClick(buttonClick) {
        this.buttonClick.emit(buttonClick);
    }
}
ButtonToolbarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ButtonToolbarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
ButtonToolbarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: ButtonToolbarComponent, selector: "ngx-mat-button-toolbar", inputs: { buttons: "buttons", buttonAlign: "buttonAlign" }, outputs: { buttonClick: "buttonClick" }, ngImport: i0, template: "<mat-toolbar>\n    <div fxFlex=\"0 0 25\">\n        <div *ngIf=\"buttonAlign === 'left'\" fxLayoutAlign=\"row\" class=\"marker-align-left\">\n            <ngx-mat-buttons [buttons]=\"buttons\" (buttonClick)=\"emitButtonClick($event)\"></ngx-mat-buttons>\n        </div>\n    </div>\n    <div fxFlex=\"0 0 50\">\n        <ng-content></ng-content>\n    </div>\n    <div fxFlex=\"0 0 25\">\n        <div fxFlex></div>\n        <div *ngIf=\"buttonAlign === 'right'\" fxLayoutAlign=\"row\" class=\"marker-align-right\">\n            <ngx-mat-buttons [buttons]=\"buttons\" (buttonClick)=\"emitButtonClick($event)\"></ngx-mat-buttons>\n        </div>\n    </div>\n</mat-toolbar>\n", styles: [""], components: [{ type: i1$5.MatToolbar, selector: "mat-toolbar", inputs: ["color"], exportAs: ["matToolbar"] }, { type: ButtonsComponent, selector: "ngx-mat-buttons", inputs: ["buttons"], outputs: ["buttonClick"] }], directives: [{ type: i5.DefaultFlexDirective, selector: "  [fxFlex], [fxFlex.xs], [fxFlex.sm], [fxFlex.md],  [fxFlex.lg], [fxFlex.xl], [fxFlex.lt-sm], [fxFlex.lt-md],  [fxFlex.lt-lg], [fxFlex.lt-xl], [fxFlex.gt-xs], [fxFlex.gt-sm],  [fxFlex.gt-md], [fxFlex.gt-lg]", inputs: ["fxFlex", "fxFlex.xs", "fxFlex.sm", "fxFlex.md", "fxFlex.lg", "fxFlex.xl", "fxFlex.lt-sm", "fxFlex.lt-md", "fxFlex.lt-lg", "fxFlex.lt-xl", "fxFlex.gt-xs", "fxFlex.gt-sm", "fxFlex.gt-md", "fxFlex.gt-lg"] }, { type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i5.DefaultLayoutAlignDirective, selector: "  [fxLayoutAlign], [fxLayoutAlign.xs], [fxLayoutAlign.sm], [fxLayoutAlign.md],  [fxLayoutAlign.lg], [fxLayoutAlign.xl], [fxLayoutAlign.lt-sm], [fxLayoutAlign.lt-md],  [fxLayoutAlign.lt-lg], [fxLayoutAlign.lt-xl], [fxLayoutAlign.gt-xs], [fxLayoutAlign.gt-sm],  [fxLayoutAlign.gt-md], [fxLayoutAlign.gt-lg]", inputs: ["fxLayoutAlign", "fxLayoutAlign.xs", "fxLayoutAlign.sm", "fxLayoutAlign.md", "fxLayoutAlign.lg", "fxLayoutAlign.xl", "fxLayoutAlign.lt-sm", "fxLayoutAlign.lt-md", "fxLayoutAlign.lt-lg", "fxLayoutAlign.lt-xl", "fxLayoutAlign.gt-xs", "fxLayoutAlign.gt-sm", "fxLayoutAlign.gt-md", "fxLayoutAlign.gt-lg"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ButtonToolbarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-button-toolbar', template: "<mat-toolbar>\n    <div fxFlex=\"0 0 25\">\n        <div *ngIf=\"buttonAlign === 'left'\" fxLayoutAlign=\"row\" class=\"marker-align-left\">\n            <ngx-mat-buttons [buttons]=\"buttons\" (buttonClick)=\"emitButtonClick($event)\"></ngx-mat-buttons>\n        </div>\n    </div>\n    <div fxFlex=\"0 0 50\">\n        <ng-content></ng-content>\n    </div>\n    <div fxFlex=\"0 0 25\">\n        <div fxFlex></div>\n        <div *ngIf=\"buttonAlign === 'right'\" fxLayoutAlign=\"row\" class=\"marker-align-right\">\n            <ngx-mat-buttons [buttons]=\"buttons\" (buttonClick)=\"emitButtonClick($event)\"></ngx-mat-buttons>\n        </div>\n    </div>\n</mat-toolbar>\n", styles: [""] }]
        }], ctorParameters: function () { return []; }, propDecorators: { buttons: [{
                type: Input
            }], buttonAlign: [{
                type: Input
            }], buttonClick: [{
                type: Output
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A toolbar that renders `mat-raised-button`s in a `MatToolbar`. As a result
 * this is a larger toolbar, and can be used in things like the main header of
 * your application, or anywhere you need to include 1 or more left or right
 * aligned buttons in a row in your application. It is used internally by
 * components that utilize the `PagedCollectionWithRaisedButtonToolbar`. You
 * can take a look at
 * [PagedCollectionWithRaisedButtonToolbar](/widgets/collection/overview#paged-collection-with-raised-button-toolbar-component)
 * for an example of how you can use this component.
 *
 * @overviewDetails
 *
 * #### Features
 *
 * The toolbar allows you to control the alignment of buttons (i.e. left or
 * right). It also includes the ability to render an optional `FilterDropDown`.
 *
 * ##### Button Alignment
 *
 * To align buttons to the left or right simply use the `buttonAlign` input
 * with the desired `left` or `right` value. Buttons default to be `right`
 * aligned.
 *
 * ##### Optional Filter Drop Down
 *
 * You may include an optional `FilterDropDown` that renders a detailed formed
 * to filter paged collections. See the following for more details on the
 * [FilterDropDown](/widgets/toolbar/overview#filter-drop-down-component).
 */
class RaisedButtonToolbarComponent {
    constructor() {
        /** The management buttons to display in the toolbar. */
        this.buttons = [];
        /**
         * String value indicating whether buttons should appear on left or right
         * side of screen (defaults to right).
         */
        this.buttonAlign = 'right';
        this.buttonClick = new EventEmitter();
        this.sub = new Subscription();
    }
    /**
     * Emits a buttonClick event to the parent.
     *
     * @param buttonClick The action from the button that was clicked by the user.
     */
    emitButtonClick(buttonClick) {
        this.buttonClick.emit(buttonClick);
    }
}
RaisedButtonToolbarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: RaisedButtonToolbarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
RaisedButtonToolbarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: RaisedButtonToolbarComponent, selector: "ngx-mat-raised-button-toolbar", inputs: { buttons: "buttons", buttonAlign: "buttonAlign" }, outputs: { buttonClick: "buttonClick" }, ngImport: i0, template: "<mat-toolbar>\n    <div fxFlex=\"0 0 25\">\n        <div *ngIf=\"buttonAlign === 'left'\" fxLayoutAlign=\"row\" class=\"marker-align-left\">\n            <ngx-mat-buttons [buttons]=\"buttons\" (buttonClick)=\"emitButtonClick($event)\"></ngx-mat-buttons>\n        </div>\n    </div>\n    <div fxFlex=\"0 0 50\">\n        <ng-content></ng-content>\n    </div>\n    <div fxFlex=\"0 0 25\">\n        <div fxFlex></div>\n        <div *ngIf=\"buttonAlign === 'right'\" fxLayoutAlign=\"row\" class=\"marker-align-right\">\n            <ngx-mat-buttons [buttons]=\"buttons\" (buttonClick)=\"emitButtonClick($event)\"></ngx-mat-buttons>\n        </div>\n    </div>\n</mat-toolbar>\n", styles: [""], components: [{ type: i1$5.MatToolbar, selector: "mat-toolbar", inputs: ["color"], exportAs: ["matToolbar"] }, { type: ButtonsComponent, selector: "ngx-mat-buttons", inputs: ["buttons"], outputs: ["buttonClick"] }], directives: [{ type: i5.DefaultFlexDirective, selector: "  [fxFlex], [fxFlex.xs], [fxFlex.sm], [fxFlex.md],  [fxFlex.lg], [fxFlex.xl], [fxFlex.lt-sm], [fxFlex.lt-md],  [fxFlex.lt-lg], [fxFlex.lt-xl], [fxFlex.gt-xs], [fxFlex.gt-sm],  [fxFlex.gt-md], [fxFlex.gt-lg]", inputs: ["fxFlex", "fxFlex.xs", "fxFlex.sm", "fxFlex.md", "fxFlex.lg", "fxFlex.xl", "fxFlex.lt-sm", "fxFlex.lt-md", "fxFlex.lt-lg", "fxFlex.lt-xl", "fxFlex.gt-xs", "fxFlex.gt-sm", "fxFlex.gt-md", "fxFlex.gt-lg"] }, { type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i5.DefaultLayoutAlignDirective, selector: "  [fxLayoutAlign], [fxLayoutAlign.xs], [fxLayoutAlign.sm], [fxLayoutAlign.md],  [fxLayoutAlign.lg], [fxLayoutAlign.xl], [fxLayoutAlign.lt-sm], [fxLayoutAlign.lt-md],  [fxLayoutAlign.lt-lg], [fxLayoutAlign.lt-xl], [fxLayoutAlign.gt-xs], [fxLayoutAlign.gt-sm],  [fxLayoutAlign.gt-md], [fxLayoutAlign.gt-lg]", inputs: ["fxLayoutAlign", "fxLayoutAlign.xs", "fxLayoutAlign.sm", "fxLayoutAlign.md", "fxLayoutAlign.lg", "fxLayoutAlign.xl", "fxLayoutAlign.lt-sm", "fxLayoutAlign.lt-md", "fxLayoutAlign.lt-lg", "fxLayoutAlign.lt-xl", "fxLayoutAlign.gt-xs", "fxLayoutAlign.gt-sm", "fxLayoutAlign.gt-md", "fxLayoutAlign.gt-lg"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: RaisedButtonToolbarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-raised-button-toolbar', template: "<mat-toolbar>\n    <div fxFlex=\"0 0 25\">\n        <div *ngIf=\"buttonAlign === 'left'\" fxLayoutAlign=\"row\" class=\"marker-align-left\">\n            <ngx-mat-buttons [buttons]=\"buttons\" (buttonClick)=\"emitButtonClick($event)\"></ngx-mat-buttons>\n        </div>\n    </div>\n    <div fxFlex=\"0 0 50\">\n        <ng-content></ng-content>\n    </div>\n    <div fxFlex=\"0 0 25\">\n        <div fxFlex></div>\n        <div *ngIf=\"buttonAlign === 'right'\" fxLayoutAlign=\"row\" class=\"marker-align-right\">\n            <ngx-mat-buttons [buttons]=\"buttons\" (buttonClick)=\"emitButtonClick($event)\"></ngx-mat-buttons>\n        </div>\n    </div>\n</mat-toolbar>\n", styles: [""] }]
        }], ctorParameters: function () { return []; }, propDecorators: { buttons: [{
                type: Input
            }], buttonAlign: [{
                type: Input
            }], buttonClick: [{
                type: Output
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
class ToolbarModule {
}
ToolbarModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ToolbarModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ToolbarModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ToolbarModule, declarations: [ButtonsComponent,
        ButtonToolbarComponent,
        FilterDropDownComponent,
        IconButtonsComponent,
        IconButtonsWithPaginatorComponent,
        RaisedButtonToolbarComponent,
        SearchFilterDirective,
        SorterComponent], imports: [CommonModule,
        MatButtonModule,
        MatCheckboxModule,
        MatMenuModule,
        MatPaginatorModule,
        MatSelectModule,
        MatSortModule,
        MatToolbarModule,
        MatTooltipModule,
        FlexLayoutModule,
        FontAwesomeModule,
        FormModule], exports: [ButtonToolbarComponent,
        FilterDropDownComponent,
        IconButtonsWithPaginatorComponent,
        RaisedButtonToolbarComponent,
        SearchFilterDirective,
        SorterComponent] });
ToolbarModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ToolbarModule, imports: [[
            CommonModule,
            MatButtonModule,
            MatCheckboxModule,
            MatMenuModule,
            MatPaginatorModule,
            MatSelectModule,
            MatSortModule,
            MatToolbarModule,
            MatTooltipModule,
            FlexLayoutModule,
            FontAwesomeModule,
            FormModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ToolbarModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        ButtonsComponent,
                        ButtonToolbarComponent,
                        FilterDropDownComponent,
                        IconButtonsComponent,
                        IconButtonsWithPaginatorComponent,
                        RaisedButtonToolbarComponent,
                        SearchFilterDirective,
                        SorterComponent
                    ],
                    exports: [
                        ButtonToolbarComponent,
                        FilterDropDownComponent,
                        IconButtonsWithPaginatorComponent,
                        RaisedButtonToolbarComponent,
                        SearchFilterDirective,
                        SorterComponent
                    ],
                    imports: [
                        CommonModule,
                        MatButtonModule,
                        MatCheckboxModule,
                        MatMenuModule,
                        MatPaginatorModule,
                        MatSelectModule,
                        MatSortModule,
                        MatToolbarModule,
                        MatTooltipModule,
                        FlexLayoutModule,
                        FontAwesomeModule,
                        FormModule
                    ]
                }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
class CollectionModule {
}
CollectionModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: CollectionModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
CollectionModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: CollectionModule, declarations: [CollectionComponent,
        PagedCollectionWithToolbarComponent,
        PagedCollectionComponent,
        PagedCollectionWithIconToolbarComponent,
        PagedCollectionWithRaisedButtonToolbarComponent], imports: [CommonModule,
        FlexLayoutModule,
        MatPaginatorModule,
        MatSelectModule,
        MatSortModule,
        FontAwesomeModule,
        ToolbarModule] });
CollectionModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: CollectionModule, imports: [[
            CommonModule,
            FlexLayoutModule,
            MatPaginatorModule,
            MatSelectModule,
            MatSortModule,
            FontAwesomeModule,
            ToolbarModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: CollectionModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        CollectionComponent,
                        PagedCollectionWithToolbarComponent,
                        PagedCollectionComponent,
                        PagedCollectionWithIconToolbarComponent,
                        PagedCollectionWithRaisedButtonToolbarComponent
                    ],
                    imports: [
                        CommonModule,
                        FlexLayoutModule,
                        MatPaginatorModule,
                        MatSelectModule,
                        MatSortModule,
                        FontAwesomeModule,
                        ToolbarModule
                    ]
                }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A re-usable confirmation dialog with configurable title and text values. If
 * the user confirms in the dialog, then the result returned to the dialog
 * opener is `true`. This allows for complete control of deleting the thing
 * the user wants to delete.
 *
 * @overviewDetails
 * #### Basic Usage Example
 * ```typescript
 * import {Component} from '@angular/core';
 * import {MatDialog} from '@angular/material/dialog';
 *
 * @Component({
 *     selector: 'confirm-delete-dialog-usage-example',
 *     templateUrl: './confirm-delete-dialog-usage-example.html'
 * })
 * export class ConfirmDeleteDialogUsageExample {
 *
 *     constructor(private dialog: MatDialog) {}
 *
 *     // you will need to call this somewhere, either from a button `(click)`
 *     // event, or perhaps in a subscribe block to some observable
 *     openConfirmDeleteDialog(): void {
 *         // open the dialog
 *         const dialogRef = this.dialog.open(
 *             ConfirmDeleteDialogComponent,
 *             {data: {context:'Are you sure you want to delete value?', title:'Delete value?'}}
 *         );
 *
 *         // handle when dialog closed
 *         dialogRef.afterClosed().subscribe((confirm: boolean) => {
 *             if (confirm) {
 *                 // logic to delete the thing
 *             } // if no confirmation then nothing to do
 *         });
 *     }
 * }
 * ```
 */
class ConfirmDeleteDialogComponent {
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
        /** The icon to render in the dialog. */
        this.faTrash = faTrash;
        this.title = this.data.title;
        this.content = this.data.content;
    }
    ngOnInit() { }
    /**
     * Closes the dialog without returning any value so dialog opener can
     * safely ignore the initial delete request.
     */
    cancel() {
        this.dialogRef.close();
    }
    /**
     * Closes the dialog and returns `true` to the dialog opener so it can
     * handle the logic to delete the thing.
     */
    delete() {
        this.dialogRef.close(true);
    }
}
ConfirmDeleteDialogComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ConfirmDeleteDialogComponent, deps: [{ token: i1$6.MatDialogRef }, { token: MAT_DIALOG_DATA }], target: i0.ɵɵFactoryTarget.Component });
ConfirmDeleteDialogComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: ConfirmDeleteDialogComponent, selector: "ngx-mat-confirm-delete-dialog", ngImport: i0, template: "<div mat-dialog-title>\n    <span>\n        <fa-icon [icon]=\"faTrash\"></fa-icon>\n        {{title}}\n    </span>\n</div>\n<mat-dialog-content>\n    {{content}}\n</mat-dialog-content>\n<mat-dialog-actions align=\"center\">\n    <button mat-raised-button (click)=\"cancel()\" class=\"marker-action-cancel\">Cancel</button>\n    <button mat-raised-button \n            color=\"primary\" \n            type=\"submit\" \n            (click)=\"delete()\"\n            class=\"marker-action-delete\">\n        <span>Delete</span>\n    </button>\n</mat-dialog-actions>\n", styles: [""], components: [{ type: i2.FaIconComponent, selector: "fa-icon", inputs: ["icon", "title", "spin", "pulse", "mask", "styles", "flip", "size", "pull", "border", "inverse", "symbol", "rotate", "fixedWidth", "classes", "transform", "a11yRole"] }, { type: i1$2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }], directives: [{ type: i1$6.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { type: i1$6.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { type: i1$6.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ConfirmDeleteDialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-confirm-delete-dialog', template: "<div mat-dialog-title>\n    <span>\n        <fa-icon [icon]=\"faTrash\"></fa-icon>\n        {{title}}\n    </span>\n</div>\n<mat-dialog-content>\n    {{content}}\n</mat-dialog-content>\n<mat-dialog-actions align=\"center\">\n    <button mat-raised-button (click)=\"cancel()\" class=\"marker-action-cancel\">Cancel</button>\n    <button mat-raised-button \n            color=\"primary\" \n            type=\"submit\" \n            (click)=\"delete()\"\n            class=\"marker-action-delete\">\n        <span>Delete</span>\n    </button>\n</mat-dialog-actions>\n", styles: [""] }]
        }], ctorParameters: function () {
        return [{ type: i1$6.MatDialogRef }, { type: undefined, decorators: [{
                        type: Inject,
                        args: [MAT_DIALOG_DATA]
                    }] }];
    } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
class DialogModule {
}
DialogModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: DialogModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
DialogModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: DialogModule, declarations: [ConfirmDeleteDialogComponent], imports: [CommonModule, MatButtonModule, MatDialogModule, FontAwesomeModule], exports: [ConfirmDeleteDialogComponent] });
DialogModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: DialogModule, imports: [[CommonModule, MatButtonModule, MatDialogModule, FontAwesomeModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: DialogModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [ConfirmDeleteDialogComponent],
                    exports: [ConfirmDeleteDialogComponent],
                    imports: [CommonModule, MatButtonModule, MatDialogModule, FontAwesomeModule]
                }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A set of screen sizes.
 */
var ScreenSize;
(function (ScreenSize) {
    ScreenSize[ScreenSize["XSmall"] = 0] = "XSmall";
    ScreenSize[ScreenSize["Small"] = 1] = "Small";
    ScreenSize[ScreenSize["Medium"] = 2] = "Medium";
    ScreenSize[ScreenSize["Large"] = 3] = "Large";
    ScreenSize[ScreenSize["XLarge"] = 4] = "XLarge";
})(ScreenSize || (ScreenSize = {}));

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
class ScreenSizeService {
    constructor(breakpointObserver) {
        this.breakpointObserver = breakpointObserver;
        this.screenSizeSource = new BehaviorSubject(ScreenSize.Medium);
        this.screenSize = this.screenSizeSource.asObservable();
        this.sub = new Subscription();
        const sub = this.breakpointObserver
            .observe([
            Breakpoints.XSmall,
            Breakpoints.Small,
            Breakpoints.Medium,
            Breakpoints.Large,
            Breakpoints.XLarge
        ])
            .subscribe((state) => {
            if (state.breakpoints[Breakpoints.XSmall]) {
                this.screenSizeSource.next(ScreenSize.XSmall);
            }
            else if (state.breakpoints[Breakpoints.Small]) {
                this.screenSizeSource.next(ScreenSize.Small);
            }
            else if (state.breakpoints[Breakpoints.Medium]) {
                this.screenSizeSource.next(ScreenSize.Medium);
            }
            else if (state.breakpoints[Breakpoints.Large]) {
                this.screenSizeSource.next(ScreenSize.Large);
            }
            else if (state.breakpoints[Breakpoints.XLarge]) {
                this.screenSizeSource.next(ScreenSize.XLarge);
            }
        });
        this.sub.add(sub);
    }
    ngOnDestroy() {
        this.sub.unsubscribe();
    }
}
ScreenSizeService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ScreenSizeService, deps: [{ token: i1$7.BreakpointObserver }], target: i0.ɵɵFactoryTarget.Injectable });
ScreenSizeService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ScreenSizeService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ScreenSizeService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1$7.BreakpointObserver }]; } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `Grid` extends `Collection`, and is meant for rendering items in a grid
 * layout. The component dynamically calculates the width of each item in the
 * grid and determines how many items to display in each row based on the space
 * available. You must define the template for each item in the grid in the
 * template where you intend to include this component. A `Sorter` is rendered
 * above the data grid, which is meant to allow users to well sort the data in
 * the grid based on the provided `field` options users should be able to sort
 * the data on.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-grid [data]="data" [fields]="fields">
 *     <ng-template #model let-model="model">
 *        <mat-card>
 *            <mat-card-title>
 *                {{model.id}} Title
 *            </mat-card-title>
 *            <mat-card-content>
 *                Content for dummy object {{model.id}}
 *            </mat-card-content>
 *       </mat-card>
 *     </ng-template>
 * </ngx-mat-grid>
 * ```
 * ```typescript
 * @Component({
 *     selector: 'basic-grid-usage-example',
 *     templateUrl: './basic-grid-usage-example.html'
 * }) export class BasicGridUsageExample {
 *     data: Task[] = [...];
 *     fields: string[] = ['id'];
 * }
 * ```
 */
class GridComponent extends CollectionComponent {
    constructor(screenSizeService, changeDetectorRef, selectionService) {
        super(selectionService);
        this.screenSizeService = screenSizeService;
        this.changeDetectorRef = changeDetectorRef;
        /** The number of columns to render in the grid. */
        this.cols = 2;
    }
    ngAfterViewChecked() {
        // calculate the number of columns that can fit comfortably in the grid
        // using the width of the grid and each grid tile once all children and
        // content have rendered; this seems really hackish since this lifecycle
        // hook is run quite a bit, the way tileWidth is determined, and need
        // for detectChanges to fix ExpressionChangedAfterItHasBeenCheckedError
        this.screenSizeService.screenSize.subscribe(() => {
            if (this.tiles.first) {
                // get the width of the grid element
                const width = this.grid.nativeElement.offsetWidth;
                // first child of MatGridTile is figure, then it is component passed
                // in in template (i.e. the component we are looking for when calculating
                // number of columns)
                const tileWidth = this.tiles.first.nativeElement.children[0].children[0]
                    .offsetWidth;
                this.cols = Math.floor(width / (tileWidth + 2));
                this.changeDetectorRef.detectChanges();
            }
        });
    }
}
GridComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: GridComponent, deps: [{ token: ScreenSizeService }, { token: i0.ChangeDetectorRef }, { token: SelectionService }], target: i0.ɵɵFactoryTarget.Component });
GridComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: GridComponent, selector: "ngx-mat-grid", viewQueries: [{ propertyName: "grid", first: true, predicate: MatGridList, descendants: true, read: ElementRef }, { propertyName: "sort$", first: true, predicate: SorterComponent, descendants: true }, { propertyName: "tiles", predicate: MatGridTile, descendants: true, read: ElementRef }], usesInheritance: true, ngImport: i0, template: "<div fxLayout=\"row\" fxLayoutAlign=\"center center\" fxLayoutGap=\"10px\">\n    <mat-checkbox class=\"marker-checkbox-select-all\"\n        (change)=\"masterToggle()\"\n        [checked]=\"selection.hasValue() && isAllSelected()\"\n        [indeterminate]=\"selection.hasValue() && !isAllSelected()\">\n    </mat-checkbox>\n    <ngx-mat-sorter [options]=\"fields\"></ngx-mat-sorter>\n    <div fxFlex></div>\n</div>\n<mat-grid-list *ngIf=\"models.length > 0; else noModels\" [cols]=\"cols\" gutterSize=\"2\">\n    <div *ngFor=\"let model of models; index as i\">\n        <mat-grid-tile>\n            <div fxLayout=\"column\" fxLayoutGap=\"10px\">\n                <ng-container\n                    *ngTemplateOutlet=\"template; context: { model: model }\">\n                </ng-container>\n                <div fxLayout=\"row\" fxLayoutAlign=\"center center\" fxLayoutGap=\"10px\">\n                    <mat-checkbox class=\"marker-checkbox-row-select\"\n                        (click)=\"$event.stopPropagation()\"\n                        (change)=\"onRowSelected(model);\"\n                        [checked]=\"selection.isSelected(model)\">\n                    </mat-checkbox>\n                    <div fxLayout=\"row\">\n                        <button *ngFor=\"let button of collectionButtons\"\n                            class=\"button-marker-{{button.click}}\"\n                            (click)=\"onActionButtonClick(button.click, model)\"\n                            mat-icon-button>\n                            <fa-icon [icon]=\"button.icon\"></fa-icon>\n                            <div class=\"mat-button-focus-overlay\"></div>\n                            <div class=\"mat-button-ripple mat-ripple\"></div>\n                        </button>\n                    </div>\n                </div>\n            </div>\n        </mat-grid-tile> \n    </div>\n</mat-grid-list>\n<ng-template #noModels>\n    <h2>No data to display</h2>\n</ng-template>\n", styles: [""], components: [{ type: i1$3.MatCheckbox, selector: "mat-checkbox", inputs: ["disableRipple", "color", "tabIndex", "aria-label", "aria-labelledby", "aria-describedby", "id", "required", "labelPosition", "name", "value", "checked", "disabled", "indeterminate"], outputs: ["change", "indeterminateChange"], exportAs: ["matCheckbox"] }, { type: SorterComponent, selector: "ngx-mat-sorter", inputs: ["options"] }, { type: i5$2.MatGridList, selector: "mat-grid-list", inputs: ["cols", "gutterSize", "rowHeight"], exportAs: ["matGridList"] }, { type: i5$2.MatGridTile, selector: "mat-grid-tile", inputs: ["rowspan", "colspan"], exportAs: ["matGridTile"] }, { type: i1$2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i2.FaIconComponent, selector: "fa-icon", inputs: ["icon", "title", "spin", "pulse", "mask", "styles", "flip", "size", "pull", "border", "inverse", "symbol", "rotate", "fixedWidth", "classes", "transform", "a11yRole"] }], directives: [{ type: i5.DefaultLayoutDirective, selector: "  [fxLayout], [fxLayout.xs], [fxLayout.sm], [fxLayout.md],  [fxLayout.lg], [fxLayout.xl], [fxLayout.lt-sm], [fxLayout.lt-md],  [fxLayout.lt-lg], [fxLayout.lt-xl], [fxLayout.gt-xs], [fxLayout.gt-sm],  [fxLayout.gt-md], [fxLayout.gt-lg]", inputs: ["fxLayout", "fxLayout.xs", "fxLayout.sm", "fxLayout.md", "fxLayout.lg", "fxLayout.xl", "fxLayout.lt-sm", "fxLayout.lt-md", "fxLayout.lt-lg", "fxLayout.lt-xl", "fxLayout.gt-xs", "fxLayout.gt-sm", "fxLayout.gt-md", "fxLayout.gt-lg"] }, { type: i5.DefaultLayoutAlignDirective, selector: "  [fxLayoutAlign], [fxLayoutAlign.xs], [fxLayoutAlign.sm], [fxLayoutAlign.md],  [fxLayoutAlign.lg], [fxLayoutAlign.xl], [fxLayoutAlign.lt-sm], [fxLayoutAlign.lt-md],  [fxLayoutAlign.lt-lg], [fxLayoutAlign.lt-xl], [fxLayoutAlign.gt-xs], [fxLayoutAlign.gt-sm],  [fxLayoutAlign.gt-md], [fxLayoutAlign.gt-lg]", inputs: ["fxLayoutAlign", "fxLayoutAlign.xs", "fxLayoutAlign.sm", "fxLayoutAlign.md", "fxLayoutAlign.lg", "fxLayoutAlign.xl", "fxLayoutAlign.lt-sm", "fxLayoutAlign.lt-md", "fxLayoutAlign.lt-lg", "fxLayoutAlign.lt-xl", "fxLayoutAlign.gt-xs", "fxLayoutAlign.gt-sm", "fxLayoutAlign.gt-md", "fxLayoutAlign.gt-lg"] }, { type: i5.DefaultLayoutGapDirective, selector: "  [fxLayoutGap], [fxLayoutGap.xs], [fxLayoutGap.sm], [fxLayoutGap.md],  [fxLayoutGap.lg], [fxLayoutGap.xl], [fxLayoutGap.lt-sm], [fxLayoutGap.lt-md],  [fxLayoutGap.lt-lg], [fxLayoutGap.lt-xl], [fxLayoutGap.gt-xs], [fxLayoutGap.gt-sm],  [fxLayoutGap.gt-md], [fxLayoutGap.gt-lg]", inputs: ["fxLayoutGap", "fxLayoutGap.xs", "fxLayoutGap.sm", "fxLayoutGap.md", "fxLayoutGap.lg", "fxLayoutGap.xl", "fxLayoutGap.lt-sm", "fxLayoutGap.lt-md", "fxLayoutGap.lt-lg", "fxLayoutGap.lt-xl", "fxLayoutGap.gt-xs", "fxLayoutGap.gt-sm", "fxLayoutGap.gt-md", "fxLayoutGap.gt-lg"] }, { type: i5.DefaultFlexDirective, selector: "  [fxFlex], [fxFlex.xs], [fxFlex.sm], [fxFlex.md],  [fxFlex.lg], [fxFlex.xl], [fxFlex.lt-sm], [fxFlex.lt-md],  [fxFlex.lt-lg], [fxFlex.lt-xl], [fxFlex.gt-xs], [fxFlex.gt-sm],  [fxFlex.gt-md], [fxFlex.gt-lg]", inputs: ["fxFlex", "fxFlex.xs", "fxFlex.sm", "fxFlex.md", "fxFlex.lg", "fxFlex.xl", "fxFlex.lt-sm", "fxFlex.lt-md", "fxFlex.lt-lg", "fxFlex.lt-xl", "fxFlex.gt-xs", "fxFlex.gt-sm", "fxFlex.gt-md", "fxFlex.gt-lg"] }, { type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i4.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: GridComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-grid', template: "<div fxLayout=\"row\" fxLayoutAlign=\"center center\" fxLayoutGap=\"10px\">\n    <mat-checkbox class=\"marker-checkbox-select-all\"\n        (change)=\"masterToggle()\"\n        [checked]=\"selection.hasValue() && isAllSelected()\"\n        [indeterminate]=\"selection.hasValue() && !isAllSelected()\">\n    </mat-checkbox>\n    <ngx-mat-sorter [options]=\"fields\"></ngx-mat-sorter>\n    <div fxFlex></div>\n</div>\n<mat-grid-list *ngIf=\"models.length > 0; else noModels\" [cols]=\"cols\" gutterSize=\"2\">\n    <div *ngFor=\"let model of models; index as i\">\n        <mat-grid-tile>\n            <div fxLayout=\"column\" fxLayoutGap=\"10px\">\n                <ng-container\n                    *ngTemplateOutlet=\"template; context: { model: model }\">\n                </ng-container>\n                <div fxLayout=\"row\" fxLayoutAlign=\"center center\" fxLayoutGap=\"10px\">\n                    <mat-checkbox class=\"marker-checkbox-row-select\"\n                        (click)=\"$event.stopPropagation()\"\n                        (change)=\"onRowSelected(model);\"\n                        [checked]=\"selection.isSelected(model)\">\n                    </mat-checkbox>\n                    <div fxLayout=\"row\">\n                        <button *ngFor=\"let button of collectionButtons\"\n                            class=\"button-marker-{{button.click}}\"\n                            (click)=\"onActionButtonClick(button.click, model)\"\n                            mat-icon-button>\n                            <fa-icon [icon]=\"button.icon\"></fa-icon>\n                            <div class=\"mat-button-focus-overlay\"></div>\n                            <div class=\"mat-button-ripple mat-ripple\"></div>\n                        </button>\n                    </div>\n                </div>\n            </div>\n        </mat-grid-tile> \n    </div>\n</mat-grid-list>\n<ng-template #noModels>\n    <h2>No data to display</h2>\n</ng-template>\n", styles: [""] }]
        }], ctorParameters: function () { return [{ type: ScreenSizeService }, { type: i0.ChangeDetectorRef }, { type: SelectionService }]; }, propDecorators: { grid: [{
                type: ViewChild,
                args: [MatGridList, { read: ElementRef }]
            }], sort$: [{
                type: ViewChild,
                args: [SorterComponent]
            }], tiles: [{
                type: ViewChildren,
                args: [MatGridTile, { read: ElementRef }]
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `GridWithIconButtonsPaginatorBar` is a wrapper for the `PagedGrid` and
 * `IconButtonsWithPaginator` toolbar components. It allows you to define and
 * render your data models in a grid with built in paging and basic data
 * management buttons with easy to use handlers for when the user clicks a
 * button in the toolbar or the collection. The toolbar is rendered above the
 * data grid.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-grid-with-icon-buttons-paginator-bar
 *     [fields]="fields"
 *     [toolbarButtons]="toolbarButtons"
 *     (buttonClick)="onButtonClick($event)"
 *     class="marker-paged-list">
 *     <ngx-mat-grid [collectionButtons]="collectionButtons" [data]="data" #collection>
 *         <ng-template #model let-model="model">
 *             <mat-card>
 *                 <mat-card-title>
 *                     {{model.id}} Title
 *                 </mat-card-title>
 *                 <mat-card-content>
 *                     Content for dummy object {{model.id}}
 *                 </mat-card-content>
 *             </mat-card>
 *         </ng-template>
 *     </ngx-mat-grid>
 * </ngx-mat-grid-with-icon-buttons-paginator-bar>
 * ```
 * ```typescript
 * @Component({
 *     selector: 'basic-grid-usage-example',
 *     templateUrl: './basic-grid-usage-example.html'
 * }) export class BasicGridUsageExample {
 *     data: Task[] = [...];
 *     fields: string[] = ['id'];
 *     // either create your own, or use copies of buttons provided for both
 *     // collection and toolbar; use copies without references in case you
 *     // have multiple collections to render so each one gets their own
 *     // buttons and own subscriptions (otherwise events in one table will
 *     // affect buttons in others)
 *     collectionButtons: CollectionButton[] = [
 *         {...EDIT_BUTTON}, {...DELETE_BUTTON}
 *     ];
 *     toolbarButtons: ToolbarButton[] = [
 *         {...CREATE_TOOLBAR_BUTTON}, {...EDIT_TOOLBAR_BUTTON}, {...DELETE_TOOLBAR_BUTTON}
 *     ];
 *
 *     onButtonClick(btnClick: ButtonClick): void {
 *         if (btnClick.click === 'create') {
 *             // handle create
 *         } else if (btnClick.click === 'edit') {
 *             // handle edit
 *         } else if (btnClick.click === 'delete') {
 *             // handle delete
 *         }
 *     }
 * }
 * ```
 */
class GridWithIconButtonsPaginatorBarComponent extends PagedCollectionWithIconToolbarComponent {
}
GridWithIconButtonsPaginatorBarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: GridWithIconButtonsPaginatorBarComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
GridWithIconButtonsPaginatorBarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: GridWithIconButtonsPaginatorBarComponent, selector: "ngx-mat-grid-with-icon-buttons-paginator-bar", queries: [{ propertyName: "collection", first: true, predicate: GridComponent, descendants: true }], usesInheritance: true, ngImport: i0, template: "<ngx-mat-icon-buttons-with-paginator\n    [buttons]=\"toolbarButtons\"\n    [displaySelectAll]=\"false\"\n    [displaySort]=\"false\"\n    [length]=\"length\"\n    [multiple]=\"multiple\"\n    (buttonClick)=\"onToolbarButtonClick($event)\">\n</ngx-mat-icon-buttons-with-paginator>\n<!-- grid -->\n<ng-content></ng-content>\n", styles: [""], components: [{ type: IconButtonsWithPaginatorComponent, selector: "ngx-mat-icon-buttons-with-paginator", inputs: ["buttons", "displaySelectAll", "displaySort", "fields", "isAllSelected", "length", "multiple", "pageSize", "selection"], outputs: ["buttonClick", "masterToggle"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: GridWithIconButtonsPaginatorBarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-grid-with-icon-buttons-paginator-bar', template: "<ngx-mat-icon-buttons-with-paginator\n    [buttons]=\"toolbarButtons\"\n    [displaySelectAll]=\"false\"\n    [displaySort]=\"false\"\n    [length]=\"length\"\n    [multiple]=\"multiple\"\n    (buttonClick)=\"onToolbarButtonClick($event)\">\n</ngx-mat-icon-buttons-with-paginator>\n<!-- grid -->\n<ng-content></ng-content>\n", styles: [""] }]
        }], propDecorators: { collection: [{
                type: ContentChild,
                args: [GridComponent]
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `PagedGrid` is a wrapper for the `Grid` component which adds paging
 * capabilities. Like the `Grid`, you must define the template for each item in
 * the grid in the template where you intend to include this component.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-paged-grid [data]="tasks" class="marker-paged-grid">
 *     <ng-template #model let-model="model">
 *         <mat-card>
 *             <mat-card-title>
 *                 {{model.id}} Title
 *             </mat-card-title>
 *             <mat-card-content>
 *                 Content for dummy object {{model.id}}
 *             </mat-card-content>
 *         </mat-card>
 *     </ng-template>
 * </ngx-mat-paged-grid>
 * ```
 * ```typescript
 * import {Component} from '@angular/core';
 * import {Task} from './tasks'; // this should extend JsonModel
 *
 * @Component({
 *     selector: 'basic-usage-example',
 *     templateUrl: './basic-usage-example.html'
 * }) UsingBasicUsageExample {
 *     tasks: Task[] = [...];
 * }
 * ```
 */
class PagedGridComponent extends PagedCollectionComponent {
}
PagedGridComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedGridComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
PagedGridComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: PagedGridComponent, selector: "ngx-mat-paged-grid", usesInheritance: true, ngImport: i0, template: "<ngx-mat-grid \n    [collectionButtons]=\"collectionButtons\"\n    [dataSource]=\"dataSource$\"\n    [fields]=\"fields\"\n    #collection>\n    <ng-template #model let-model=\"model\">\n        <ng-container \n            *ngTemplateOutlet=\"template; context: { model: model }\">\n        </ng-container>\n    </ng-template>\n</ngx-mat-grid>\n<mat-paginator [length]=\"length\"\n                [pageSize]=\"pageSize\" \n                [pageSizeOptions]=\"[15, 25, 50, 75, 100]\">\n</mat-paginator>\n", styles: [""], components: [{ type: GridComponent, selector: "ngx-mat-grid" }, { type: i2$3.MatPaginator, selector: "mat-paginator", inputs: ["disabled"], exportAs: ["matPaginator"] }], directives: [{ type: i4.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedGridComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-paged-grid', template: "<ngx-mat-grid \n    [collectionButtons]=\"collectionButtons\"\n    [dataSource]=\"dataSource$\"\n    [fields]=\"fields\"\n    #collection>\n    <ng-template #model let-model=\"model\">\n        <ng-container \n            *ngTemplateOutlet=\"template; context: { model: model }\">\n        </ng-container>\n    </ng-template>\n</ngx-mat-grid>\n<mat-paginator [length]=\"length\"\n                [pageSize]=\"pageSize\" \n                [pageSizeOptions]=\"[15, 25, 50, 75, 100]\">\n</mat-paginator>\n", styles: [""] }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `PagedGridWithRaisedButtonsBar` is a wrapper for the `PagedGrid` and
 * `RaisedButtonsToolbar` toolbar components. It allows you to define and
 * render your data models in a grid with built in paging and basic data
 * management buttons with easy to use handlers for when the user clicks a
 * button in the toolbar or the collection. The toolbar is rendered above the
 * data grid, and the `MatPaginator` is rendered below the data grid.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-paged-grid-with-raised-buttons-bar
 *     [fields]="fields"
 *     [toolbarButtons]="toolbarButtons"
 *     (buttonClick)="onButtonClick($event)"
 *     class="marker-paged-list">
 *     <ngx-mat-grid [collectionButtons]="collectionButtons" [data]="data" #collection>
 *         <ng-template #model let-model="model">
 *             <mat-card>
 *                 <mat-card-title>
 *                     {{model.id}} Title
 *                 </mat-card-title>
 *                 <mat-card-content>
 *                     Content for dummy object {{model.id}}
 *                 </mat-card-content>
 *             </mat-card>
 *         </ng-template>
 *     </ngx-mat-grid>
 * </ngx-mat-paged-grid-with-raised-buttons-bar>
 * ```
 * ```typescript
 * @Component({
 *     selector: 'basic-grid-usage-example',
 *     templateUrl: './basic-grid-usage-example.html'
 * }) export class BasicGridUsageExample {
 *     data: Task[] = [...];
 *     fields: string[] = ['id'];
 *     // either create your own, or use copies of buttons provided for both
 *     // collection and toolbar; use copies without references in case you
 *     // have multiple collections to render so each one gets their own
 *     // buttons and own subscriptions (otherwise events in one table will
 *     // affect buttons in others)
 *     collectionButtons: CollectionButton[] = [
 *         {...EDIT_BUTTON}, {...DELETE_BUTTON}
 *     ];
 *     toolbarButtons: ToolbarButton[] = [
 *         {...CREATE_TOOLBAR_BUTTON}, {...EDIT_TOOLBAR_BUTTON}, {...DELETE_TOOLBAR_BUTTON}
 *     ];
 *
 *     onButtonClick(btnClick: ButtonClick): void {
 *         if (btnClick.click === 'create') {
 *             // handle create
 *         } else if (btnClick.click === 'edit') {
 *             // handle edit
 *         } else if (btnClick.click === 'delete') {
 *             // handle delete
 *         }
 *     }
 * }
 * ```
 */
class PagedGridWithRaisedButtonsBarComponent extends PagedCollectionWithRaisedButtonToolbarComponent {
}
PagedGridWithRaisedButtonsBarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedGridWithRaisedButtonsBarComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
PagedGridWithRaisedButtonsBarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: PagedGridWithRaisedButtonsBarComponent, selector: "ngx-mat-paged-grid-with-raised-buttons-bar", usesInheritance: true, ngImport: i0, template: "<ngx-mat-button-toolbar \n    [buttons]=\"toolbarButtons\"\n    (buttonClick)=\"onToolbarButtonClick($event)\"\n    #toolbar>\n    <ng-content select=\"[filter]\"></ng-content>\n</ngx-mat-button-toolbar>\n<!-- paged grid -->\n<ng-content select=\"[collection]\"></ng-content>\n", styles: [""], components: [{ type: ButtonToolbarComponent, selector: "ngx-mat-button-toolbar", inputs: ["buttons", "buttonAlign"], outputs: ["buttonClick"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedGridWithRaisedButtonsBarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-paged-grid-with-raised-buttons-bar', template: "<ngx-mat-button-toolbar \n    [buttons]=\"toolbarButtons\"\n    (buttonClick)=\"onToolbarButtonClick($event)\"\n    #toolbar>\n    <ng-content select=\"[filter]\"></ng-content>\n</ngx-mat-button-toolbar>\n<!-- paged grid -->\n<ng-content select=\"[collection]\"></ng-content>\n", styles: [""] }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
class GridModule {
}
GridModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: GridModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
GridModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: GridModule, declarations: [GridComponent,
        PagedGridComponent,
        PagedGridWithRaisedButtonsBarComponent,
        GridWithIconButtonsPaginatorBarComponent], imports: [CommonModule,
        FlexLayoutModule,
        MatButtonModule,
        MatCheckboxModule,
        MatGridListModule,
        MatPaginatorModule,
        FontAwesomeModule,
        CollectionModule,
        ToolbarModule] });
GridModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: GridModule, imports: [[
            CommonModule,
            FlexLayoutModule,
            MatButtonModule,
            MatCheckboxModule,
            MatGridListModule,
            MatPaginatorModule,
            FontAwesomeModule,
            CollectionModule,
            ToolbarModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: GridModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        GridComponent,
                        PagedGridComponent,
                        PagedGridWithRaisedButtonsBarComponent,
                        GridWithIconButtonsPaginatorBarComponent
                    ],
                    imports: [
                        CommonModule,
                        FlexLayoutModule,
                        MatButtonModule,
                        MatCheckboxModule,
                        MatGridListModule,
                        MatPaginatorModule,
                        FontAwesomeModule,
                        CollectionModule,
                        ToolbarModule
                    ]
                }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The LoadingService handles tracking active requests so any subscribers can
 * manage when things like a loading spinner should be displayed. The service
 * uses a map to track requests to different URLs to ensure loading is not set
 * to false before all requests have completed.
 *
 * The `Loading` component utilizes this service to determine when to render a
 * spinner. If you are using the `DefaultLayout`, the `Loading` component is
 * included there, so you should not need to worry about subscribing to load
 * changes. As long as you configure the service (preferably using an
 * interceptor), you should see a spinner whenever HTTP requests are made (as
 * long as the request takes a sufficient amount of time; if the request is
 * quick you likely will not see the spinner).
 *
 * @overviewDetails
 * #### Configure the Service
 *
 * To configure the service you must have a way to determine when HTTP requests
 * are initiated and when they complete. The best way to handle that is with an
 * interceptor (although you could use a service that acts as a wrapper for
 * `HttpClient` I suppose). Below is an example of how to configure the service
 * to handle requests using an interceptor.
 *
 * ```typescript
 * import {Injectable} from '@angular/core';
 * import {HttpEvent, HttpHandler, HttpInterceptor, HttpRequest, HttpResponse} from '@angular/common/http';
 * import {LoadingService} from '@ngx-material-dashboard/widgets';
 * import {Observable, throwError} from 'rxjs';
 * import {catchError, map} from 'rxjs/operators';
 *
 * @Injectable()
 * export class LoadingInterceptor implements HttpInterceptor {
 *
 *    constructor(private loadingService: LoadingService) {}
 *
 *    intercept(request: HttpRequest<any>, next: HttpHandler): Observable<HttpEvent<any>> {
 *         // mark the requests URL as loading
 *         this.loadingService.setLoading(true, request.url);
 *         return next.handle(request).pipe(catchError((err) => {
 *             // handle when error occurs (still need to mark requests URL to
 *             // not loading; otherwise you end up with never-ending spinner
 *             // when errors occur)
 *             this.loadingService.setLoading(false, request.url);
 *            // throw error so your app can handle accordingly
 *            return throwError(() => err);
 *         })).pipe(map<HttpEvent<any>, any>((evt: HttpEvent<any>) => {
 *             if (evt instanceof HttpResponse) {
 *                 // handle success response; mark requests URL not loading
 *                 this.loadingService.setLoading(false, request.url);
 *             }
 *             return evt;
 *         }));
 *     }
 * }
 * ```
 *
 * When requests start they are added to the map of requests used by the
 * `LoadingService`, and when they complete they are removed from the map. The
 * loading state is true if there are any URLs in the map, and false if the map
 * is empty. This code was taken directly from below blog.
 * https://medium.com/swlh/angular-loading-spinner-using-http-interceptor-63c1bb76517b
 *
 * #### Loading State
 *
 * If you want to render your own spinner component when data is loading you
 * need to subscribe to the `loadingSub` `Observable`. This will return `true`
 * if there is anything loading, otherwise it will return `false`.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <div *ngIf="loading">
 *     <!-- some sort of spinner or gif -->
 * </div>
 * ```
 * ```typescript
 * import {Component, OnDestroy, OnInit} from '@angular/core';
 * import {LoadingService} from '@ngx-material-dashboard/widgets';
 * import {Subscription} from 'rxjs';
 *
 * @Component({
 *     selector: 'loading-service-usage-example',
 *     templateUrl: './loading-service-usage-example.html'
 * })
 * export class LoadingServiceUsageExample implements OnDestroy, OnInit {
 *     loading: boolean;
 *     sub: Subscription;
 *
 *     constructor(private loadingService: LoadingService) {
 *         this.loading = false;
 *         this.sub = new Subscription();
 *     }
 *
 *     ngOnInit() {
 *         const sub = this.loadingService.loadingSub.subscribe(loadingState => {
 *            this.loading = loadingState;
 *         });
 *         sub.add(sub);
 *     }
 *
 *     ngOnDestroy() {
 *         this.sub.unsubscribe();
 *     }
 * }
 * ```
 *
 */
class LoadingService {
    constructor() {
        /**
         * Observable for emitting whether there is an active request. When true
         * there is at least one active request, when false there are no active
         * requests. Defaults to false (i.e. no active requests).
         */
        this.loadingSub = new BehaviorSubject(false);
        /** Contains in-progress loading requests. */
        this.loadingMap = new Map();
    }
    /**
     * Sets the loadingSub property value based on the following:
     * - If loading is true, add the provided url to the loadingMap with a true
     * value, set loadingSub value to true
     * - If loading is false, remove the loadingMap entry and only when the map
     * is empty will we set loadingSub to false
     *
     * This pattern ensures if there are multiple requests awaiting completion,
     * we don't set loading to false before other requests have completed. At
     * the moment, this function is only called from the @link{HttpRequestInterceptor}.
     *
     * @param loading Boolean value to set loadingSub to.
     * @param url The URL that is loading.
     */
    setLoading(loading, url) {
        // update map and loadingSub according to given parameters
        if (loading === true) {
            // add URL to map of URLs
            this.loadingMap.set(url, loading);
            // emit true so subscribers can display loading spinners
            this.loadingSub.next(true);
        }
        else if (loading === false && this.loadingMap.has(url)) {
            // remove URL from map of loading URLs
            this.loadingMap.delete(url);
        }
        if (this.loadingMap.size === 0) {
            // emit false so subscribers can hide loading spinners if there are
            // no URLs in the map of loading URLs
            this.loadingSub.next(false);
        }
    }
}
LoadingService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: LoadingService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
LoadingService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: LoadingService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: LoadingService, decorators: [{
            type: Injectable
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A wrapper component for `MatProgressSpinner` that only displays the spinner
 * when HTTP requests are in progress. This component is automatically included
 * in the `DefaultLayout`, so there is no need to include this yourself if you
 * are using that.
 *
 * You may use this component if you are not using the `DefaultLayout`. The
 * `LoadingService` must be conigured for this component to work correctly. See
 * the [LoadingService](/widgets/layout/overview#loading-service) documentation for more info.
 *
 *  @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-loading></ngx-mat-default-loading>
 * <!-- any additional tags -->
 * ```
 * ```typescript
 * import {Component} from '@angular/core';
 *
 * @Component({
 *     selector: 'basic-usage-example',
 *     templateUrl: './basic-usage-example.html'
 * })
 * export class BasicUsageExample {}
 * ```
 */
class LoadingComponent {
    constructor(loadingService) {
        this.loadingService = loadingService;
        this.loading = false;
        this.sub = new Subscription();
    }
    ngOnInit() {
        const sub = this.loadingService.loadingSub.subscribe((loadingState) => {
            this.loading = loadingState;
        });
        sub.add(sub);
    }
    ngOnDestroy() {
        this.sub.unsubscribe();
    }
}
LoadingComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: LoadingComponent, deps: [{ token: LoadingService }], target: i0.ɵɵFactoryTarget.Component });
LoadingComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: LoadingComponent, selector: "ngx-mat-loading", ngImport: i0, template: "<div *ngIf=\"loading\" class=\"loading-wrapper\">\n    <mat-progress-spinner\n        class=\"loading-spinner\"\n        color=\"primary\"\n        mode=\"indeterminate\">\n    </mat-progress-spinner>\n</div>\n", styles: [".loading-wrapper{z-index:100000;position:fixed;background-color:#fff9;display:block;height:100%;width:100%}.loading-spinner{position:absolute;top:50%;left:50%;transform:translate(-50%,-50%)}\n"], components: [{ type: i2$4.MatProgressSpinner, selector: "mat-progress-spinner, mat-spinner", inputs: ["color", "diameter", "strokeWidth", "mode", "value"], exportAs: ["matProgressSpinner"] }], directives: [{ type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: LoadingComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-loading', template: "<div *ngIf=\"loading\" class=\"loading-wrapper\">\n    <mat-progress-spinner\n        class=\"loading-spinner\"\n        color=\"primary\"\n        mode=\"indeterminate\">\n    </mat-progress-spinner>\n</div>\n", styles: [".loading-wrapper{z-index:100000;position:fixed;background-color:#fff9;display:block;height:100%;width:100%}.loading-spinner{position:absolute;top:50%;left:50%;transform:translate(-50%,-50%)}\n"] }]
        }], ctorParameters: function () { return [{ type: LoadingService }]; } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A wrapper component for the `MatNavList` to be used to render in a
 * `MatSidenav`. This provides all necessary logic and styles to highlight and
 * expand `SidenavItems` according to the current route. It also includes an
 * SCSS mixin for you to configure the colors to use for active sidenav items,
 * so you can ensure the sidenav theme matches the rest of your application.
 *
 * The component is automatically included in the `DefaultLayout`. If you use
 * the `DefaultLayout`, the only thing you need to do is define the array of
 * `SidenavItems` and include it as an input in the tag. You may use this
 * component without the `DefaultLayout` if you want to use it to create your
 * own layout.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <div fxLayout="column">
 *     <mat-sidenav-container class="content" fxLayout="row">
 *         <mat-sidenav [mode]="mode">
 *             <ngx-mat-sidenav [sidenavItems]="sidenavItems"></ngx-mat-sidenav>
 *         </mat-sidenav>
 *         <mat-sidenav-content fxFlex>
 *             <router-outlet></router-outlet>
 *         </mat-sidenav-content>
 *     </mat-sidenav-container>
 * </div>
 * ```
 * ```typescript
 * import {Component} from '@angular/core';
 * import {SidenavItem} from '@ngx-material-dashboard/widgets';
 *
 * @Component({
 *     selector: 'basic-usage-example',
 *     templateUrl: './basic-usage-example.html'
 * })
 * export class BasicUsageExample {
 *     mode = 'side';
 *     sidenavItems: SidenavItem[] = [
 *         { queryParams: { isComplete: false }, route: ['tasks'], text: 'Pending', selector: 'pending' },
 *         { queryParams: { isComplete: false, filter: 'overdue' }, route: ['tasks'], text: 'Over Due', selector: 'over-due' },
 *         { queryParams: { isComplete: true }, route: ['tasks'], text: 'Complete', selector: 'complete' }
 *     ];
 * }
 * ```
 *
 * @overviewDetails
 * #### Features
 *
 * The `Sidenav` has several features including the ability to render nested
 * `SidenavItems`, icons with each `SidenavItem`, and custom `tooltips` to
 * render when the user hovers over a `SidenavItem`.
 *
 * ##### Nested SidenavItems
 *
 * The `Sidenav` allows you to define basic or nested `SidenavItems`. A basic
 * `Sidenav` item should have a route defined, while a nested `SidenavItem`
 * should have children defined. Nested `SidenavItems` will expand to display
 * any children. Currently the `Sidenav` will only render 2 levels of
 * `children`, meaning you can only define a parent, child, and grandchildren
 * `SidenavItems`. The grandchildren `SidenavItems` should all define a `route`.
 *
 * ##### Icons
 *
 * You may define a fontawesome icon for each of the items rendered in the
 * `Sidenav`. The icons will be rendered to the left of the text you include
 * for the `SidenavItem`.
 *
 * ##### Tooltip
 *
 * You may define text to render as a `tooltip` for when the user hovers over
 * a `SidenavItem`. The text displayed with the `SidenavItem` itself should be
 * mostly self explanatory, but this allows you to include some additional
 * details to the user when they hover over a `SidenavItem`.
 *
 * See the [Sidenav](/widgets/layout/overview#sidenav) interface documentation for
 * more details on the values to include when defining your `SidenavItems`.
 */
class SidenavComponent {
    constructor(route, router) {
        this.route = route;
        this.router = router;
        /** Angle down icon displayed for expanded sidenav items. */
        this.faAngleDown = faAngleDown;
        /** Angle right icon displayed for collapsed sidenav items. */
        this.faAngleRight = faAngleRight;
        /** Any query params  */
        this.queryParams = {};
        /** The array of items to display in the sidenav. */
        this.sidenavItems$ = [];
        /** Tracks the toggle status for items in sidenav. */
        this.toggle = [];
        this.sub = new Subscription();
    }
    /** The array of items to display in the sidenav. */
    set sidenavItems(sidenavItems) {
        this.sidenavItems$ = sidenavItems;
        this.initSidenavItems();
    }
    ngOnDestroy() {
        this.sub.unsubscribe();
    }
    ngOnInit() {
        this.initSidenavItems();
        const queryParamsSub = this.route.queryParams.subscribe((params) => {
            this.queryParams = params;
            this.initSidenavItems();
        });
        this.sub.add(queryParamsSub);
    }
    /**
     * Returns array of child SidenavItems if they exist for given item.
     *
     * @param item SidenavItem to get children from (if they exist).
     * @returns Children SidenavItems of given item (if they exist).
     */
    getChildrenByItem(item) {
        if ('children' in item) {
            return item.children;
        }
        else {
            return undefined;
        }
    }
    /**
     * Initializes sidenav items and toggle state based on current URL.
     */
    initSidenavItems() {
        let childIndex;
        const index = this.sidenavItems$.findIndex((item) => {
            if ('children' in item) {
                childIndex = item.children.findIndex((childItem) => {
                    if ('route' in childItem) {
                        return this.router.url.includes(`/${item.selector}/${childItem.route
                            .join('/')
                            .replace('./', '')}`);
                    }
                    else {
                        return this.router.url.includes(`/${item.selector}/${childItem.selector}`);
                    }
                });
                if (childIndex >= 0) {
                    return true;
                    // I don't think below else if ever comes to pass or even makes sense
                    // really since a sidenavItem with children will most likely not have
                    // a route
                    // } else if (item.route) {
                    //     return this.router.url.includes(`/${item.route.join('/').replace('./', '')}`);
                }
                else {
                    return (this.router.url.endsWith(`/${item.selector}`) ||
                        this.router.url.includes(`/${item.selector}/`));
                }
            }
            else {
                return this.router.url.includes(`/${item.route.join('/').replace('./', '')}`);
            }
        });
        this.toggle = new Array(this.sidenavItems$.length);
        for (let i = 0; i < this.toggle.length; i++) {
            this.toggle[i] = { toggle: index === i, children: [] };
        }
        this.sidenavItems$.forEach((item, i) => {
            if ('children' in item) {
                //this.toggle[i].children = [];
                for (let j = 0; j < item.children.length; j++) {
                    this.toggle[i].children.push(index === i && childIndex === j);
                }
            }
        });
    }
    /**
     * Returns true if the current URL ends with the route in the given
     * SidenavItem. Used to determine when to add the selected-list-item
     * class to a mat-list-item in the sidenav.
     *
     * @param sidenavItem The sidenav item to test against the current URL.
     * @returns true if the current URL ends with the route in the given SidenavItem.
     */
    isActive(sidenavItem, parent) {
        if ('route' in sidenavItem) {
            // remove './' from beggining of the route to avoid issues comparing
            // sidenav route with router.url
            const filteredRoute = sidenavItem.route.filter((it) => it !== './');
            // join filtered route parts
            const route = filteredRoute.join('/');
            if (route === '') {
                return this.router.url === '/';
            }
            else if (!sidenavItem.queryParams) {
                // if url includes route with '/' at end this allows sidenav to
                // be highlighted for child routes from things like tabs and
                // prevents possible multiple sidenav items from getting
                // highlighted in case they have similar routes; checking for
                // endsWith ensures items without child routes are highlighted
                // as well
                return (this.router.url === route ||
                    this.router.url.includes(`/${route}/`) ||
                    this.router.url.endsWith(`/${route}`));
            }
            else {
                const currentRoute = this.router.url.slice(0, this.router.url.indexOf('?'));
                return ((currentRoute === route || currentRoute === `/${route}`) &&
                    this.compareMaps(this.queryParams, sidenavItem.queryParams));
            }
        }
        else {
            return false;
        }
    }
    /**
     * Returns true if the sidenav item associated with the given index in the
     * toggle property is toggled.
     *
     * @param i The index of the sidenav item in the toggle property.
     * @returns True if the sidenav item is toggled.
     */
    isToggled(i) {
        if (this.toggle && this.toggle[i]) {
            return this.toggle[i].toggle;
        }
        else {
            return false;
        }
    }
    /**
     * Returns true if the child sidenav item associated with the given parent
     * index and child index in the toggle property is toggled.
     *
     * @param i The index of the parent sidenav item.
     * @param iChild The index of the child sidenav item.
     * @returns True if the child sidenav item is toggled.
     */
    isChildToggled(i, iChild) {
        const children = this.toggle[i].children;
        if (children && children[iChild]) {
            return children[iChild];
        }
        else {
            return false;
        }
    }
    /**
     * Navigates to the route of the given sidenavItem (if it exists).
     *
     * @param index The sidenav item selected.
     */
    select(index) {
        const sidenavItem = this.sidenavItems$[index];
        if ('route' in sidenavItem) {
            if (sidenavItem.queryParams) {
                this.router.navigate(sidenavItem.route, {
                    queryParams: sidenavItem.queryParams
                });
            }
            else {
                this.router.navigate(sidenavItem.route);
            }
        }
        else if (this.toggle[index]) {
            this.toggle[index].toggle = !this.toggle[index].toggle;
        }
    }
    /**
     * Navigates to the route of the given child sidenav item.
     *
     * @param index The index of the parent.
     * @param childIndex The index of the child.
     */
    selectChild(index, childIndex) {
        const sidenavItem = this.sidenavItems$[index];
        if ('children' in sidenavItem) {
            const children = sidenavItem.children;
            const child = children[childIndex];
            if ('route' in child) {
                if (child.route && child.queryParams) {
                    this.router.navigate(child.route, {
                        queryParams: child.queryParams
                    });
                }
                else if (child.route) {
                    this.router.navigate(child.route);
                }
            }
            else {
                const gChildren = child.children;
                const toggleChildren = this.toggle[index].children;
                if (gChildren && toggleChildren) {
                    toggleChildren[childIndex] = !toggleChildren[childIndex];
                }
            }
        }
    }
    /**
     * Navigates to the route of the given grandchild.
     *
     * @param index The index of the parent.
     * @param childIndex The index of the child.
     * @param grandChildIndex The index of the grandchild.
     */
    selectGrandChild(index, childIndex, grandChildIndex) {
        const parent = this.sidenavItems$[index];
        if ('children' in parent) {
            const children = parent.children;
            const child = children[childIndex];
            if ('children' in child) {
                const gChildren = child.children;
                const gChild = gChildren[grandChildIndex];
                if ('route' in gChild) {
                    if (gChild.queryParams) {
                        this.router.navigate(gChild.route, {
                            queryParams: gChild.queryParams
                        });
                    }
                    else {
                        this.router.navigate(gChild.route);
                    }
                }
            }
        }
    }
    /**
     * Compares the given maps and returns true if they are equal. The given
     * maps are equal if they have the same keys and associated values.
     *
     * @param obj1 A map to compare.
     * @param obj2 Another map to compare.
     * @returns True if the given maps are equal.
     */
    compareMaps(obj1, obj2) {
        const keys1 = Object.keys(obj1), keys2 = Object.keys(obj2);
        let match = true;
        if (keys1.length !== keys2.length)
            return false;
        for (const key of keys1) {
            // handle case obj1[key] is boolean (which are treated as strings
            // in queryParams); TODO probably handle case for when obj1[key] is
            // number... any other cases? parameters with spaces?
            const boolVal = obj1[key].toLowerCase() === 'true';
            if (obj1[key] !== obj2[key] && boolVal !== obj2[key]) {
                match = false;
                break;
            }
        }
        return match;
    }
}
SidenavComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: SidenavComponent, deps: [{ token: i1.ActivatedRoute }, { token: i1.Router }], target: i0.ɵɵFactoryTarget.Component });
SidenavComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: SidenavComponent, selector: "ngx-mat-sidenav", inputs: { sidenavItems: "sidenavItems" }, ngImport: i0, template: "<mat-nav-list>\n    <div *ngFor=\"let item of sidenavItems$; let i = index\">\n        <mat-list-item class=\"marker-list-item-button-{{item.selector}}\"\n                        [class.selected-list-item]=\"isActive(item)\"\n                        (click)=\"select(i)\">\n            <div *ngIf=\"getChildrenByItem(item) !== undefined\">\n                <fa-icon *ngIf=\"!isToggled(i); else angleDown\" [icon]=\"faAngleRight\" class=\"marker-angle-right\"></fa-icon>\n                <ng-template #angleDown>\n                    <fa-icon [icon]=\"faAngleDown\" class=\"marker-angle-down\"></fa-icon>\n                </ng-template>\n            </div>        \n            <span fxFlex=\"0 0 auto\" class=\"marker-list-item\">\n                <fa-icon *ngIf=\"item.icon\" [icon]=\"item.icon\" [ngClass]=\"{ 'pl-2': getChildrenByItem(item) && item.icon }\"></fa-icon>\n                <span class=\"pl-2 marker-list-item-text\">{{item.text}}</span>\n            </span>\n        </mat-list-item>\n        <div *ngIf=\"isToggled(i)\">\n            <div *ngFor=\"let child of getChildrenByItem(item); let iChild = index\">\n                <mat-list-item class=\"marker-list-item-button-{{child.selector}}\"\n                               [class.selected-list-item]=\"isActive(child)\"\n                               (click)=\"selectChild(i, iChild)\">\n                    <div *ngIf=\"getChildrenByItem(child) !== undefined\" class=\"pl-4\">\n                        <fa-icon *ngIf=\"!isChildToggled(i, iChild); else childAngleDown\" [icon]=\"faAngleRight\" class=\"marker-angle-right\"></fa-icon>\n                        <ng-template #childAngleDown>\n                            <fa-icon [icon]=\"faAngleDown\" class=\"marker-angle-down\"></fa-icon>\n                        </ng-template>\n                    </div>        \n                    <span fxFlex=\"0 0 auto\" class=\"pl-2 marker-list-item\">\n                        <fa-icon *ngIf=\"item.icon\" [icon]=\"item.icon\" [ngClass]=\"{ 'pl-2': getChildrenByItem(item) && item.icon }\"></fa-icon>\n                        <span class=\"marker-list-item-text\">{{child.text}}</span>\n                    </span>\n                </mat-list-item>\n                <div *ngIf=\"isChildToggled(i, iChild)\">\n                    <div *ngFor=\"let grandChild of getChildrenByItem(child); let iGChild = index\">\n                        <mat-list-item class=\"marker-list-item-button-{{grandChild.selector}}\"\n                            [class.selected-list-item]=\"isActive(grandChild, child)\"\n                            (click)=\"selectGrandChild(i, iChild, iGChild)\">\n                            <span fxFlex=\"0 0 auto\" class=\"marker-list-item pl-5\">\n                                <span class=\"marker-list-item-text\">{{grandChild.text}}</span>\n                            </span>\n                        </mat-list-item>\n                    </div>\n                </div>\n            </div>\n        </div>\n    </div>\n<!--\n    <mat-list-item *ngFor=\"let item of sidenavItems\"\n        class=\"marker-list-item-button-{{item.text}}\"\n        [class.selected-list-item]=\"isActive(item)\"\n        (click)=\"select(item)\">\n            <span fxFlex=\"0 0 auto\">\n                <fa-icon *ngIf=\"item.icon\" [icon]=\"item.icon\"></fa-icon>\n                <span class=\"marker-list-item-text\">{{item.text}}</span>\n            </span>\n    </mat-list-item>\n-->\n</mat-nav-list>\n", styles: [".mat-list-item{box-sizing:border-box;-moz-box-sizing:border-box;-webkit-box-sizing:border-box;border-right:3px solid transparent}.mat-nav-list{padding-top:0}\n"], components: [{ type: i2$5.MatNavList, selector: "mat-nav-list", inputs: ["disableRipple", "disabled"], exportAs: ["matNavList"] }, { type: i2$5.MatListItem, selector: "mat-list-item, a[mat-list-item], button[mat-list-item]", inputs: ["disableRipple", "disabled"], exportAs: ["matListItem"] }, { type: i2.FaIconComponent, selector: "fa-icon", inputs: ["icon", "title", "spin", "pulse", "mask", "styles", "flip", "size", "pull", "border", "inverse", "symbol", "rotate", "fixedWidth", "classes", "transform", "a11yRole"] }], directives: [{ type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i5.DefaultFlexDirective, selector: "  [fxFlex], [fxFlex.xs], [fxFlex.sm], [fxFlex.md],  [fxFlex.lg], [fxFlex.xl], [fxFlex.lt-sm], [fxFlex.lt-md],  [fxFlex.lt-lg], [fxFlex.lt-xl], [fxFlex.gt-xs], [fxFlex.gt-sm],  [fxFlex.gt-md], [fxFlex.gt-lg]", inputs: ["fxFlex", "fxFlex.xs", "fxFlex.sm", "fxFlex.md", "fxFlex.lg", "fxFlex.xl", "fxFlex.lt-sm", "fxFlex.lt-md", "fxFlex.lt-lg", "fxFlex.lt-xl", "fxFlex.gt-xs", "fxFlex.gt-sm", "fxFlex.gt-md", "fxFlex.gt-lg"] }, { type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i6.DefaultClassDirective, selector: "  [ngClass], [ngClass.xs], [ngClass.sm], [ngClass.md], [ngClass.lg], [ngClass.xl],  [ngClass.lt-sm], [ngClass.lt-md], [ngClass.lt-lg], [ngClass.lt-xl],  [ngClass.gt-xs], [ngClass.gt-sm], [ngClass.gt-md], [ngClass.gt-lg]", inputs: ["ngClass", "ngClass.xs", "ngClass.sm", "ngClass.md", "ngClass.lg", "ngClass.xl", "ngClass.lt-sm", "ngClass.lt-md", "ngClass.lt-lg", "ngClass.lt-xl", "ngClass.gt-xs", "ngClass.gt-sm", "ngClass.gt-md", "ngClass.gt-lg"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: SidenavComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-sidenav', template: "<mat-nav-list>\n    <div *ngFor=\"let item of sidenavItems$; let i = index\">\n        <mat-list-item class=\"marker-list-item-button-{{item.selector}}\"\n                        [class.selected-list-item]=\"isActive(item)\"\n                        (click)=\"select(i)\">\n            <div *ngIf=\"getChildrenByItem(item) !== undefined\">\n                <fa-icon *ngIf=\"!isToggled(i); else angleDown\" [icon]=\"faAngleRight\" class=\"marker-angle-right\"></fa-icon>\n                <ng-template #angleDown>\n                    <fa-icon [icon]=\"faAngleDown\" class=\"marker-angle-down\"></fa-icon>\n                </ng-template>\n            </div>        \n            <span fxFlex=\"0 0 auto\" class=\"marker-list-item\">\n                <fa-icon *ngIf=\"item.icon\" [icon]=\"item.icon\" [ngClass]=\"{ 'pl-2': getChildrenByItem(item) && item.icon }\"></fa-icon>\n                <span class=\"pl-2 marker-list-item-text\">{{item.text}}</span>\n            </span>\n        </mat-list-item>\n        <div *ngIf=\"isToggled(i)\">\n            <div *ngFor=\"let child of getChildrenByItem(item); let iChild = index\">\n                <mat-list-item class=\"marker-list-item-button-{{child.selector}}\"\n                               [class.selected-list-item]=\"isActive(child)\"\n                               (click)=\"selectChild(i, iChild)\">\n                    <div *ngIf=\"getChildrenByItem(child) !== undefined\" class=\"pl-4\">\n                        <fa-icon *ngIf=\"!isChildToggled(i, iChild); else childAngleDown\" [icon]=\"faAngleRight\" class=\"marker-angle-right\"></fa-icon>\n                        <ng-template #childAngleDown>\n                            <fa-icon [icon]=\"faAngleDown\" class=\"marker-angle-down\"></fa-icon>\n                        </ng-template>\n                    </div>        \n                    <span fxFlex=\"0 0 auto\" class=\"pl-2 marker-list-item\">\n                        <fa-icon *ngIf=\"item.icon\" [icon]=\"item.icon\" [ngClass]=\"{ 'pl-2': getChildrenByItem(item) && item.icon }\"></fa-icon>\n                        <span class=\"marker-list-item-text\">{{child.text}}</span>\n                    </span>\n                </mat-list-item>\n                <div *ngIf=\"isChildToggled(i, iChild)\">\n                    <div *ngFor=\"let grandChild of getChildrenByItem(child); let iGChild = index\">\n                        <mat-list-item class=\"marker-list-item-button-{{grandChild.selector}}\"\n                            [class.selected-list-item]=\"isActive(grandChild, child)\"\n                            (click)=\"selectGrandChild(i, iChild, iGChild)\">\n                            <span fxFlex=\"0 0 auto\" class=\"marker-list-item pl-5\">\n                                <span class=\"marker-list-item-text\">{{grandChild.text}}</span>\n                            </span>\n                        </mat-list-item>\n                    </div>\n                </div>\n            </div>\n        </div>\n    </div>\n<!--\n    <mat-list-item *ngFor=\"let item of sidenavItems\"\n        class=\"marker-list-item-button-{{item.text}}\"\n        [class.selected-list-item]=\"isActive(item)\"\n        (click)=\"select(item)\">\n            <span fxFlex=\"0 0 auto\">\n                <fa-icon *ngIf=\"item.icon\" [icon]=\"item.icon\"></fa-icon>\n                <span class=\"marker-list-item-text\">{{item.text}}</span>\n            </span>\n    </mat-list-item>\n-->\n</mat-nav-list>\n", styles: [".mat-list-item{box-sizing:border-box;-moz-box-sizing:border-box;-webkit-box-sizing:border-box;border-right:3px solid transparent}.mat-nav-list{padding-top:0}\n"] }]
        }], ctorParameters: function () { return [{ type: i1.ActivatedRoute }, { type: i1.Router }]; }, propDecorators: { sidenavItems: [{
                type: Input
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The header for the app.
 */
class HeaderComponent {
    constructor() {
        /** The main "logo" text for the app. */
        this.logo = 'My App';
        /** Event emitted when user clicks search button in drop down filter. */
        this.searchFilterClick = new EventEmitter();
        /** Event emitted when user clicks button to toggle sidenav. */
        this.toggleSidenav = new EventEmitter();
        /**
         * The bars icon to display in the header.
         */
        this.faBars = faBars;
    }
    ngAfterContentInit() {
        if (this.filter) {
            this.filter.searchClick.subscribe((val) => {
                this.searchFilterClick.emit(val);
            });
        }
    }
    /**
     * Emits the event to toggle the sidenav menu when the user clicks the bars.
     */
    onToggleSidenav() {
        this.toggleSidenav.emit(true);
    }
}
HeaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: HeaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
HeaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: HeaderComponent, selector: "ngx-mat-header", inputs: { logo: "logo" }, outputs: { searchFilterClick: "searchFilterClick", toggleSidenav: "toggleSidenav" }, queries: [{ propertyName: "filter", first: true, predicate: FilterDropDownComponent, descendants: true }], ngImport: i0, template: "<header>\n    <mat-toolbar color=\"primary\">\n        <div fxFlex=\"0 0 25\">\n            <button mat-icon-button (click)=\"onToggleSidenav()\" class=\"marker-bars-button\">\n                <fa-icon [icon]=\"faBars\"></fa-icon>\n                <div class=\"mat-button-focus-overlay\"></div>\n                <div class=\"mat-button-ripple mat-ripple\"></div>\n            </button>\n            <button mat-button\n                    class=\"mat-button marker-home-button\"\n                    [routerLink]=\"['/']\">\n                <span class=\"marker-header-logo\">{{logo}}</span>\n                <div class=\"mat-button-focus-overlay\"></div>\n                <div class=\"mat-button-ripple mat-ripple\"></div>\n            </button>\n        </div>\n        <div fxFlex=\"0 0 50\">\n            <ng-content></ng-content>\n        </div>\n        <div fxFlex=\"0 0 25\">\n<!--\n        <span fxFlex></span>\n        <ngx-mat-header-user-login></ngx-mat-header-user-login>\n-->\n        </div>\n    </mat-toolbar>\n</header>\n", styles: ["h1,h2{margin-bottom:0;font-feature-settings:\"smcp\";font-variant:small-caps}h1{font-size:3em;font-weight:700}h2{font-size:1.5em}.bar-bottom{color:#fff;font-feature-settings:\"smcp\";font-variant:small-caps;width:auto}.bar-top{color:#fff;max-height:25px;width:auto}.header-image{background-position:center center;background-size:100% 100%}.large-font{font-size:5em}.logo{height:20px}@media only screen and (min-device-width: 768px){.bar-bottom{height:auto;width:auto}.bar-top{height:auto;max-height:100%;width:auto}.logo{height:29px}}ngx-material-dashboard-header{z-index:2}\n"], components: [{ type: i1$5.MatToolbar, selector: "mat-toolbar", inputs: ["color"], exportAs: ["matToolbar"] }, { type: i1$2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i2.FaIconComponent, selector: "fa-icon", inputs: ["icon", "title", "spin", "pulse", "mask", "styles", "flip", "size", "pull", "border", "inverse", "symbol", "rotate", "fixedWidth", "classes", "transform", "a11yRole"] }], directives: [{ type: i5.DefaultFlexDirective, selector: "  [fxFlex], [fxFlex.xs], [fxFlex.sm], [fxFlex.md],  [fxFlex.lg], [fxFlex.xl], [fxFlex.lt-sm], [fxFlex.lt-md],  [fxFlex.lt-lg], [fxFlex.lt-xl], [fxFlex.gt-xs], [fxFlex.gt-sm],  [fxFlex.gt-md], [fxFlex.gt-lg]", inputs: ["fxFlex", "fxFlex.xs", "fxFlex.sm", "fxFlex.md", "fxFlex.lg", "fxFlex.xl", "fxFlex.lt-sm", "fxFlex.lt-md", "fxFlex.lt-lg", "fxFlex.lt-xl", "fxFlex.gt-xs", "fxFlex.gt-sm", "fxFlex.gt-md", "fxFlex.gt-lg"] }, { type: i1.RouterLink, selector: ":not(a):not(area)[routerLink]", inputs: ["queryParams", "fragment", "queryParamsHandling", "preserveFragment", "skipLocationChange", "replaceUrl", "state", "relativeTo", "routerLink"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: HeaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-header', template: "<header>\n    <mat-toolbar color=\"primary\">\n        <div fxFlex=\"0 0 25\">\n            <button mat-icon-button (click)=\"onToggleSidenav()\" class=\"marker-bars-button\">\n                <fa-icon [icon]=\"faBars\"></fa-icon>\n                <div class=\"mat-button-focus-overlay\"></div>\n                <div class=\"mat-button-ripple mat-ripple\"></div>\n            </button>\n            <button mat-button\n                    class=\"mat-button marker-home-button\"\n                    [routerLink]=\"['/']\">\n                <span class=\"marker-header-logo\">{{logo}}</span>\n                <div class=\"mat-button-focus-overlay\"></div>\n                <div class=\"mat-button-ripple mat-ripple\"></div>\n            </button>\n        </div>\n        <div fxFlex=\"0 0 50\">\n            <ng-content></ng-content>\n        </div>\n        <div fxFlex=\"0 0 25\">\n<!--\n        <span fxFlex></span>\n        <ngx-mat-header-user-login></ngx-mat-header-user-login>\n-->\n        </div>\n    </mat-toolbar>\n</header>\n", styles: ["h1,h2{margin-bottom:0;font-feature-settings:\"smcp\";font-variant:small-caps}h1{font-size:3em;font-weight:700}h2{font-size:1.5em}.bar-bottom{color:#fff;font-feature-settings:\"smcp\";font-variant:small-caps;width:auto}.bar-top{color:#fff;max-height:25px;width:auto}.header-image{background-position:center center;background-size:100% 100%}.large-font{font-size:5em}.logo{height:20px}@media only screen and (min-device-width: 768px){.bar-bottom{height:auto;width:auto}.bar-top{height:auto;max-height:100%;width:auto}.logo{height:29px}}ngx-material-dashboard-header{z-index:2}\n"] }]
        }], propDecorators: { filter: [{
                type: ContentChild,
                args: [FilterDropDownComponent]
            }], logo: [{
                type: Input
            }], searchFilterClick: [{
                type: Output
            }], toggleSidenav: [{
                type: Output
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A simple footer for the app. Renders a copyright symbol with the current
 * date and an optional company name.
 */
class FooterComponent {
    constructor() {
        /** Text to display next to copyright date. */
        this.company = '';
        /** The current date to use when displaying the copyright notice. */
        this.date = new Date(Date.now());
    }
}
FooterComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FooterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
FooterComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: FooterComponent, selector: "ngx-mat-footer", inputs: { company: "company" }, ngImport: i0, template: "<footer class=\"container\" fxLayout=\"row\" fxLayoutGap=\"10px\">\n    <span>&#169; {{ date | date: 'yyyy' }}</span>\n    <span>{{company}}</span>\n</footer>\n", styles: [""], directives: [{ type: i5.DefaultLayoutDirective, selector: "  [fxLayout], [fxLayout.xs], [fxLayout.sm], [fxLayout.md],  [fxLayout.lg], [fxLayout.xl], [fxLayout.lt-sm], [fxLayout.lt-md],  [fxLayout.lt-lg], [fxLayout.lt-xl], [fxLayout.gt-xs], [fxLayout.gt-sm],  [fxLayout.gt-md], [fxLayout.gt-lg]", inputs: ["fxLayout", "fxLayout.xs", "fxLayout.sm", "fxLayout.md", "fxLayout.lg", "fxLayout.xl", "fxLayout.lt-sm", "fxLayout.lt-md", "fxLayout.lt-lg", "fxLayout.lt-xl", "fxLayout.gt-xs", "fxLayout.gt-sm", "fxLayout.gt-md", "fxLayout.gt-lg"] }, { type: i5.DefaultLayoutGapDirective, selector: "  [fxLayoutGap], [fxLayoutGap.xs], [fxLayoutGap.sm], [fxLayoutGap.md],  [fxLayoutGap.lg], [fxLayoutGap.xl], [fxLayoutGap.lt-sm], [fxLayoutGap.lt-md],  [fxLayoutGap.lt-lg], [fxLayoutGap.lt-xl], [fxLayoutGap.gt-xs], [fxLayoutGap.gt-sm],  [fxLayoutGap.gt-md], [fxLayoutGap.gt-lg]", inputs: ["fxLayoutGap", "fxLayoutGap.xs", "fxLayoutGap.sm", "fxLayoutGap.md", "fxLayoutGap.lg", "fxLayoutGap.xl", "fxLayoutGap.lt-sm", "fxLayoutGap.lt-md", "fxLayoutGap.lt-lg", "fxLayoutGap.lt-xl", "fxLayoutGap.gt-xs", "fxLayoutGap.gt-sm", "fxLayoutGap.gt-md", "fxLayoutGap.gt-lg"] }], pipes: { "date": i4.DatePipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FooterComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-footer', template: "<footer class=\"container\" fxLayout=\"row\" fxLayoutGap=\"10px\">\n    <span>&#169; {{ date | date: 'yyyy' }}</span>\n    <span>{{company}}</span>\n</footer>\n", styles: [""] }]
        }], propDecorators: { company: [{
                type: Input
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * Defines the default layout for the app, which consists of the header, footer,
 * and main content based on the current route. The layout should have a sticky
 * footer, meaning if the main content is not tall enough to fill the existing
 * space, then the footer will stick to the bottom of the page.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-default-layout [logo]="logo" [sidenavItems]="sidenavItems">
 *  </ngx-mat-default-layout>
 * ```
 * ```typescript
 * import {Component} from '@angular/core';
 * import {SidenavItem} from '@ngx-material-dashboard/widgets';
 *
 * @Component({
 *     selector: 'basic-usage-example',
 *     templateUrl: './basic-usage-example.html'
 * })
 * export class BasicUsageExample {
 *     logo = 'My Tasks';
 *     sidenavItems: SidenavItem[] = [
 *         { queryParams: { isComplete: false }, route: ['tasks'], text: 'Pending', selector: 'pending' },
 *         { queryParams: { isComplete: false, filter: 'overdue' }, route: ['tasks'], text: 'Over Due', selector: 'over-due' },
 *         { queryParams: { isComplete: true }, route: ['tasks'], text: 'Complete', selector: 'complete' }
 *     ];
 * }
 * ```
 */
class DefaultLayoutComponent {
    constructor() {
        /** Text to display next to copyright date. */
        this.company = '';
        /** The main "logo" text for the app to display in the header. */
        this.logo = 'My App';
        /** The mode for the drawer (i.e. 'over', 'push', 'side', or 'rail'). */
        this.mode = 'side';
        /** List of items to render in the sidenav. */
        this.sidenavItems = [];
        /** Boolean indicating whether the screen size is small (defaults to false). */
        this.isSmallScreen = false;
        /** Event emitted when user clicks search button in filter. */
        this.clickSearch = new EventEmitter();
    }
    /**
     * Returns true if sidenav is opened.
     */
    get opened() {
        return this.sidenav.opened;
    }
    /**
     * Handler for when the user clicks the search button in the filter.
     *
     * @param res Boolean value to indicate if search button was clicked.
     */
    onSearchFilterClick(res) {
        this.clickSearch.emit(res);
    }
    /**
     * Toggles the sidenav.
     */
    toggleSidenav() {
        this.sidenav.opened = !this.sidenav.opened;
        this.sidenav.toggle();
    }
}
DefaultLayoutComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: DefaultLayoutComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
DefaultLayoutComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: DefaultLayoutComponent, selector: "ngx-mat-default-layout", inputs: { company: "company", logo: "logo", mode: "mode", sidenavItems: "sidenavItems", isSmallScreen: "isSmallScreen" }, outputs: { clickSearch: "clickSearch" }, viewQueries: [{ propertyName: "header", first: true, predicate: HeaderComponent, descendants: true }, { propertyName: "sidenav", first: true, predicate: ["sidenav"], descendants: true }], ngImport: i0, template: "<ngx-mat-loading></ngx-mat-loading>\n<div class=\"box\" fxLayout=\"column\">\n    <ngx-mat-header\n        [logo]=\"logo\"\n        (searchFilterClick)=\"onSearchFilterClick($event)\"\n        (toggleSidenav)=\"toggleSidenav()\"\n        class=\"mat-elevation-z6\">\n        <ng-content select=\"[filter]\"></ng-content>\n    </ngx-mat-header>\n    <mat-sidenav-container class=\"content\" fxLayout=\"row\">\n        <mat-sidenav *ngIf=\"mode === 'rail'; else defaultSidenav\" rail-mode [opened]=\"opened\" #sidenav>\n            <ngx-mat-sidenav [sidenavItems]=\"sidenavItems\"></ngx-mat-sidenav>\n        </mat-sidenav>\n        <ng-template #defaultSidenav>\n            <mat-sidenav [mode]=\"mode\" #sidenav>\n                <ngx-mat-sidenav [sidenavItems]=\"sidenavItems\"></ngx-mat-sidenav>\n            </mat-sidenav>\n        </ng-template>\n        <mat-sidenav-content fxFlex>\n            <router-outlet></router-outlet>\n        </mat-sidenav-content>\n    </mat-sidenav-container>\n    <ngx-mat-footer [company]=\"company\"></ngx-mat-footer>\n</div>\n", styles: ["ngx-material-dashboard-header{z-index:2}\n"], components: [{ type: LoadingComponent, selector: "ngx-mat-loading" }, { type: HeaderComponent, selector: "ngx-mat-header", inputs: ["logo"], outputs: ["searchFilterClick", "toggleSidenav"] }, { type: i3$1.MatSidenavContainer, selector: "mat-sidenav-container", exportAs: ["matSidenavContainer"] }, { type: i3$1.MatSidenav, selector: "mat-sidenav", inputs: ["fixedInViewport", "fixedTopGap", "fixedBottomGap"], exportAs: ["matSidenav"] }, { type: SidenavComponent, selector: "ngx-mat-sidenav", inputs: ["sidenavItems"] }, { type: i3$1.MatSidenavContent, selector: "mat-sidenav-content" }, { type: FooterComponent, selector: "ngx-mat-footer", inputs: ["company"] }], directives: [{ type: i5.DefaultLayoutDirective, selector: "  [fxLayout], [fxLayout.xs], [fxLayout.sm], [fxLayout.md],  [fxLayout.lg], [fxLayout.xl], [fxLayout.lt-sm], [fxLayout.lt-md],  [fxLayout.lt-lg], [fxLayout.lt-xl], [fxLayout.gt-xs], [fxLayout.gt-sm],  [fxLayout.gt-md], [fxLayout.gt-lg]", inputs: ["fxLayout", "fxLayout.xs", "fxLayout.sm", "fxLayout.md", "fxLayout.lg", "fxLayout.xl", "fxLayout.lt-sm", "fxLayout.lt-md", "fxLayout.lt-lg", "fxLayout.lt-xl", "fxLayout.gt-xs", "fxLayout.gt-sm", "fxLayout.gt-md", "fxLayout.gt-lg"] }, { type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i8.MatDrawerRailDirective, selector: "mat-sidenav[mode=\"rail\"], mat-drawer[mode=\"rail\"], mat-sidenav[rail-mode], mat-drawer[rail-mode]", inputs: ["openAnimation", "closeAnimation", "closeWidth", "expandedWidth"] }, { type: i5.DefaultFlexDirective, selector: "  [fxFlex], [fxFlex.xs], [fxFlex.sm], [fxFlex.md],  [fxFlex.lg], [fxFlex.xl], [fxFlex.lt-sm], [fxFlex.lt-md],  [fxFlex.lt-lg], [fxFlex.lt-xl], [fxFlex.gt-xs], [fxFlex.gt-sm],  [fxFlex.gt-md], [fxFlex.gt-lg]", inputs: ["fxFlex", "fxFlex.xs", "fxFlex.sm", "fxFlex.md", "fxFlex.lg", "fxFlex.xl", "fxFlex.lt-sm", "fxFlex.lt-md", "fxFlex.lt-lg", "fxFlex.lt-xl", "fxFlex.gt-xs", "fxFlex.gt-sm", "fxFlex.gt-md", "fxFlex.gt-lg"] }, { type: i1.RouterOutlet, selector: "router-outlet", outputs: ["activate", "deactivate", "attach", "detach"], exportAs: ["outlet"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: DefaultLayoutComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-default-layout', template: "<ngx-mat-loading></ngx-mat-loading>\n<div class=\"box\" fxLayout=\"column\">\n    <ngx-mat-header\n        [logo]=\"logo\"\n        (searchFilterClick)=\"onSearchFilterClick($event)\"\n        (toggleSidenav)=\"toggleSidenav()\"\n        class=\"mat-elevation-z6\">\n        <ng-content select=\"[filter]\"></ng-content>\n    </ngx-mat-header>\n    <mat-sidenav-container class=\"content\" fxLayout=\"row\">\n        <mat-sidenav *ngIf=\"mode === 'rail'; else defaultSidenav\" rail-mode [opened]=\"opened\" #sidenav>\n            <ngx-mat-sidenav [sidenavItems]=\"sidenavItems\"></ngx-mat-sidenav>\n        </mat-sidenav>\n        <ng-template #defaultSidenav>\n            <mat-sidenav [mode]=\"mode\" #sidenav>\n                <ngx-mat-sidenav [sidenavItems]=\"sidenavItems\"></ngx-mat-sidenav>\n            </mat-sidenav>\n        </ng-template>\n        <mat-sidenav-content fxFlex>\n            <router-outlet></router-outlet>\n        </mat-sidenav-content>\n    </mat-sidenav-container>\n    <ngx-mat-footer [company]=\"company\"></ngx-mat-footer>\n</div>\n", styles: ["ngx-material-dashboard-header{z-index:2}\n"] }]
        }], propDecorators: { company: [{
                type: Input
            }], logo: [{
                type: Input
            }], mode: [{
                type: Input
            }], sidenavItems: [{
                type: Input
            }], isSmallScreen: [{
                type: Input
            }], clickSearch: [{
                type: Output
            }], header: [{
                type: ViewChild,
                args: [HeaderComponent]
            }], sidenav: [{
                type: ViewChild,
                args: ['sidenav']
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
// import { AuthService } from '@app-core/services/auth.service';
class HeaderUserMenuComponent {
    constructor() {
        this.username = '';
        this.logoutClick = new EventEmitter();
        this.caretDown = faCaretDown;
    }
    logout() {
        this.logoutClick.emit(true);
    }
}
HeaderUserMenuComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: HeaderUserMenuComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
HeaderUserMenuComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: HeaderUserMenuComponent, selector: "ngx-mat-header-user-menu", inputs: { username: "username" }, outputs: { logoutClick: "logoutClick" }, ngImport: i0, template: "<button mat-button\n        class=\"mat-button marker-menu-trigger\"\n        [matMenuTriggerFor]=\"menu\">\n    <span>{{username}}</span>\n    <fa-icon class=\"pl-2\" [icon]=\"caretDown\"></fa-icon>\n</button>\n<mat-menu xPosition=\"before\" yPosition=\"below\" #menu=\"matMenu\">\n    <div matMenuContent #menuContent>\n        <button mat-menu-item class=\"marker-button-logout\" (click)=\"logout()\">Logout</button>\n    </div>\n</mat-menu>\n", styles: [""], components: [{ type: i1$2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i2.FaIconComponent, selector: "fa-icon", inputs: ["icon", "title", "spin", "pulse", "mask", "styles", "flip", "size", "pull", "border", "inverse", "symbol", "rotate", "fixedWidth", "classes", "transform", "a11yRole"] }, { type: i3.MatMenu, selector: "mat-menu", exportAs: ["matMenu"] }, { type: i3.MatMenuItem, selector: "[mat-menu-item]", inputs: ["disabled", "disableRipple", "role"], exportAs: ["matMenuItem"] }], directives: [{ type: i3.MatMenuTrigger, selector: "[mat-menu-trigger-for], [matMenuTriggerFor]", exportAs: ["matMenuTrigger"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: HeaderUserMenuComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-header-user-menu', template: "<button mat-button\n        class=\"mat-button marker-menu-trigger\"\n        [matMenuTriggerFor]=\"menu\">\n    <span>{{username}}</span>\n    <fa-icon class=\"pl-2\" [icon]=\"caretDown\"></fa-icon>\n</button>\n<mat-menu xPosition=\"before\" yPosition=\"below\" #menu=\"matMenu\">\n    <div matMenuContent #menuContent>\n        <button mat-menu-item class=\"marker-button-logout\" (click)=\"logout()\">Logout</button>\n    </div>\n</mat-menu>\n", styles: [""] }]
        }], propDecorators: { username: [{
                type: Input
            }], logoutClick: [{
                type: Output
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
// import { AuthService } from '@app-core/services/auth.service';
// import { User } from '@ngx-material-dashboard/json-api/src/lib/models/user.model';
class HeaderUserLoginComponent {
    // constructor(private authService: AuthService) {}
    ngOnInit() {
        // this.authService.currentUser.subscribe(
        //     (user: User) => {
        //         this.username = user.name;
        //     },
        //     (error: any) => {
        //         // TODO handle error
        //     }
        // );
    }
    login() {
        // this.authService.login();
    }
}
HeaderUserLoginComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: HeaderUserLoginComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
HeaderUserLoginComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: HeaderUserLoginComponent, selector: "ngx-mat-header-user-login", ngImport: i0, template: "<ngx-mat-header-user-menu *ngIf=\"username; else loginButton\" [username]=\"username\"></ngx-mat-header-user-menu>\n<ng-template #loginButton>\n    <button mat-button\n            class=\"mat-button marker-login-button\"\n            (click)=\"login()\">\n        <span>Login</span>\n        <div class=\"mat-button-focus-overlay\"></div>\n        <div class=\"mat-button-ripple mat-ripple\"></div>\n    </button>\n</ng-template>", styles: [""], components: [{ type: HeaderUserMenuComponent, selector: "ngx-mat-header-user-menu", inputs: ["username"], outputs: ["logoutClick"] }, { type: i1$2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }], directives: [{ type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: HeaderUserLoginComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-header-user-login', template: "<ngx-mat-header-user-menu *ngIf=\"username; else loginButton\" [username]=\"username\"></ngx-mat-header-user-menu>\n<ng-template #loginButton>\n    <button mat-button\n            class=\"mat-button marker-login-button\"\n            (click)=\"login()\">\n        <span>Login</span>\n        <div class=\"mat-button-focus-overlay\"></div>\n        <div class=\"mat-button-ripple mat-ripple\"></div>\n    </button>\n</ng-template>", styles: [""] }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
class LayoutModule {
}
LayoutModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: LayoutModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
LayoutModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: LayoutModule, declarations: [HeaderComponent,
        HeaderUserLoginComponent,
        HeaderUserMenuComponent,
        FooterComponent,
        DefaultLayoutComponent,
        SidenavComponent,
        LoadingComponent], imports: [CommonModule,
        FlexLayoutModule,
        RouterModule,
        MatButtonModule,
        MatListModule,
        MatMenuModule,
        MatProgressSpinnerModule,
        MatSidenavModule,
        MatToolbarModule,
        DrawerRailModule,
        FontAwesomeModule,
        ToolbarModule], exports: [DefaultLayoutComponent, LoadingComponent, SidenavComponent] });
LayoutModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: LayoutModule, providers: [LoadingService], imports: [[
            CommonModule,
            FlexLayoutModule,
            RouterModule,
            MatButtonModule,
            MatListModule,
            MatMenuModule,
            MatProgressSpinnerModule,
            MatSidenavModule,
            MatToolbarModule,
            DrawerRailModule,
            FontAwesomeModule,
            ToolbarModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: LayoutModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        HeaderComponent,
                        HeaderUserLoginComponent,
                        HeaderUserMenuComponent,
                        FooterComponent,
                        DefaultLayoutComponent,
                        SidenavComponent,
                        LoadingComponent
                    ],
                    exports: [DefaultLayoutComponent, LoadingComponent, SidenavComponent],
                    imports: [
                        CommonModule,
                        FlexLayoutModule,
                        RouterModule,
                        MatButtonModule,
                        MatListModule,
                        MatMenuModule,
                        MatProgressSpinnerModule,
                        MatSidenavModule,
                        MatToolbarModule,
                        DrawerRailModule,
                        FontAwesomeModule,
                        ToolbarModule
                    ],
                    providers: [LoadingService]
                }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `List` extends `Collection` and is meant for rendering items in a list.
 * A `Sorter` is rendered above the data list, which is meant to allow users to
 * well sort the data in the list based on the provided `field` options users
 * should be able to sort the data on.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-list [data]="data" [fields]="fields">
 *     <ng-template #model let-model="model">
 *        <mat-card>
 *            <mat-card-title>
 *                {{model.id}} Title
 *            </mat-card-title>
 *            <mat-card-content>
 *                Content for dummy object {{model.id}}
 *            </mat-card-content>
 *       </mat-card>
 *     </ng-template>
 * </ngx-mat-list>
 * ```
 * ```typescript
 * @Component({
 *     selector: 'basic-list-usage-example',
 *     templateUrl: './basic-list-usage-example.html'
 * }) export class BasicListUsageExample {
 *     data: Task[] = [...];
 *     fields: string[] = ['id'];
 * }
 * ```
 */
class ListComponent extends CollectionComponent {
}
ListComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ListComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
ListComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: ListComponent, selector: "ngx-mat-list", usesInheritance: true, ngImport: i0, template: "<div class=\"marker-list\">\n    <div fxLayout=\"row\" fxLayoutAlign=\"center center\" fxLayoutGap=\"10px\">\n        <mat-checkbox class=\"marker-checkbox-select-all\"\n            (change)=\"masterToggle()\"\n            [checked]=\"selection.hasValue() && isAllSelected()\"\n            [indeterminate]=\"selection.hasValue() && !isAllSelected()\">\n        </mat-checkbox>\n        <ngx-mat-sorter *ngIf=\"displaySorter\" [options]=\"fields\"></ngx-mat-sorter>\n        <div fxFlex></div>\n    </div>\n    <div fxLayout=\"column\" fxLayoutGap=\"5px\">\n        <div *ngFor=\"let model of models\">\n            <div class=\"marker-list-item\" fxLayout=\"row\" fxLayoutAlign=\"center center\" fxLayoutGap=\"10px\">\n                <mat-checkbox class=\"marker-checkbox-item-select\"\n                    (click)=\"$event.stopPropagation()\"\n                    (change)=\"onRowSelected(model);\"\n                    [checked]=\"selection.isSelected(model)\">\n                </mat-checkbox>\n                <div fxFlex>\n                    <ng-container \n                        *ngTemplateOutlet=\"template; context: { model: model }\">\n                    </ng-container>\n                </div>\n                <div class=\"marker-list-item-buttons\" fxLayout=\"row\" fxLayoutGap=\"5px\">\n                    <button *ngFor=\"let button of collectionButtons\"\n                        class=\"marker-button-{{button.click}}\"\n                        (click)=\"onActionButtonClick(button.click, model)\"\n                        mat-icon-button>\n                        <fa-icon [icon]=\"button.icon\"></fa-icon>\n                        <div class=\"mat-button-focus-overlay\"></div>\n                        <div class=\"mat-button-ripple mat-ripple\"></div>\n                    </button>\n                </div>\n            </div>\n        </div>\n    </div>\n</div>", styles: ["mat-checkbox{padding-left:10px}\n"], components: [{ type: i1$3.MatCheckbox, selector: "mat-checkbox", inputs: ["disableRipple", "color", "tabIndex", "aria-label", "aria-labelledby", "aria-describedby", "id", "required", "labelPosition", "name", "value", "checked", "disabled", "indeterminate"], outputs: ["change", "indeterminateChange"], exportAs: ["matCheckbox"] }, { type: SorterComponent, selector: "ngx-mat-sorter", inputs: ["options"] }, { type: i1$2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i2.FaIconComponent, selector: "fa-icon", inputs: ["icon", "title", "spin", "pulse", "mask", "styles", "flip", "size", "pull", "border", "inverse", "symbol", "rotate", "fixedWidth", "classes", "transform", "a11yRole"] }], directives: [{ type: i5.DefaultLayoutDirective, selector: "  [fxLayout], [fxLayout.xs], [fxLayout.sm], [fxLayout.md],  [fxLayout.lg], [fxLayout.xl], [fxLayout.lt-sm], [fxLayout.lt-md],  [fxLayout.lt-lg], [fxLayout.lt-xl], [fxLayout.gt-xs], [fxLayout.gt-sm],  [fxLayout.gt-md], [fxLayout.gt-lg]", inputs: ["fxLayout", "fxLayout.xs", "fxLayout.sm", "fxLayout.md", "fxLayout.lg", "fxLayout.xl", "fxLayout.lt-sm", "fxLayout.lt-md", "fxLayout.lt-lg", "fxLayout.lt-xl", "fxLayout.gt-xs", "fxLayout.gt-sm", "fxLayout.gt-md", "fxLayout.gt-lg"] }, { type: i5.DefaultLayoutAlignDirective, selector: "  [fxLayoutAlign], [fxLayoutAlign.xs], [fxLayoutAlign.sm], [fxLayoutAlign.md],  [fxLayoutAlign.lg], [fxLayoutAlign.xl], [fxLayoutAlign.lt-sm], [fxLayoutAlign.lt-md],  [fxLayoutAlign.lt-lg], [fxLayoutAlign.lt-xl], [fxLayoutAlign.gt-xs], [fxLayoutAlign.gt-sm],  [fxLayoutAlign.gt-md], [fxLayoutAlign.gt-lg]", inputs: ["fxLayoutAlign", "fxLayoutAlign.xs", "fxLayoutAlign.sm", "fxLayoutAlign.md", "fxLayoutAlign.lg", "fxLayoutAlign.xl", "fxLayoutAlign.lt-sm", "fxLayoutAlign.lt-md", "fxLayoutAlign.lt-lg", "fxLayoutAlign.lt-xl", "fxLayoutAlign.gt-xs", "fxLayoutAlign.gt-sm", "fxLayoutAlign.gt-md", "fxLayoutAlign.gt-lg"] }, { type: i5.DefaultLayoutGapDirective, selector: "  [fxLayoutGap], [fxLayoutGap.xs], [fxLayoutGap.sm], [fxLayoutGap.md],  [fxLayoutGap.lg], [fxLayoutGap.xl], [fxLayoutGap.lt-sm], [fxLayoutGap.lt-md],  [fxLayoutGap.lt-lg], [fxLayoutGap.lt-xl], [fxLayoutGap.gt-xs], [fxLayoutGap.gt-sm],  [fxLayoutGap.gt-md], [fxLayoutGap.gt-lg]", inputs: ["fxLayoutGap", "fxLayoutGap.xs", "fxLayoutGap.sm", "fxLayoutGap.md", "fxLayoutGap.lg", "fxLayoutGap.xl", "fxLayoutGap.lt-sm", "fxLayoutGap.lt-md", "fxLayoutGap.lt-lg", "fxLayoutGap.lt-xl", "fxLayoutGap.gt-xs", "fxLayoutGap.gt-sm", "fxLayoutGap.gt-md", "fxLayoutGap.gt-lg"] }, { type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i5.DefaultFlexDirective, selector: "  [fxFlex], [fxFlex.xs], [fxFlex.sm], [fxFlex.md],  [fxFlex.lg], [fxFlex.xl], [fxFlex.lt-sm], [fxFlex.lt-md],  [fxFlex.lt-lg], [fxFlex.lt-xl], [fxFlex.gt-xs], [fxFlex.gt-sm],  [fxFlex.gt-md], [fxFlex.gt-lg]", inputs: ["fxFlex", "fxFlex.xs", "fxFlex.sm", "fxFlex.md", "fxFlex.lg", "fxFlex.xl", "fxFlex.lt-sm", "fxFlex.lt-md", "fxFlex.lt-lg", "fxFlex.lt-xl", "fxFlex.gt-xs", "fxFlex.gt-sm", "fxFlex.gt-md", "fxFlex.gt-lg"] }, { type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i4.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ListComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-list', template: "<div class=\"marker-list\">\n    <div fxLayout=\"row\" fxLayoutAlign=\"center center\" fxLayoutGap=\"10px\">\n        <mat-checkbox class=\"marker-checkbox-select-all\"\n            (change)=\"masterToggle()\"\n            [checked]=\"selection.hasValue() && isAllSelected()\"\n            [indeterminate]=\"selection.hasValue() && !isAllSelected()\">\n        </mat-checkbox>\n        <ngx-mat-sorter *ngIf=\"displaySorter\" [options]=\"fields\"></ngx-mat-sorter>\n        <div fxFlex></div>\n    </div>\n    <div fxLayout=\"column\" fxLayoutGap=\"5px\">\n        <div *ngFor=\"let model of models\">\n            <div class=\"marker-list-item\" fxLayout=\"row\" fxLayoutAlign=\"center center\" fxLayoutGap=\"10px\">\n                <mat-checkbox class=\"marker-checkbox-item-select\"\n                    (click)=\"$event.stopPropagation()\"\n                    (change)=\"onRowSelected(model);\"\n                    [checked]=\"selection.isSelected(model)\">\n                </mat-checkbox>\n                <div fxFlex>\n                    <ng-container \n                        *ngTemplateOutlet=\"template; context: { model: model }\">\n                    </ng-container>\n                </div>\n                <div class=\"marker-list-item-buttons\" fxLayout=\"row\" fxLayoutGap=\"5px\">\n                    <button *ngFor=\"let button of collectionButtons\"\n                        class=\"marker-button-{{button.click}}\"\n                        (click)=\"onActionButtonClick(button.click, model)\"\n                        mat-icon-button>\n                        <fa-icon [icon]=\"button.icon\"></fa-icon>\n                        <div class=\"mat-button-focus-overlay\"></div>\n                        <div class=\"mat-button-ripple mat-ripple\"></div>\n                    </button>\n                </div>\n            </div>\n        </div>\n    </div>\n</div>", styles: ["mat-checkbox{padding-left:10px}\n"] }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `ListWithIconButtonsPaginatorBar` is a wrapper for the `PagedList` and
 * `IconButtonsWithPaginator` toolbar components. It allows you to define and
 * render your data models in a list with built in paging and basic data
 * management buttons with easy to use handlers for when the user clicks a
 * button in the toolbar or the collection. The toolbar is rendered above the
 * data list.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-list-with-icon-buttons-paginator-bar
 *     [fields]="fields"
 *     [toolbarButtons]="toolbarButtons"
 *     (buttonClick)="onButtonClick($event)"
 *     class="marker-paged-list">
 *     <ngx-mat-list [collectionButtons]="collectionButtons" [data]="data" #collection>
 *         <ng-template #model let-model="model">
 *             <mat-card>
 *                 <mat-card-title>
 *                     {{model.id}} Title
 *                 </mat-card-title>
 *                 <mat-card-content>
 *                     Content for dummy object {{model.id}}
 *                 </mat-card-content>
 *             </mat-card>
 *         </ng-template>
 *     </ngx-mat-list>
 * </ngx-mat-list-with-icon-buttons-paginator-bar>
 * ```
 * ```typescript
 * @Component({
 *     selector: 'basic-list-usage-example',
 *     templateUrl: './basic-list-usage-example.html'
 * }) export class BasicListUsageExample {
 *     data: Task[] = [...];
 *     fields: string[] = ['id'];
 *     // either create your own, or use copies of buttons provided for both
 *     // collection and toolbar; use copies without references in case you
 *     // have multiple collections to render so each one gets their own
 *     // buttons and own subscriptions (otherwise events in one table will
 *     // affect buttons in others)
 *     collectionButtons: CollectionButton[] = [
 *         {...EDIT_BUTTON}, {...DELETE_BUTTON}
 *     ];
 *     toolbarButtons: ToolbarButton[] = [
 *         {...CREATE_TOOLBAR_BUTTON}, {...EDIT_TOOLBAR_BUTTON}, {...DELETE_TOOLBAR_BUTTON}
 *     ];
 *
 *     onButtonClick(btnClick: ButtonClick): void {
 *         if (btnClick.click === 'create') {
 *             // handle create
 *         } else if (btnClick.click === 'edit') {
 *             // handle edit
 *         } else if (btnClick.click === 'delete') {
 *             // handle delete
 *         }
 *     }
 * }
 * ```
 */
class ListWithIconButtonsPaginatorBarComponent extends PagedCollectionWithIconToolbarComponent {
}
ListWithIconButtonsPaginatorBarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ListWithIconButtonsPaginatorBarComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
ListWithIconButtonsPaginatorBarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: ListWithIconButtonsPaginatorBarComponent, selector: "ngx-mat-list-with-icon-buttons-paginator-bar", queries: [{ propertyName: "collection", first: true, predicate: ListComponent, descendants: true }], usesInheritance: true, ngImport: i0, template: "<ngx-mat-icon-buttons-with-paginator\n    [buttons]=\"toolbarButtons\"\n    [displaySelectAll]=\"false\"\n    [displaySort]=\"displaySorterInToolbar\"\n    [length]=\"length\"\n    [multiple]=\"multiple\"\n    [pageSize]=\"pageSize\"\n    (buttonClick)=\"onToolbarButtonClick($event)\"\n    #toolbar>\n</ngx-mat-icon-buttons-with-paginator>\n<!-- list -->\n<ng-content></ng-content>\n", styles: [""], components: [{ type: IconButtonsWithPaginatorComponent, selector: "ngx-mat-icon-buttons-with-paginator", inputs: ["buttons", "displaySelectAll", "displaySort", "fields", "isAllSelected", "length", "multiple", "pageSize", "selection"], outputs: ["buttonClick", "masterToggle"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ListWithIconButtonsPaginatorBarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-list-with-icon-buttons-paginator-bar', template: "<ngx-mat-icon-buttons-with-paginator\n    [buttons]=\"toolbarButtons\"\n    [displaySelectAll]=\"false\"\n    [displaySort]=\"displaySorterInToolbar\"\n    [length]=\"length\"\n    [multiple]=\"multiple\"\n    [pageSize]=\"pageSize\"\n    (buttonClick)=\"onToolbarButtonClick($event)\"\n    #toolbar>\n</ngx-mat-icon-buttons-with-paginator>\n<!-- list -->\n<ng-content></ng-content>\n", styles: [""] }]
        }], propDecorators: { collection: [{
                type: ContentChild,
                args: [ListComponent]
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `PagedList` is a wrapper for the `List`, and renders items in a list
 * with built in paging capabilities. You must provide the template for each
 * item to render in the list. A `MatPaginator` is rendered below the `Sorter`
 * and data list to provide paging capabilities for the data.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-paged-list [data]="tasks" class="marker-paged-grid">
 *     <ng-template #model let-model="model">
 *         <mat-card>
 *             <mat-card-title>
 *                 {{model.id}} Title
 *             </mat-card-title>
 *             <mat-card-content>
 *                 Content for dummy object {{model.id}}
 *             </mat-card-content>
 *         </mat-card>
 *     </ng-template>
 * </ngx-mat-paged-list>
 * ```
 * ```typescript
 * import {Component} from '@angular/core';
 * import {Task} from './tasks'; // this should extend JsonModel
 *
 * @Component({
 *     selector: 'basic-usage-example',
 *     templateUrl: './basic-usage-example.html'
 * }) UsingBasicUsageExample {
 *     tasks: Task[] = []; // assuming this is initialized with data at some point
 * }
 * ```
 */
class PagedListComponent extends PagedCollectionComponent {
}
PagedListComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedListComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
PagedListComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: PagedListComponent, selector: "ngx-mat-paged-list", usesInheritance: true, ngImport: i0, template: "<ngx-mat-list\n    [collectionButtons]=\"collectionButtons\"\n    [dataSource]=\"dataSource$\"\n    [fields]=\"fields\"\n    #collection>\n    <ng-template #model let-model=\"model\">\n        <div fxFlex>\n            <ng-container \n                *ngTemplateOutlet=\"template; context: { model: model }\">\n            </ng-container>\n        </div>\n    </ng-template>\n</ngx-mat-list>\n<mat-paginator [length]=\"length\"\n                [pageSize]=\"pageSize\"\n                [pageSizeOptions]=\"[15, 25, 50, 75, 100]\">\n</mat-paginator>", styles: [""], components: [{ type: ListComponent, selector: "ngx-mat-list" }, { type: i2$3.MatPaginator, selector: "mat-paginator", inputs: ["disabled"], exportAs: ["matPaginator"] }], directives: [{ type: i5.DefaultFlexDirective, selector: "  [fxFlex], [fxFlex.xs], [fxFlex.sm], [fxFlex.md],  [fxFlex.lg], [fxFlex.xl], [fxFlex.lt-sm], [fxFlex.lt-md],  [fxFlex.lt-lg], [fxFlex.lt-xl], [fxFlex.gt-xs], [fxFlex.gt-sm],  [fxFlex.gt-md], [fxFlex.gt-lg]", inputs: ["fxFlex", "fxFlex.xs", "fxFlex.sm", "fxFlex.md", "fxFlex.lg", "fxFlex.xl", "fxFlex.lt-sm", "fxFlex.lt-md", "fxFlex.lt-lg", "fxFlex.lt-xl", "fxFlex.gt-xs", "fxFlex.gt-sm", "fxFlex.gt-md", "fxFlex.gt-lg"] }, { type: i4.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedListComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-paged-list', template: "<ngx-mat-list\n    [collectionButtons]=\"collectionButtons\"\n    [dataSource]=\"dataSource$\"\n    [fields]=\"fields\"\n    #collection>\n    <ng-template #model let-model=\"model\">\n        <div fxFlex>\n            <ng-container \n                *ngTemplateOutlet=\"template; context: { model: model }\">\n            </ng-container>\n        </div>\n    </ng-template>\n</ngx-mat-list>\n<mat-paginator [length]=\"length\"\n                [pageSize]=\"pageSize\"\n                [pageSizeOptions]=\"[15, 25, 50, 75, 100]\">\n</mat-paginator>", styles: [""] }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `PagedListWithRaisedButtonsBar` is a wrapper for the `PagedList` and
 * `RaisedButtonsToolbar` toolbar components. It allows you to define and
 * render your data models in a list with built in paging and basic data
 * management buttons with easy to use handlers for when the user clicks a
 * button in the toolbar or the collection. The toolbar is rendered above the
 * data list, and the `MatPaginator` is rendered below the data list.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-paged-list-with-raised-buttons-bar
 *     [fields]="fields"
 *     [toolbarButtons]="toolbarButtons"
 *     (buttonClick)="onButtonClick($event)"
 *     class="marker-paged-list">
 *     <ngx-mat-list [collectionButtons]="collectionButtons" [data]="data" #collection>
 *         <ng-template #model let-model="model">
 *             <mat-card>
 *                 <mat-card-title>
 *                     {{model.id}} Title
 *                 </mat-card-title>
 *                 <mat-card-content>
 *                     Content for dummy object {{model.id}}
 *                 </mat-card-content>
 *             </mat-card>
 *         </ng-template>
 *     </ngx-mat-list>
 * </ngx-mat-paged-list-with-raised-buttons-bar>
 * ```
 * ```typescript
 * @Component({
 *     selector: 'basic-list-usage-example',
 *     templateUrl: './basic-list-usage-example.html'
 * }) export class BasicListUsageExample {
 *     data: Task[] = [...];
 *     fields: string[] = ['id'];
 *     // either create your own, or use copies of buttons provided for both
 *     // collection and toolbar; use copies without references in case you
 *     // have multiple collections to render so each one gets their own
 *     // buttons and own subscriptions (otherwise events in one table will
 *     // affect buttons in others)
 *     collectionButtons: CollectionButton[] = [
 *         {...EDIT_BUTTON}, {...DELETE_BUTTON}
 *     ];
 *     toolbarButtons: ToolbarButton[] = [
 *         {...CREATE_TOOLBAR_BUTTON}, {...EDIT_TOOLBAR_BUTTON}, {...DELETE_TOOLBAR_BUTTON}
 *     ];
 *
 *     onButtonClick(btnClick: ButtonClick): void {
 *         if (btnClick.click === 'create') {
 *             // handle create
 *         } else if (btnClick.click === 'edit') {
 *             // handle edit
 *         } else if (btnClick.click === 'delete') {
 *             // handle delete
 *         }
 *     }
 * }
 * ```
 */
class PagedListWithRaisedButtonsBarComponent extends PagedCollectionWithRaisedButtonToolbarComponent {
}
PagedListWithRaisedButtonsBarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedListWithRaisedButtonsBarComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
PagedListWithRaisedButtonsBarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: PagedListWithRaisedButtonsBarComponent, selector: "ngx-mat-paged-list-with-raised-buttons-bar", usesInheritance: true, ngImport: i0, template: "<ngx-mat-button-toolbar\n    [buttons]=\"toolbarButtons\"\n    (buttonClick)=\"onToolbarButtonClick($event)\"\n    #toolbar>\n    <ng-content select=\"[filter]\"></ng-content>\n</ngx-mat-button-toolbar>\n<!-- paged-list -->\n<ng-content select=\"[collection]\"></ng-content>\n", styles: [""], components: [{ type: ButtonToolbarComponent, selector: "ngx-mat-button-toolbar", inputs: ["buttons", "buttonAlign"], outputs: ["buttonClick"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedListWithRaisedButtonsBarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-paged-list-with-raised-buttons-bar', template: "<ngx-mat-button-toolbar\n    [buttons]=\"toolbarButtons\"\n    (buttonClick)=\"onToolbarButtonClick($event)\"\n    #toolbar>\n    <ng-content select=\"[filter]\"></ng-content>\n</ngx-mat-button-toolbar>\n<!-- paged-list -->\n<ng-content select=\"[collection]\"></ng-content>\n", styles: [""] }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
class ListModule {
}
ListModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ListModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ListModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ListModule, declarations: [PagedListComponent,
        ListComponent,
        ListWithIconButtonsPaginatorBarComponent,
        PagedListWithRaisedButtonsBarComponent], imports: [CommonModule,
        FlexLayoutModule,
        FontAwesomeModule,
        MatButtonModule,
        MatCheckboxModule,
        MatPaginatorModule,
        CollectionModule,
        ToolbarModule], exports: [PagedListComponent] });
ListModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ListModule, imports: [[
            CommonModule,
            FlexLayoutModule,
            FontAwesomeModule,
            MatButtonModule,
            MatCheckboxModule,
            MatPaginatorModule,
            CollectionModule,
            ToolbarModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ListModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        PagedListComponent,
                        ListComponent,
                        ListWithIconButtonsPaginatorBarComponent,
                        PagedListWithRaisedButtonsBarComponent
                    ],
                    exports: [PagedListComponent],
                    imports: [
                        CommonModule,
                        FlexLayoutModule,
                        FontAwesomeModule,
                        MatButtonModule,
                        MatCheckboxModule,
                        MatPaginatorModule,
                        CollectionModule,
                        ToolbarModule
                    ]
                }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `Table` is a wrapper for `MatTable`, and provides features defined in
 * `Collection`. Think of it as a `MatTable` plus, or `MatTable+` for short
 * if you will. Sorting columns in the table is automatically built in to
 * the component. Additionally it provides built in select one or more (or all)
 * capabilities, as well as rendering one or more buttons in each row and
 * emitting click events for you to handle response to clicks.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-table
 *     matSort
 *     [collectionButtons]="collectionButtons"
 *     [data]="data"
 *     [displayedColumns]="displayedColumns">
 *     <ng-container matColumnDef="id">
 *         <mat-header-cell *matHeaderCellDef mat-sort-header>ID</mat-header-cell>
 *         <mat-cell class="col1-cell" *matCellDef="let obj">{{obj.id}}</mat-cell>
 *     </ng-container>
 *     <ng-container matColumnDef="noData">
 *         <mat-footer-cell *matFooterCellDef colspan="displayedColumns.length" fxLayoutAlign="center center">
 *             No data found
 *         </mat-footer-cell>
 *     </ng-container>
 * </ngx-mat-table>
 * ```
 * ```typescript
 * @Component({
 *     selector: 'basic-table-usage-example',
 *     templateUrl: './basic-table-usage-example.html'
 * }) export class BasicTableUsageExample {
 *     // either create your own, or use copies of buttons provided
 *     collectionButtons: CollectionButton[] = [
 *         {...EDIT_BUTTON}, {...DELETE_BUTTON}
 *     ];
 *     data: Task[] = [...];
 *     displayedColumns: string[] = ['select', 'id', 'actions'];
 * }
 * ```
 *
 * @overviewDetails
 * #### Features
 *
 * The `Table` automatically wires up sorting, renders and handles select
 * one or more rows, as well as adding one or more buttons to each row and
 * handling click events for those buttons.
 *
 * ##### Sorting
 *
 * To make sorting work all you need to do is add the `matSort` directive to
 * the `Table` selector and the `mat-sort-header` directive to the header cells
 * for the columns you want to be able to sort on. Other than making sure to
 * include the `MatSortModule` in the module where you define the component
 * that uses `Table`, there is nothing else you need to do.
 *
 * ##### Select
 *
 * The `Table` defines a column for selecting one, more, or all rows in the
 * table (select all being in the header). To utilize the select column simply
 * include `'select'` as one of the `displayedColumns` for the `Table`, and
 * it will be rendered along with all other columns included in the property.
 *
 * ##### Row Buttons
 *
 * A column for rendering one or more buttons in each row of the table is
 * also included in the main template. Additionally, `Table` includes
 * the `buttonClick` event emitter that emits a `ButtonClick` event which
 * should include the type of button that was clicked and the row data for
 * the row where the button was clicked. To utilize buttons in each row
 * of the table you must add an array of `collectionButtons` as an input
 * to the `Table` selector, and define a handler for `buttonClick` event
 * emitter.
 */
class TableComponent extends CollectionComponent {
    constructor(selectionService, matSort) {
        super(selectionService);
        /** Columns to display in the table. */
        this.displayedColumns = ['select', 'actions'];
        this.sort$ = matSort;
    }
    /**
     * After the <ng-content> has been initialized, the column definitions defined
     * in the HTML where this component is referenced are available. Once they are
     * available we need to add the definitions to the table manually so the MatTable
     * is aware of all additional columns included.
     */
    ngAfterContentInit() {
        this.columnDefs.forEach((columnDef) => this.table.addColumnDef(columnDef));
    }
}
TableComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: TableComponent, deps: [{ token: SelectionService }, { token: i2$6.MatSort }], target: i0.ɵɵFactoryTarget.Component });
TableComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: TableComponent, selector: "ngx-mat-table", inputs: { displayedColumns: "displayedColumns" }, queries: [{ propertyName: "columnDefs", predicate: MatColumnDef }], viewQueries: [{ propertyName: "table", first: true, predicate: MatTable, descendants: true, static: true }], usesInheritance: true, ngImport: i0, template: "<mat-table [dataSource]=\"dataSource$\">\n    <!-- Checkbox Column -->\n    <ng-container matColumnDef=\"select\">\n        <mat-header-cell *matHeaderCellDef>\n            <mat-checkbox\n                class=\"marker-checkbox-select-all\"\n                (change)=\"masterToggle()\"\n                [checked]=\"selection.hasValue() && isAllSelected()\"\n                [indeterminate]=\"selection.hasValue() && !isAllSelected()\">\n            </mat-checkbox>\n        </mat-header-cell>\n        <mat-cell *matCellDef=\"let row\">\n            <mat-checkbox \n                class=\"marker-checkbox-row-select\"\n                (click)=\"$event.stopPropagation()\"\n                (change)=\"onRowSelected(row);\"\n                [checked]=\"selection.isSelected(row)\">\n            </mat-checkbox>\n        </mat-cell>\n    </ng-container>\n    <!-- Additional columns defined in tag where this component is used -->\n    <ng-container></ng-container>\n\n    <!-- Actions Column (where buttons go) -->\n    <ng-container matColumnDef=\"actions\">\n        <mat-header-cell *matHeaderCellDef></mat-header-cell>\n        <mat-cell class=\"actions-cell mat-row-buttons\" *matCellDef=\"let row\">\n            <div class=\"row-hover\">\n                <button *ngFor=\"let button of collectionButtons\"\n                    class=\"marker-button-{{button.click}}\"\n                    (click)=\"onActionButtonClick(button.click, row)\"\n                    mat-icon-button>\n                    <fa-icon [icon]=\"button.icon\"></fa-icon>\n                    <div class=\"mat-button-focus-overlay\"></div>\n                    <div class=\"mat-button-ripple mat-ripple\"></div>\n                </button>\n            </div>\n        </mat-cell>\n    </ng-container>\n\n    <!-- row definitions -->\n    <mat-header-row *matHeaderRowDef=\"displayedColumns\"></mat-header-row>\n    <mat-row *matRowDef=\"let row; columns: displayedColumns\" class=\"pointer\"></mat-row>\n    <mat-footer-row *matFooterRowDef=\"['noData']\" [ngClass]=\"{'hide': length > 0}\"></mat-footer-row>\n</mat-table>\n", styles: [".hide{display:none}\n"], components: [{ type: i3$2.MatTable, selector: "mat-table, table[mat-table]", exportAs: ["matTable"] }, { type: i1$3.MatCheckbox, selector: "mat-checkbox", inputs: ["disableRipple", "color", "tabIndex", "aria-label", "aria-labelledby", "aria-describedby", "id", "required", "labelPosition", "name", "value", "checked", "disabled", "indeterminate"], outputs: ["change", "indeterminateChange"], exportAs: ["matCheckbox"] }, { type: i1$2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i2.FaIconComponent, selector: "fa-icon", inputs: ["icon", "title", "spin", "pulse", "mask", "styles", "flip", "size", "pull", "border", "inverse", "symbol", "rotate", "fixedWidth", "classes", "transform", "a11yRole"] }, { type: i3$2.MatHeaderRow, selector: "mat-header-row, tr[mat-header-row]", exportAs: ["matHeaderRow"] }, { type: i3$2.MatRow, selector: "mat-row, tr[mat-row]", exportAs: ["matRow"] }, { type: i3$2.MatFooterRow, selector: "mat-footer-row, tr[mat-footer-row]", exportAs: ["matFooterRow"] }], directives: [{ type: i3$2.MatColumnDef, selector: "[matColumnDef]", inputs: ["sticky", "matColumnDef"] }, { type: i3$2.MatHeaderCellDef, selector: "[matHeaderCellDef]" }, { type: i3$2.MatHeaderCell, selector: "mat-header-cell, th[mat-header-cell]" }, { type: i3$2.MatCellDef, selector: "[matCellDef]" }, { type: i3$2.MatCell, selector: "mat-cell, td[mat-cell]" }, { type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i3$2.MatHeaderRowDef, selector: "[matHeaderRowDef]", inputs: ["matHeaderRowDef", "matHeaderRowDefSticky"] }, { type: i3$2.MatRowDef, selector: "[matRowDef]", inputs: ["matRowDefColumns", "matRowDefWhen"] }, { type: i3$2.MatFooterRowDef, selector: "[matFooterRowDef]", inputs: ["matFooterRowDef", "matFooterRowDefSticky"] }, { type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i6.DefaultClassDirective, selector: "  [ngClass], [ngClass.xs], [ngClass.sm], [ngClass.md], [ngClass.lg], [ngClass.xl],  [ngClass.lt-sm], [ngClass.lt-md], [ngClass.lt-lg], [ngClass.lt-xl],  [ngClass.gt-xs], [ngClass.gt-sm], [ngClass.gt-md], [ngClass.gt-lg]", inputs: ["ngClass", "ngClass.xs", "ngClass.sm", "ngClass.md", "ngClass.lg", "ngClass.xl", "ngClass.lt-sm", "ngClass.lt-md", "ngClass.lt-lg", "ngClass.lt-xl", "ngClass.gt-xs", "ngClass.gt-sm", "ngClass.gt-md", "ngClass.gt-lg"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: TableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-table', template: "<mat-table [dataSource]=\"dataSource$\">\n    <!-- Checkbox Column -->\n    <ng-container matColumnDef=\"select\">\n        <mat-header-cell *matHeaderCellDef>\n            <mat-checkbox\n                class=\"marker-checkbox-select-all\"\n                (change)=\"masterToggle()\"\n                [checked]=\"selection.hasValue() && isAllSelected()\"\n                [indeterminate]=\"selection.hasValue() && !isAllSelected()\">\n            </mat-checkbox>\n        </mat-header-cell>\n        <mat-cell *matCellDef=\"let row\">\n            <mat-checkbox \n                class=\"marker-checkbox-row-select\"\n                (click)=\"$event.stopPropagation()\"\n                (change)=\"onRowSelected(row);\"\n                [checked]=\"selection.isSelected(row)\">\n            </mat-checkbox>\n        </mat-cell>\n    </ng-container>\n    <!-- Additional columns defined in tag where this component is used -->\n    <ng-container></ng-container>\n\n    <!-- Actions Column (where buttons go) -->\n    <ng-container matColumnDef=\"actions\">\n        <mat-header-cell *matHeaderCellDef></mat-header-cell>\n        <mat-cell class=\"actions-cell mat-row-buttons\" *matCellDef=\"let row\">\n            <div class=\"row-hover\">\n                <button *ngFor=\"let button of collectionButtons\"\n                    class=\"marker-button-{{button.click}}\"\n                    (click)=\"onActionButtonClick(button.click, row)\"\n                    mat-icon-button>\n                    <fa-icon [icon]=\"button.icon\"></fa-icon>\n                    <div class=\"mat-button-focus-overlay\"></div>\n                    <div class=\"mat-button-ripple mat-ripple\"></div>\n                </button>\n            </div>\n        </mat-cell>\n    </ng-container>\n\n    <!-- row definitions -->\n    <mat-header-row *matHeaderRowDef=\"displayedColumns\"></mat-header-row>\n    <mat-row *matRowDef=\"let row; columns: displayedColumns\" class=\"pointer\"></mat-row>\n    <mat-footer-row *matFooterRowDef=\"['noData']\" [ngClass]=\"{'hide': length > 0}\"></mat-footer-row>\n</mat-table>\n", styles: [".hide{display:none}\n"] }]
        }], ctorParameters: function () { return [{ type: SelectionService }, { type: i2$6.MatSort }]; }, propDecorators: { columnDefs: [{
                type: ContentChildren,
                args: [MatColumnDef]
            }], displayedColumns: [{
                type: Input
            }], table: [{
                type: ViewChild,
                args: [MatTable, { static: true }]
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A wrapper component for MatTable that provides built in paging, row selection,
 * and the ability to add custom buttons to each row through a built in `actions`
 * column. This component works very much like the MatTable component in both
 * configuration and usage. You must define the data, which can be either an
 * array of local data or a remote data source, and the table column templates
 * as well as list of columns to display (based on defined templates).
 *
 * The `RemoteDataSource` is included and provides an implementation of the
 * Angular Material `DataSource` for remote data, that relies on a model type
 * that extends the `JsonModel` object and an implementation of the
 * `JsonDatastore`, both defined in the `base-json` library. For more details
 * on the `JsonModel` and `JsonDatastore` check out the [base-json](/base-json)
 * documentation.
 *
 * @usageNotes
 * #### Basic Local Data Usage
 * ```html
 * <ngx-mat-paged-table matSort [data]="data" [displayedColumns]="displayedColumns">
 *     <ng-container matColumnDef="id">
 *         <mat-header-cell *matHeaderCellDef mat-sort-header>ID</mat-header-cell>
 *         <mat-cell *matCellDef="let row">{{row.id}}</mat-cell>
 *     </ng-container>
 *     <ng-container matColumnDef="name">
 *         <mat-header-cell *matHeaderCellDef mat-sort-header>Name</mat-header-cell>
 *         <mat-cell *matCellDef="let row">{{row.name}}</mat-cell>
 *     </ng-container>
 *     <ng-container matColumnDef="noData">
 *         <mat-footer-cell *matFooterCellDef colspan="displayedColumns.length" fxLayoutAlign="center center">
 *             No data to display
 *         </mat-footer-cell>
 *     </ng-container>
 * </ngx-mat-paged-table>
 * ```
 * ```typescript
 * import {AfterViewInit, Component, ViewChild} from '@angular/core';
 * import {MatSort} from '@angular/material/sort';
 * import {PagedTableComponent} from '@ngx-material-dashboard/widgets';
 * import {Model} from '@models'; // assumed path defined in tsconfig
 *
 * @Component({
 *  selector: 'paged-table-basic-local-data-usage-example',
 *  templateUrl: './paged-table-basic-local-data-usage-example.html'
 * })
 * class PagedTableBasicLocalDataUsageExample implements AfterViewInit {
 *    @ViewChild(PagedTableComponent) pagedTable!: PagedTableComponent<Model>;
 *    @ViewChild(MatSort) sort!: MatSort;
 *    data: Model[] = [];
 *    displayedColumns: string[] = ['select', 'id', 'name', 'actions'];
 *
 *    ngAfterViewInit(): void {
 *        // this is needed to properly initialize sorting capability for table
 *        this.pagedTable.sort = this.sort;
 *    }
 * }
 * ```
 *
 * @usageNotes
 * #### Remote Data Usage Example
 * ```html
 * <ngx-mat-paged-table
 *     matSort
 *     [buttons]="collectionButtons"
 *     [dataSource]="dataSource"
 *     [displayedColumns]="displayedColumns">
 *     <ng-container matColumnDef="id">
 *         <mat-header-cell *matHeaderCellDef mat-sort-header>ID</mat-header-cell>
 *         <mat-cell *matCellDef="let row">{{row.id}}</mat-cell>
 *     </ng-container>
 *     <ng-container matColumnDef="name">
 *         <mat-header-cell *matHeaderCellDef mat-sort-header>Name</mat-header-cell>
 *         <mat-cell *matCellDef="let row">{{row.name}}</mat-cell>
 *     </ng-container>
 *     <ng-container matColumnDef="noData">
 *         <mat-footer-cell *matFooterCellDef colspan="displayedColumns.length" fxLayoutAlign="center center">
 *             No data to display
 *         </mat-footer-cell>
 *     </ng-container>
 * </ngx-mat-paged-table>
 * ```
 * ```typescript
 * import {AfterViewInit, Component, ViewChild} from '@angular/core';
 * import {MatSort} from '@angular/material/sort';
 * import {
 *     PagedTableComponent,
 *     RemoteDataSource,
 *     TableButton,
 *     EDIT_BUTTON,
 *     DELETE_BUTTON
 * } from '@ngx-material-dashboard/widgets';
 * import {Model} from '@models'; // assumed path defined in tsconfig
 *
 * @Component({
 *  selector: 'paged-table-remote-data-usage-example',
 *  templateUrl: './paged-table-basic-remote-data-usage-example.html'
 * })
 * class PagedTableRemoteDataUsageExample implements AfterViewInit {
 *    @ViewChild(PagedTableComponent) pagedTable!: PagedTableComponent<Model>;
 *    @ViewChild(MatSort) sort!: MatSort;
 *    buttons: TableButton[] = [EDIT_BUTTON, DELETE_BUTTON];
 *    dataSource: RemoteDataSource<Model>;
 *    displayedColumns: string[] = ['select', 'id', 'name', 'actions'];
 *
 *    constructor(private jsonApiService: JsonApiService) {
 *        this.dataSource = new RemoteDataSource<T>(Model, this.jsonApiService);
 *    }
 *
 *    ngAfterViewInit(): void {
 *        // this is needed to properly initialize sorting capability for table
 *        this.pagedTable.sort = this.sort;
 *    }
 * }
 * ```
 *
 * @overviewDetails
 * #### Features
 *
 * The `PagedTable` provides some features out of the box that must be manaully
 * added for `MatTable`s. While you can add all of the features provided by
 * `PagedTable` to a `MatTable` directly, and there are examples of addeding
 * each of those features provided in the Angular Material documentation, the
 * `PagedTable` helps to reduce the amount of code needed and simplify adding
 * those features to the tables in your application.
 *
 * The main feature provided by `PagedTable` is unsurprisingly pagination.
 * Additionally there is sorting and table selection. See the sections below
 * for specifics on each of the features.
 *
 * ##### Pagination
 *
 * The `PagedTable` includes the `<mat-paginator>` in the components template,
 * and handles initializing the pagination for both local and remote data. There
 * is no additional configuration necessary to use this feature.
 *
 * ##### Sort
 *
 * The `PagedTable` includes the ability to add sorting just like `MatTable`. To
 * add sorting add the `matSort` directive to the `PagedTable` tag and add
 * `mat-sort-header`to each column header cell that should trigger sorting. You
 * must also set the sort on the `PagedTable` in your typescript code, which
 * will configure sorting for both local and remote data sources. Note that you
 * have to import `MatSortModule` in order to initialize the `matSort` directive.
 *
 * Your template should contain the following (similar to what you would add for
 * a `MatTable`).
 *
 * ```html
 * <ngx-mat-paged-table matSort [data]="data">
 *     <ng-container matColumnDef="name">
 *         <mat-header-cell *matHeaderCellDef mat-sort-header>Name</mat-header-cell>
 *         <mat-cell *matCellDef="let row">{{row.name}}</mat-cell>
 *     </ng-container>
 * </ngx-mat-paged-table>
 * ```
 *
 * And your component should implement `AfterViewInit` and contain the following
 * code.
 *
 * ```typescript
 * ...
 * @ViewChild(PagedTableComponent) pagedTable!: PagedTableComponent<Model>;
 * @ViewChild(MatSort) sort!: MatSort;
 * ...
 *
 * ngAfterViewInit(): void {
 *     // this is needed to properly initialize sorting capability for table
 *     this.pagedTable.sort = this.sort;
 * }
 * ...
 * ```
 *
 * ##### Selection
 *
 * The `PagedTable` provides all code necessary for handling selecting one or
 * more rows in your tables. The only thing you need to do is add the `select`
 * column to your array of `displayedColumns` that you pass as an `@Input`
 * value to the component. You can use the `selectionChange` `Observable`
 * provided in the `SelectionService` which is included with the `TableModule`
 * for handling change events. This returns an `Observable` of ` a
 * `SelectionModel` from `@angular/cdk/collections`, which should be easy
 * enough to work with if you are familiar with the example solution provided
 * for `MatTable` in the Angular Material (documentation)
 *
 * ### No Table Data
 *
 * If you want to display any text in the table when there is no data available
 * you should include a "noData" column definition with a colspan set to the
 * number of displayed columns in the table so the text can be centered in the
 * table. The column definition should look like the following:
 *
 * ```html
 * <ng-container matColumnDef="noData">
 *     <mat-footer-cell *matFooterCellDef colspan="displayedColumns.length" fxLayoutAlign="center center">
 *         No data to display
 *     </mat-footer-cell>
 * </ng-container>
 * ```
 *
 * TODO: Update to use matNoDataRow
 *
 */
class PagedTableComponent extends PagedCollectionComponent {
    /**
     * Creates a new PagedTableComponent. Note that the matSort directive is
     * included in the constructor per the answer provided at the stackoverflow
     * question here: https://stackoverflow.com/a/58548837. Apparently there is
     * an issue accessing directives included directly in components and the
     * only way to access them is with DI.
     *
     * @param sort$ DI directive needed for sorting columns.
     */
    constructor(sort$) {
        super();
        this.sort$ = sort$;
        /** Columns to display in the table. */
        this.displayedColumns = ['select', 'actions'];
    }
    /**
     * After the <ng-content> has been initialized, the column definitions defined
     * in the HTML where this component is referenced are available. Once they are
     * available we need to add the definitions to the table manually so the MatTable
     * is aware of all additional columns included.
     */
    ngAfterContentInit() {
        this.columnDefs.forEach((columnDef) => this.collection$.table.addColumnDef(columnDef));
    }
    ngAfterViewInit() {
        super.ngAfterViewInit();
        this.collection$.dataSource$.paginator = this.paginator$;
        this.collection$.dataSource$.sort = this.sort$;
    }
}
PagedTableComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedTableComponent, deps: [{ token: i2$6.MatSort }], target: i0.ɵɵFactoryTarget.Component });
PagedTableComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: PagedTableComponent, selector: "ngx-mat-paged-table", inputs: { displayedColumns: "displayedColumns" }, queries: [{ propertyName: "columnDefs", predicate: MatColumnDef }], viewQueries: [{ propertyName: "collection$", first: true, predicate: TableComponent, descendants: true, static: true }, { propertyName: "paginator$", first: true, predicate: MatPaginator, descendants: true }], usesInheritance: true, ngImport: i0, template: "<ngx-mat-table\n    [collectionButtons]=\"collectionButtons\"\n    [dataSource]=\"dataSource$\"\n    [displayedColumns]=\"displayedColumns\"\n    [multiple]=\"multiple\"\n    (buttonClick)=\"onButtonClick($event)\"\n    #collection>\n    <!-- Additional columns defined in tag where this component is used -->\n    <ng-container></ng-container>\n</ngx-mat-table>\n<mat-paginator [length]=\"length\" \n                [pageSize]=\"pageSize\" \n                [pageSizeOptions]=\"[15, 25, 50, 75, 100]\">\n</mat-paginator>\n", styles: [""], components: [{ type: TableComponent, selector: "ngx-mat-table", inputs: ["displayedColumns"] }, { type: i2$3.MatPaginator, selector: "mat-paginator", inputs: ["disabled"], exportAs: ["matPaginator"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedTableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-paged-table', changeDetection: ChangeDetectionStrategy.OnPush, template: "<ngx-mat-table\n    [collectionButtons]=\"collectionButtons\"\n    [dataSource]=\"dataSource$\"\n    [displayedColumns]=\"displayedColumns\"\n    [multiple]=\"multiple\"\n    (buttonClick)=\"onButtonClick($event)\"\n    #collection>\n    <!-- Additional columns defined in tag where this component is used -->\n    <ng-container></ng-container>\n</ngx-mat-table>\n<mat-paginator [length]=\"length\" \n                [pageSize]=\"pageSize\" \n                [pageSizeOptions]=\"[15, 25, 50, 75, 100]\">\n</mat-paginator>\n", styles: [""] }]
        }], ctorParameters: function () { return [{ type: i2$6.MatSort }]; }, propDecorators: { columnDefs: [{
                type: ContentChildren,
                args: [MatColumnDef]
            }], displayedColumns: [{
                type: Input
            }], collection$: [{
                type: ViewChild,
                args: [TableComponent, { static: true }]
            }], paginator$: [{
                type: ViewChild,
                args: [MatPaginator]
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `PagedTableWithIconButtonsPaginatorBar` is a wrapper for the
 * `PagedPagedTable` and `IconButtonsWithPaginator` toolbar components. It
 * allows you to define and render your data models in a paged-table with
 * built in paging and basic data management buttons with easy to use
 * handlers for when the user clicks a button in the toolbar or the
 * collection. The toolbar is rendered above the data paged-table.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-paged-table-with-icon-buttons-paginator-bar
 *     [fields]="fields"
 *     [toolbarButtons]="toolbarButtons"
 *     (buttonClick)="onButtonClick($event)"
 *     class="marker-paged-list">
 *     <ngx-mat-paged-table
 *          [collectionButtons]="collectionButtons"
 *          [data]="data"
 *          [displayedColumns]="displayedColumns"
 *          collection
 *          #collection>
 *         <ng-container matColumnDef="name">
 *             <mat-header-cell *matHeaderCellDef mat-sort-header>Name</mat-header-cell>
 *             <mat-cell class="name-cell" *matCellDef="let obj">{{obj.name}}</mat-cell>
 *         </ng-container>
 *         <ng-container matColumnDef="description">
 *             <mat-header-cell *matHeaderCellDef mat-sort-header>Description</mat-header-cell>
 *             <mat-cell class="description-cell" *matCellDef="let obj">{{obj.description}}</mat-cell>
 *         </ng-container>
 *         <ng-container matColumnDef="dueDate">
 *             <mat-header-cell *matHeaderCellDef mat-sort-header>Due Date</mat-header-cell>
 *             <mat-cell class="due-date-cell" *matCellDef="let obj">{{obj.dueDate}}</mat-cell>
 *         </ng-container>
 *         <ng-container matColumnDef="noData">
 *             <mat-footer-cell *matFooterCellDef colspan="displayedColumns.length" fxLayoutAlign="center center">
 *                 No data found
 *             </mat-footer-cell>
 *         </ng-container>
 *     </ngx-mat-paged-table>
 * </ngx-mat-paged-table-with-icon-buttons-paginator-bar>
 * ```
 * ```typescript
 * @Component({
 *     selector: 'basic-paged-table-usage-example',
 *     templateUrl: './basic-paged-table-usage-example.html'
 * }) export class BasicPagedTableUsageExample {
 *     data: Task[] = [...];
 *     displayedColumns: string[] = ['select', 'name', 'description', 'dueDate', 'actions'];
 *     // either create your own, or use copies of buttons provided for both
 *     // collection and toolbar; use copies without references in case you
 *     // have multiple collections to render so each one gets their own
 *     // buttons and own subscriptions (otherwise events in one table will
 *     // affect buttons in others)
 *     collectionButtons: CollectionButton[] = [
 *         {...EDIT_BUTTON}, {...DELETE_BUTTON}
 *     ];
 *     toolbarButtons: ToolbarButton[] = [
 *         {...CREATE_TOOLBAR_BUTTON}, {...EDIT_TOOLBAR_BUTTON}, {...DELETE_TOOLBAR_BUTTON}
 *     ];
 *
 *     onButtonClick(btnClick: ButtonClick): void {
 *         if (btnClick.click === 'create') {
 *             // handle create
 *         } else if (btnClick.click === 'edit') {
 *             // handle edit
 *         } else if (btnClick.click === 'delete') {
 *             // handle delete
 *         }
 *     }
 * }
 * ```
 */
class PagedTableWithRaisedButtonsBarComponent extends PagedCollectionWithRaisedButtonToolbarComponent {
    constructor() {
        super(...arguments);
        /** Columns to display in the table. */
        this.displayedColumns = ['select', 'actions'];
    }
}
PagedTableWithRaisedButtonsBarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedTableWithRaisedButtonsBarComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
PagedTableWithRaisedButtonsBarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: PagedTableWithRaisedButtonsBarComponent, selector: "ngx-mat-paged-table-with-raised-buttons-bar", inputs: { displayedColumns: "displayedColumns" }, queries: [{ propertyName: "collectionCmp", first: true, predicate: ["collection"], descendants: true }], usesInheritance: true, ngImport: i0, template: "<ngx-mat-button-toolbar \n    [buttons]=\"toolbarButtons\"\n    ngxMatSearchFilter\n    [form]=\"form\"\n    [filter]=\"filter\"\n    [collection]=\"collectionCmp\"\n    (buttonClick)=\"onToolbarButtonClick($event)\">\n    <ng-content select=\"[filter]\"></ng-content>\n</ngx-mat-button-toolbar>\n<!-- paged-table -->\n<ng-content select=\"[collection]\"></ng-content>\n", styles: [""], components: [{ type: ButtonToolbarComponent, selector: "ngx-mat-button-toolbar", inputs: ["buttons", "buttonAlign"], outputs: ["buttonClick"] }], directives: [{ type: SearchFilterDirective, selector: "[ngxMatSearchFilter]", inputs: ["filter", "form", "collection"], outputs: ["searchClick"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PagedTableWithRaisedButtonsBarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-paged-table-with-raised-buttons-bar', template: "<ngx-mat-button-toolbar \n    [buttons]=\"toolbarButtons\"\n    ngxMatSearchFilter\n    [form]=\"form\"\n    [filter]=\"filter\"\n    [collection]=\"collectionCmp\"\n    (buttonClick)=\"onToolbarButtonClick($event)\">\n    <ng-content select=\"[filter]\"></ng-content>\n</ngx-mat-button-toolbar>\n<!-- paged-table -->\n<ng-content select=\"[collection]\"></ng-content>\n", styles: [""] }]
        }], propDecorators: { displayedColumns: [{
                type: Input
            }], collectionCmp: [{
                type: ContentChild,
                args: ['collection']
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * The `PagedTableWithIconButtonsPaginatorBar` is a wrapper for the `PagedPagedTable` and
 * `IconButtonsWithPaginator` toolbar components. It allows you to define and
 * render your data models in a paged-table with built in paging and basic data
 * management buttons with easy to use handlers for when the user clicks a
 * button in the toolbar or the collection. The toolbar is rendered above the
 * data paged-table.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-paged-table-with-icon-buttons-paginator-bar
 *     [fields]="fields"
 *     [toolbarButtons]="toolbarButtons"
 *     (buttonClick)="onButtonClick($event)"
 *     class="marker-paged-paged-table">
 *     <ngx-mat-paged-table [collectionButtons]="collectionButtons" [data]="data" #collection>
 *         <ng-container matColumnDef="id">
 *             <mat-header-cell *matHeaderCellDef mat-sort-header>ID</mat-header-cell>
 *             <mat-cell class="col1-cell" *matCellDef="let obj">{{obj.id}}</mat-cell>
 *         </ng-container>
 *         <ng-container matColumnDef="noData">
 *             <mat-footer-cell *matFooterCellDef colspan="displayedColumns.length" fxLayoutAlign="center center">
 *                 No data found
 *             </mat-footer-cell>
 *         </ng-container>
 *     </ngx-mat-paged-table>
 * </ngx-mat-paged-table-with-icon-buttons-paginator-bar>
 * ```
 * ```typescript
 * @Component({
 *     selector: 'basic-paged-table-usage-example',
 *     templateUrl: './basic-paged-table-usage-example.html'
 * }) export class BasicPagedTableUsageExample {
 *     data: Task[] = [...];
 *     fields: string[] = ['id'];
 *     // either create your own, or use copies of buttons provided for both
 *     // collection and toolbar; use copies without references in case you
 *     // have multiple collections to render so each one gets their own
 *     // buttons and own subscriptions (otherwise events in one table will
 *     // affect buttons in others)
 *     collectionButtons: CollectionButton[] = [
 *         {...EDIT_BUTTON}, {...DELETE_BUTTON}
 *     ];
 *     toolbarButtons: ToolbarButton[] = [
 *         {...CREATE_TOOLBAR_BUTTON}, {...EDIT_TOOLBAR_BUTTON}, {...DELETE_TOOLBAR_BUTTON}
 *     ];
 *
 *     onButtonClick(btnClick: ButtonClick): void {
 *         if (btnClick.click === 'create') {
 *             // handle create
 *         } else if (btnClick.click === 'edit') {
 *             // handle edit
 *         } else if (btnClick.click === 'delete') {
 *             // handle delete
 *         }
 *     }
 * }
 * ```
 */
class TableWithIconButtonsPaginatorBarComponent extends PagedCollectionWithIconToolbarComponent {
    constructor() {
        super(...arguments);
        /** Columns to display in the table. */
        this.displayedColumns = ['select', 'actions'];
    }
}
TableWithIconButtonsPaginatorBarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: TableWithIconButtonsPaginatorBarComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
TableWithIconButtonsPaginatorBarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.12", type: TableWithIconButtonsPaginatorBarComponent, selector: "ngx-mat-table-with-icon-buttons-paginator-bar", inputs: { displayedColumns: "displayedColumns" }, queries: [{ propertyName: "collectionCmp", first: true, predicate: TableComponent, descendants: true }], usesInheritance: true, ngImport: i0, template: "<ngx-mat-icon-buttons-with-paginator\n    [buttons]=\"toolbarButtons\"\n    [displaySelectAll]=\"false\"\n    [displaySort]=\"false\"\n    [length]=\"length\"\n    [multiple]=\"multiple\"\n    [pageSize]=\"pageSize\"\n    (buttonClick)=\"onToolbarButtonClick($event)\">\n</ngx-mat-icon-buttons-with-paginator>\n<!-- table -->\n<ng-content></ng-content>\n", styles: [""], components: [{ type: IconButtonsWithPaginatorComponent, selector: "ngx-mat-icon-buttons-with-paginator", inputs: ["buttons", "displaySelectAll", "displaySort", "fields", "isAllSelected", "length", "multiple", "pageSize", "selection"], outputs: ["buttonClick", "masterToggle"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: TableWithIconButtonsPaginatorBarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-table-with-icon-buttons-paginator-bar', template: "<ngx-mat-icon-buttons-with-paginator\n    [buttons]=\"toolbarButtons\"\n    [displaySelectAll]=\"false\"\n    [displaySort]=\"false\"\n    [length]=\"length\"\n    [multiple]=\"multiple\"\n    [pageSize]=\"pageSize\"\n    (buttonClick)=\"onToolbarButtonClick($event)\">\n</ngx-mat-icon-buttons-with-paginator>\n<!-- table -->\n<ng-content></ng-content>\n", styles: [""] }]
        }], propDecorators: { displayedColumns: [{
                type: Input
            }], collectionCmp: [{
                type: ContentChild,
                args: [TableComponent]
            }] } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
class TableModule {
}
TableModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: TableModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
TableModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: TableModule, declarations: [PagedTableComponent,
        PagedTableWithRaisedButtonsBarComponent,
        TableComponent,
        TableWithIconButtonsPaginatorBarComponent], imports: [CommonModule,
        FlexLayoutModule,
        FormsModule,
        ReactiveFormsModule,
        FontAwesomeModule,
        MatButtonModule,
        MatCheckboxModule,
        MatDividerModule,
        MatFormFieldModule,
        MatInputModule,
        MatListModule,
        MatPaginatorModule,
        MatMenuModule,
        MatSortModule,
        MatTableModule,
        MatToolbarModule,
        CollectionModule,
        FormModule,
        ToolbarModule], exports: [PagedTableComponent,
        PagedTableWithRaisedButtonsBarComponent,
        TableComponent,
        TableWithIconButtonsPaginatorBarComponent] });
TableModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: TableModule, imports: [[
            CommonModule,
            FlexLayoutModule,
            FormsModule,
            ReactiveFormsModule,
            FontAwesomeModule,
            MatButtonModule,
            MatCheckboxModule,
            MatDividerModule,
            MatFormFieldModule,
            MatInputModule,
            MatListModule,
            MatPaginatorModule,
            MatMenuModule,
            MatSortModule,
            MatTableModule,
            MatToolbarModule,
            CollectionModule,
            FormModule,
            ToolbarModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: TableModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        PagedTableComponent,
                        PagedTableWithRaisedButtonsBarComponent,
                        TableComponent,
                        TableWithIconButtonsPaginatorBarComponent
                    ],
                    exports: [
                        PagedTableComponent,
                        PagedTableWithRaisedButtonsBarComponent,
                        TableComponent,
                        TableWithIconButtonsPaginatorBarComponent
                    ],
                    imports: [
                        CommonModule,
                        FlexLayoutModule,
                        FormsModule,
                        ReactiveFormsModule,
                        FontAwesomeModule,
                        MatButtonModule,
                        MatCheckboxModule,
                        MatDividerModule,
                        MatFormFieldModule,
                        MatInputModule,
                        MatListModule,
                        MatPaginatorModule,
                        MatMenuModule,
                        MatSortModule,
                        MatTableModule,
                        MatToolbarModule,
                        CollectionModule,
                        FormModule,
                        ToolbarModule
                    ]
                }]
        }] });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A shareable service for managing state changes in filter for paged content.
 */
class FilterService {
    constructor() {
        /** The behavior subject that tracks the latest filter map. */
        this.filterSub = new BehaviorSubject(null);
        this.filter = this.filterSub.asObservable();
    }
    /**
     * Updates the filter subject with the next filter value.
     */
    search(filter) {
        this.filterSub.next(filter);
    }
}
FilterService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FilterService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
FilterService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FilterService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: FilterService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
/**
 * A basic add button.
 */
const CREATE_TOOLBAR_BUTTON = {
    canDisable: false,
    disabled: false,
    icon: faPlus,
    multiSelectDisabled: false,
    text: 'Add',
    click: 'create'
};
/**
 * A basic edit button.
 */
const EDIT_TOOLBAR_BUTTON = {
    canDisable: true,
    disabled: true,
    icon: faEdit,
    multiSelectDisabled: true,
    text: 'Edit',
    click: 'edit'
};
/**
 * A basic delete button.
 */
const DELETE_TOOLBAR_BUTTON = {
    canDisable: true,
    disabled: true,
    icon: faTrash,
    multiSelectDisabled: false,
    text: 'Delete',
    click: 'delete'
};
/** Default buttons for toolbar above collection. */
const DEFAULT_TOOLBAR_BUTTONS = [
    CREATE_TOOLBAR_BUTTON,
    EDIT_TOOLBAR_BUTTON,
    DELETE_TOOLBAR_BUTTON
];

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */

/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */

/**
 * Generated bundle index. Do not edit.
 */

export { Alert, AlertComponent, AlertModule, AlertService, AlertType, ButtonClickAction, ButtonToolbarComponent, CREATE_TOOLBAR_BUTTON, ClickStopPropagationDirective, CollectionComponent, CollectionModule, ConfirmDeleteDialogComponent, DEFAULT_COLLECTION_BUTTONS, DEFAULT_TOOLBAR_BUTTONS, DELETE_BUTTON, DELETE_TOOLBAR_BUTTON, DefaultLayoutComponent, DialogModule, EDIT_BUTTON, EDIT_TOOLBAR_BUTTON, FieldErrorComponent, FilterDropDownComponent, FilterService, FormModule, FormService, GridComponent, GridModule, GridWithIconButtonsPaginatorBarComponent, IconButtonsWithPaginatorComponent, LayoutModule, ListComponent, ListModule, ListWithIconButtonsPaginatorBarComponent, LoadingComponent, LoadingService, PagedCollectionComponent, PagedCollectionWithIconToolbarComponent, PagedCollectionWithRaisedButtonToolbarComponent, PagedCollectionWithToolbarComponent, PagedGridComponent, PagedGridWithRaisedButtonsBarComponent, PagedListComponent, PagedListWithRaisedButtonsBarComponent, PagedTableComponent, PagedTableWithRaisedButtonsBarComponent, RaisedButtonToolbarComponent, RemoteDataSource, ScreenSize, SearchFilterDirective, SelectionService, SidenavComponent, SorterComponent, TabStopPropagationDirective, TableComponent, TableModule, TableWithIconButtonsPaginatorBarComponent, ToolbarModule };
//# sourceMappingURL=ngx-material-dashboard-widgets.mjs.map
